Class: Google::Apis::ChatV1::AccessSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents the access setting of the space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AccessSettings

Returns a new instance of AccessSettings.



105
106
107
# File 'lib/google/apis/chat_v1/classes.rb', line 105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_permission_settingsGoogle::Apis::ChatV1::AccessPermissionSettings

Access permission settings for a space. Corresponds to the JSON property accessPermissionSettings



77
78
79
# File 'lib/google/apis/chat_v1/classes.rb', line 77

def access_permission_settings
  @access_permission_settings
end

#access_stateString

Output only. Indicates the access state of the space. Corresponds to the JSON property accessState

Returns:

  • (String)


82
83
84
# File 'lib/google/apis/chat_v1/classes.rb', line 82

def access_state
  @access_state
end

#audienceString

Optional. The resource name of the target audience who can discover the space, join the space, and preview the messages in the space. If unset, only users or Google Groups who have been individually invited or added to the space can access it. For details, see Make a space discoverable to a target audience. Format: audiences/audience`To use the default target audience for the Google Workspace organization, set to audiences/default. Reading the target audience supports: - [User authentication](https://developers.google.com/workspace/chat/authenticate- authorize-chat-user) - [App authentication](https://developers.google.com/ workspace/chat/authenticate-authorize-chat-app) with [administrator approval]( https://support.google.com/a?p=chat-app-auth) with thechat.app.spacesscope. This field is not populated when using thechat.botscope with [app authentication](https://developers.google.com/workspace/chat/authenticate- authorize-chat-app). Setting the target audience requires [user authentication] (https://developers.google.com/workspace/chat/authenticate-authorize-chat-user) . Corresponds to the JSON propertyaudience`

Returns:

  • (String)


103
104
105
# File 'lib/google/apis/chat_v1/classes.rb', line 103

def audience
  @audience
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



110
111
112
113
114
# File 'lib/google/apis/chat_v1/classes.rb', line 110

def update!(**args)
  @access_permission_settings = args[:access_permission_settings] if args.key?(:access_permission_settings)
  @access_state = args[:access_state] if args.key?(:access_state)
  @audience = args[:audience] if args.key?(:audience)
end