Class: Google::Apis::ChatV1::AppCommandMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::AppCommandMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Metadata about a Chat app command.
Instance Attribute Summary collapse
-
#app_command_id ⇒ Fixnum
The ID for the command specified in the Chat API configuration.
-
#app_command_type ⇒ String
The type of Chat app command.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppCommandMetadata
constructor
A new instance of AppCommandMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppCommandMetadata
Returns a new instance of AppCommandMetadata.
268 269 270 |
# File 'lib/google/apis/chat_v1/classes.rb', line 268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_command_id ⇒ Fixnum
The ID for the command specified in the Chat API configuration.
Corresponds to the JSON property appCommandId
261 262 263 |
# File 'lib/google/apis/chat_v1/classes.rb', line 261 def app_command_id @app_command_id end |
#app_command_type ⇒ String
The type of Chat app command.
Corresponds to the JSON property appCommandType
266 267 268 |
# File 'lib/google/apis/chat_v1/classes.rb', line 266 def app_command_type @app_command_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
273 274 275 276 |
# File 'lib/google/apis/chat_v1/classes.rb', line 273 def update!(**args) @app_command_id = args[:app_command_id] if args.key?(:app_command_id) @app_command_type = args[:app_command_type] if args.key?(:app_command_type) end |