Class: Google::Apis::ChatV1::AttachmentDataRef
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::AttachmentDataRef
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A reference to the attachment data.
Instance Attribute Summary collapse
-
#attachment_upload_token ⇒ String
Optional.
-
#resource_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AttachmentDataRef
constructor
A new instance of AttachmentDataRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AttachmentDataRef
Returns a new instance of AttachmentDataRef.
431 432 433 |
# File 'lib/google/apis/chat_v1/classes.rb', line 431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_upload_token ⇒ String
Optional. Opaque token containing a reference to an uploaded attachment.
Treated by clients as an opaque string and used to create or update Chat
messages with attachments.
Corresponds to the JSON property attachmentUploadToken
423 424 425 |
# File 'lib/google/apis/chat_v1/classes.rb', line 423 def @attachment_upload_token end |
#resource_name ⇒ String
Optional. The resource name of the attachment data. This field is used with
the media API to download the attachment data.
Corresponds to the JSON property resourceName
429 430 431 |
# File 'lib/google/apis/chat_v1/classes.rb', line 429 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
436 437 438 439 |
# File 'lib/google/apis/chat_v1/classes.rb', line 436 def update!(**args) @attachment_upload_token = args[:attachment_upload_token] if args.key?(:attachment_upload_token) @resource_name = args[:resource_name] if args.key?(:resource_name) end |