Class: Google::Apis::ChatV1::Audience

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A target audience in Google Chat. A target audience represents a group of users within a Google Workspace organization, defined by an administrator. Target audiences are used to configure access and visibility settings for resources, such as making a space discoverable to a specific group of users. For more details, see Target audiences and Make a space discoverable to a target audience.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Audience

Returns a new instance of Audience.



462
463
464
# File 'lib/google/apis/chat_v1/classes.rb', line 462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The resource name of the target audience who can discover or join the space. For details, see Make a space discoverable to a target audience. Format: audiences/audience`To use the default target audience for the Google Workspace organization, set toaudiences/ default. Corresponds to the JSON propertyname`

Returns:

  • (String)


460
461
462
# File 'lib/google/apis/chat_v1/classes.rb', line 460

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



467
468
469
# File 'lib/google/apis/chat_v1/classes.rb', line 467

def update!(**args)
  @name = args[:name] if args.key?(:name)
end