Class: Google::Apis::ChatV1::ChatAppLogEntry
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::ChatAppLogEntry
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
JSON payload of error messages. If the Cloud Logging API is enabled, these error messages are logged to Google Cloud Logging.
Instance Attribute Summary collapse
-
#deployment ⇒ String
The deployment that caused the error.
-
#deployment_function ⇒ String
The unencrypted
callback_methodname that was running when the error was encountered. -
#error ⇒ Google::Apis::ChatV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChatAppLogEntry
constructor
A new instance of ChatAppLogEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChatAppLogEntry
Returns a new instance of ChatAppLogEntry.
683 684 685 |
# File 'lib/google/apis/chat_v1/classes.rb', line 683 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment ⇒ String
The deployment that caused the error. For Chat apps built in Apps Script, this
is the deployment ID defined by Apps Script.
Corresponds to the JSON property deployment
665 666 667 |
# File 'lib/google/apis/chat_v1/classes.rb', line 665 def deployment @deployment end |
#deployment_function ⇒ String
The unencrypted callback_method name that was running when the error was
encountered.
Corresponds to the JSON property deploymentFunction
671 672 673 |
# File 'lib/google/apis/chat_v1/classes.rb', line 671 def deployment_function @deployment_function end |
#error ⇒ Google::Apis::ChatV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
681 682 683 |
# File 'lib/google/apis/chat_v1/classes.rb', line 681 def error @error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
688 689 690 691 692 |
# File 'lib/google/apis/chat_v1/classes.rb', line 688 def update!(**args) @deployment = args[:deployment] if args.key?(:deployment) @deployment_function = args[:deployment_function] if args.key?(:deployment_function) @error = args[:error] if args.key?(:error) end |