Class: Google::Apis::ChatV1::CustomStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents a user's custom status in Google Chat. This includes a short text message with an optional emoji that a user sets to give more context about their availability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomStatus

Returns a new instance of CustomStatus.



1125
1126
1127
# File 'lib/google/apis/chat_v1/classes.rb', line 1125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emojiGoogle::Apis::ChatV1::Emoji

An emoji that is used as a reaction to a message. Corresponds to the JSON property emoji



1107
1108
1109
# File 'lib/google/apis/chat_v1/classes.rb', line 1107

def emoji
  @emoji
end

#expire_timeString

The timestamp when the custom status expires. Corresponds to the JSON property expireTime

Returns:

  • (String)


1112
1113
1114
# File 'lib/google/apis/chat_v1/classes.rb', line 1112

def expire_time
  @expire_time
end

#textString

Required. The text of the custom status. This will be a string with maximum length of 64. Corresponds to the JSON property text

Returns:

  • (String)


1118
1119
1120
# File 'lib/google/apis/chat_v1/classes.rb', line 1118

def text
  @text
end

#ttlString

Input only. The time-to-live duration after which the custom status expires. Corresponds to the JSON property ttl

Returns:

  • (String)


1123
1124
1125
# File 'lib/google/apis/chat_v1/classes.rb', line 1123

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1130
1131
1132
1133
1134
1135
# File 'lib/google/apis/chat_v1/classes.rb', line 1130

def update!(**args)
  @emoji = args[:emoji] if args.key?(:emoji)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @text = args[:text] if args.key?(:text)
  @ttl = args[:ttl] if args.key?(:ttl)
end