Class: Google::Apis::ChatV1::DoNotDisturbMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Metadata associated with the DO_NOT_DISTURB availability state, specifying when the state is set to expire.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DoNotDisturbMetadata

Returns a new instance of DoNotDisturbMetadata.



1444
1445
1446
# File 'lib/google/apis/chat_v1/classes.rb', line 1444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expiration_timeString

Output only. Timestamp until which the user should be marked as DO_NOT_DISTURB. This can be maximum of 1 year in the future. Corresponds to the JSON property expirationTime

Returns:

  • (String)


1442
1443
1444
# File 'lib/google/apis/chat_v1/classes.rb', line 1442

def expiration_time
  @expiration_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1449
1450
1451
# File 'lib/google/apis/chat_v1/classes.rb', line 1449

def update!(**args)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
end