Class: Google::Apis::ChatV1::DriveLinkData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Data for Google Drive links.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DriveLinkData

Returns a new instance of DriveLinkData.



1373
1374
1375
# File 'lib/google/apis/chat_v1/classes.rb', line 1373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#drive_data_refGoogle::Apis::ChatV1::DriveDataRef

A reference to the data of a drive attachment. Corresponds to the JSON property driveDataRef



1366
1367
1368
# File 'lib/google/apis/chat_v1/classes.rb', line 1366

def drive_data_ref
  @drive_data_ref
end

#mime_typeString

The mime type of the linked Google Drive resource. Corresponds to the JSON property mimeType

Returns:

  • (String)


1371
1372
1373
# File 'lib/google/apis/chat_v1/classes.rb', line 1371

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1378
1379
1380
1381
# File 'lib/google/apis/chat_v1/classes.rb', line 1378

def update!(**args)
  @drive_data_ref = args[:drive_data_ref] if args.key?(:drive_data_ref)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end