Class: Google::Apis::ChatV1::EmojiReactionSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

The number of people who reacted to a message with a specific emoji.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EmojiReactionSummary

Returns a new instance of EmojiReactionSummary.



1423
1424
1425
# File 'lib/google/apis/chat_v1/classes.rb', line 1423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emojiGoogle::Apis::ChatV1::Emoji

An emoji that is used as a reaction to a message. Corresponds to the JSON property emoji



1416
1417
1418
# File 'lib/google/apis/chat_v1/classes.rb', line 1416

def emoji
  @emoji
end

#reaction_countFixnum

Output only. The total number of reactions using the associated emoji. Corresponds to the JSON property reactionCount

Returns:

  • (Fixnum)


1421
1422
1423
# File 'lib/google/apis/chat_v1/classes.rb', line 1421

def reaction_count
  @reaction_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1428
1429
1430
1431
# File 'lib/google/apis/chat_v1/classes.rb', line 1428

def update!(**args)
  @emoji = args[:emoji] if args.key?(:emoji)
  @reaction_count = args[:reaction_count] if args.key?(:reaction_count)
end