Class: Google::Apis::ChatV1::GoogleAppsCardV1Button
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1Button
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A text, icon, or text and icon button that users can click. For an example in
Google Chat apps, see Add a button. To make an image a
clickable button, specify an Image (not an ImageComponent) and set an
onClick action. Google Workspace add-ons and Chat apps:
Instance Attribute Summary collapse
-
#alt_text ⇒ String
The alternative text that's used for accessibility.
-
#color ⇒ Google::Apis::ChatV1::Color
Represents a color in the RGBA color space.
-
#disabled ⇒ Boolean
(also: #disabled?)
If
true, the button is displayed in an inactive state and doesn't respond to user actions. -
#icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Icon
An icon displayed in a widget on a card.
-
#on_click ⇒ Google::Apis::ChatV1::GoogleAppsCardV1OnClick
Represents how to respond when users click an interactive element on a card, such as a button.
-
#text ⇒ String
The text displayed inside the button.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1Button
constructor
A new instance of GoogleAppsCardV1Button.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1Button
Returns a new instance of GoogleAppsCardV1Button.
2032 2033 2034 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alt_text ⇒ String
The alternative text that's used for accessibility. Set descriptive text that
lets users know what the button does. For example, if a button opens a
hyperlink, you might write: "Opens a new browser tab and navigates to the
Google Chat developer documentation at https://developers.google.com/workspace/
chat".
Corresponds to the JSON property altText
1944 1945 1946 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1944 def alt_text @alt_text end |
#color ⇒ Google::Apis::ChatV1::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property color
1993 1994 1995 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1993 def color @color end |
#disabled ⇒ Boolean Also known as: disabled?
If true, the button is displayed in an inactive state and doesn't respond to
user actions.
Corresponds to the JSON property disabled
1999 2000 2001 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1999 def disabled @disabled end |
#icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Icon
An icon displayed in a widget on a card. For an example in Google Chat apps,
see Add an icon. Supports built-in and custom icons. Google
Workspace add-ons and Chat apps:
Corresponds to the JSON property icon
2011 2012 2013 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2011 def icon @icon end |
#on_click ⇒ Google::Apis::ChatV1::GoogleAppsCardV1OnClick
Represents how to respond when users click an interactive element on a card,
such as a button. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property onClick
2018 2019 2020 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2018 def on_click @on_click end |
#text ⇒ String
The text displayed inside the button.
Corresponds to the JSON property text
2023 2024 2025 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2023 def text @text end |
#type ⇒ String
Optional. The type of a button. If unset, button type defaults to OUTLINED.
If the color field is set, the button type is forced to FILLED and any
value set for this field is ignored.
Corresponds to the JSON property type
2030 2031 2032 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2030 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2037 2038 2039 2040 2041 2042 2043 2044 2045 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2037 def update!(**args) @alt_text = args[:alt_text] if args.key?(:alt_text) @color = args[:color] if args.key?(:color) @disabled = args[:disabled] if args.key?(:disabled) @icon = args[:icon] if args.key?(:icon) @on_click = args[:on_click] if args.key?(:on_click) @text = args[:text] if args.key?(:text) @type = args[:type] if args.key?(:type) end |