Class: Google::Apis::ChatV1::GoogleAppsCardV1CardFixedFooter

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A persistent (sticky) footer that that appears at the bottom of the card. Setting fixedFooter without specifying a primaryButton or a secondaryButton causes an error. For Chat apps, you can use fixed footers in dialogs, but not card messages. For an example in Google Chat apps, see Add a persistent footer. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1CardFixedFooter

Returns a new instance of GoogleAppsCardV1CardFixedFooter.



2003
2004
2005
# File 'lib/google/apis/chat_v1/classes.rb', line 2003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#primary_buttonGoogle::Apis::ChatV1::GoogleAppsCardV1Button

A text, icon, or text and icon button that users can click. For an example in Google Chat apps, see Add a button. To make an image a clickable button, specify an Image (not an ImageComponent) and set an onClick action. Google Workspace add-ons and Chat apps: Corresponds to the JSON property primaryButton



1991
1992
1993
# File 'lib/google/apis/chat_v1/classes.rb', line 1991

def primary_button
  @primary_button
end

#secondary_buttonGoogle::Apis::ChatV1::GoogleAppsCardV1Button

A text, icon, or text and icon button that users can click. For an example in Google Chat apps, see Add a button. To make an image a clickable button, specify an Image (not an ImageComponent) and set an onClick action. Google Workspace add-ons and Chat apps: Corresponds to the JSON property secondaryButton



2001
2002
2003
# File 'lib/google/apis/chat_v1/classes.rb', line 2001

def secondary_button
  @secondary_button
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2008
2009
2010
2011
# File 'lib/google/apis/chat_v1/classes.rb', line 2008

def update!(**args)
  @primary_button = args[:primary_button] if args.key?(:primary_button)
  @secondary_button = args[:secondary_button] if args.key?(:secondary_button)
end