Class: Google::Apis::ChatV1::GoogleAppsCardV1Carousel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A carousel, also known as a slider, rotates and displays a list of widgets in a slideshow format, with buttons navigating to the previous or next widget. For example, this is a JSON representation of a carousel that contains three text paragraph widgets. ` "carouselCards": [ ` "widgets": [ ` " textParagraph": ` "text": "First text paragraph in carousel", ` ` ] `, ` " widgets": [ ` "textParagraph": ` "text": "Second text paragraph in carousel", ` ` ] `, ` "widgets": [ ` "textParagraph": ` "text": "Third text paragraph in carousel", ` ` ] ` ] ` Google Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1Carousel

Returns a new instance of GoogleAppsCardV1Carousel.



2147
2148
2149
# File 'lib/google/apis/chat_v1/classes.rb', line 2147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

A list of cards included in the carousel. Corresponds to the JSON property carouselCards



2145
2146
2147
# File 'lib/google/apis/chat_v1/classes.rb', line 2145

def carousel_cards
  @carousel_cards
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2152
2153
2154
# File 'lib/google/apis/chat_v1/classes.rb', line 2152

def update!(**args)
  @carousel_cards = args[:carousel_cards] if args.key?(:carousel_cards)
end