Class: Google::Apis::ChatV1::GoogleAppsCardV1CarouselCard
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1CarouselCard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A card that can be displayed as a carousel item. Google Chat apps:
Instance Attribute Summary collapse
-
#footer_widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed at the bottom of the carousel card.
-
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed in the carousel card.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1CarouselCard
constructor
A new instance of GoogleAppsCardV1CarouselCard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1CarouselCard
Returns a new instance of GoogleAppsCardV1CarouselCard.
2359 2360 2361 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#footer_widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed at the bottom of the carousel card. The widgets
are displayed in the order that they are specified.
Corresponds to the JSON property footerWidgets
2351 2352 2353 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2351 def @footer_widgets end |
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed in the carousel card. The widgets are displayed in
the order that they are specified.
Corresponds to the JSON property widgets
2357 2358 2359 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2357 def @widgets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2364 2365 2366 2367 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2364 def update!(**args) @footer_widgets = args[:footer_widgets] if args.key?(:footer_widgets) @widgets = args[:widgets] if args.key?(:widgets) end |