Class: Google::Apis::ChatV1::GoogleAppsCardV1ChipList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A list of chips layed out horizontally, which can either scroll horizontally or wrap to the next line. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1ChipList

Returns a new instance of GoogleAppsCardV1ChipList.



2200
2201
2202
# File 'lib/google/apis/chat_v1/classes.rb', line 2200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chipsArray<Google::Apis::ChatV1::GoogleAppsCardV1Chip>

An array of chips. Corresponds to the JSON property chips



2193
2194
2195
# File 'lib/google/apis/chat_v1/classes.rb', line 2193

def chips
  @chips
end

#layoutString

Specified chip list layout. Corresponds to the JSON property layout

Returns:

  • (String)


2198
2199
2200
# File 'lib/google/apis/chat_v1/classes.rb', line 2198

def layout
  @layout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2205
2206
2207
2208
# File 'lib/google/apis/chat_v1/classes.rb', line 2205

def update!(**args)
  @chips = args[:chips] if args.key?(:chips)
  @layout = args[:layout] if args.key?(:layout)
end