Class: Google::Apis::ChatV1::GoogleAppsCardV1CollapseControl
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1CollapseControl
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Represent an expand and collapse control. Google Workspace add-ons and Chat apps:
Instance Attribute Summary collapse
-
#collapse_button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click.
-
#expand_button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click.
-
#horizontal_alignment ⇒ String
The horizontal alignment of the expand and collapse button.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1CollapseControl
constructor
A new instance of GoogleAppsCardV1CollapseControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1CollapseControl
Returns a new instance of GoogleAppsCardV1CollapseControl.
2412 2413 2414 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collapse_button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click. For an example in
Google Chat apps, see Add a button. To make an image a
clickable button, specify an Image (not an ImageComponent) and set an
onClick action. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property collapseButton
2395 2396 2397 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2395 def @collapse_button end |
#expand_button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click. For an example in
Google Chat apps, see Add a button. To make an image a
clickable button, specify an Image (not an ImageComponent) and set an
onClick action. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property expandButton
2405 2406 2407 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2405 def @expand_button end |
#horizontal_alignment ⇒ String
The horizontal alignment of the expand and collapse button.
Corresponds to the JSON property horizontalAlignment
2410 2411 2412 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2410 def horizontal_alignment @horizontal_alignment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2417 2418 2419 2420 2421 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2417 def update!(**args) @collapse_button = args[:collapse_button] if args.key?(:collapse_button) @expand_button = args[:expand_button] if args.key?(:expand_button) @horizontal_alignment = args[:horizontal_alignment] if args.key?(:horizontal_alignment) end |