Class: Google::Apis::ChatV1::GoogleAppsCardV1Column

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1Column

Returns a new instance of GoogleAppsCardV1Column.



2345
2346
2347
# File 'lib/google/apis/chat_v1/classes.rb', line 2345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#horizontal_alignmentString

Specifies whether widgets align to the left, right, or center of a column. Corresponds to the JSON property horizontalAlignment

Returns:

  • (String)


2327
2328
2329
# File 'lib/google/apis/chat_v1/classes.rb', line 2327

def horizontal_alignment
  @horizontal_alignment
end

#horizontal_size_styleString

Specifies how a column fills the width of the card. Corresponds to the JSON property horizontalSizeStyle

Returns:

  • (String)


2332
2333
2334
# File 'lib/google/apis/chat_v1/classes.rb', line 2332

def horizontal_size_style
  @horizontal_size_style
end

#vertical_alignmentString

Specifies whether widgets align to the top, bottom, or center of a column. Corresponds to the JSON property verticalAlignment

Returns:

  • (String)


2337
2338
2339
# File 'lib/google/apis/chat_v1/classes.rb', line 2337

def vertical_alignment
  @vertical_alignment
end

#widgetsArray<Google::Apis::ChatV1::GoogleAppsCardV1Widgets>

An array of widgets included in a column. Widgets appear in the order that they are specified. Corresponds to the JSON property widgets



2343
2344
2345
# File 'lib/google/apis/chat_v1/classes.rb', line 2343

def widgets
  @widgets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2350
2351
2352
2353
2354
2355
# File 'lib/google/apis/chat_v1/classes.rb', line 2350

def update!(**args)
  @horizontal_alignment = args[:horizontal_alignment] if args.key?(:horizontal_alignment)
  @horizontal_size_style = args[:horizontal_size_style] if args.key?(:horizontal_size_style)
  @vertical_alignment = args[:vertical_alignment] if args.key?(:vertical_alignment)
  @widgets = args[:widgets] if args.key?(:widgets)
end