Class: Google::Apis::ChatV1::GoogleAppsCardV1DecoratedText

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A widget that displays text with optional decorations such as a label above or below the text, an icon in front of the text, a selection widget, or a button after the text. For an example in Google Chat apps, see Display text with decorative text. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1DecoratedText

Returns a new instance of GoogleAppsCardV1DecoratedText.



2893
2894
2895
# File 'lib/google/apis/chat_v1/classes.rb', line 2893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bottom_labelString

The text that appears below text. Always wraps. Corresponds to the JSON property bottomLabel

Returns:

  • (String)


2766
2767
2768
# File 'lib/google/apis/chat_v1/classes.rb', line 2766

def bottom_label
  @bottom_label
end

#bottom_label_textGoogle::Apis::ChatV1::GoogleAppsCardV1TextParagraph

A paragraph of text that supports formatting. For an example in Google Chat apps, see Add a paragraph of formatted text. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property bottomLabelText



2779
2780
2781
# File 'lib/google/apis/chat_v1/classes.rb', line 2779

def bottom_label_text
  @bottom_label_text
end

#buttonGoogle::Apis::ChatV1::GoogleAppsCardV1Button

A text, icon, or text and icon button that users can click. For an example in Google Chat apps, see Add a button. To make an image a clickable button, specify an Image (not an ImageComponent) and set an onClick action. Google Workspace add-ons and Chat apps: Corresponds to the JSON property button



2789
2790
2791
# File 'lib/google/apis/chat_v1/classes.rb', line 2789

def button
  @button
end

#content_textGoogle::Apis::ChatV1::GoogleAppsCardV1TextParagraph

A paragraph of text that supports formatting. For an example in Google Chat apps, see Add a paragraph of formatted text. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property contentText



2802
2803
2804
# File 'lib/google/apis/chat_v1/classes.rb', line 2802

def content_text
  @content_text
end

#end_iconGoogle::Apis::ChatV1::GoogleAppsCardV1Icon

An icon displayed in a widget on a card. For an example in Google Chat apps, see Add an icon. Supports built-in and custom icons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property endIcon



2813
2814
2815
# File 'lib/google/apis/chat_v1/classes.rb', line 2813

def end_icon
  @end_icon
end

#iconGoogle::Apis::ChatV1::GoogleAppsCardV1Icon

An icon displayed in a widget on a card. For an example in Google Chat apps, see Add an icon. Supports built-in and custom icons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property icon



2824
2825
2826
# File 'lib/google/apis/chat_v1/classes.rb', line 2824

def icon
  @icon
end

#on_clickGoogle::Apis::ChatV1::GoogleAppsCardV1OnClick

Represents how to respond when users click an interactive element on a card, such as a button. Google Workspace add-ons and Chat apps: Corresponds to the JSON property onClick



2831
2832
2833
# File 'lib/google/apis/chat_v1/classes.rb', line 2831

def on_click
  @on_click
end

#start_iconGoogle::Apis::ChatV1::GoogleAppsCardV1Icon

An icon displayed in a widget on a card. For an example in Google Chat apps, see Add an icon. Supports built-in and custom icons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property startIcon



2842
2843
2844
# File 'lib/google/apis/chat_v1/classes.rb', line 2842

def start_icon
  @start_icon
end

#start_icon_vertical_alignmentString

Optional. Vertical alignment of the start icon. If not set, the icon will be vertically centered. Google Chat apps: Corresponds to the JSON property startIconVerticalAlignment

Returns:

  • (String)


2849
2850
2851
# File 'lib/google/apis/chat_v1/classes.rb', line 2849

def start_icon_vertical_alignment
  @start_icon_vertical_alignment
end

#switch_controlGoogle::Apis::ChatV1::GoogleAppsCardV1SwitchControl

Either a toggle-style switch or a checkbox inside a decoratedText widget. Google Workspace add-ons and Chat apps: Only supported in the decoratedText widget. Corresponds to the JSON property switchControl



2856
2857
2858
# File 'lib/google/apis/chat_v1/classes.rb', line 2856

def switch_control
  @switch_control
end

#textString

Required. The primary text. Supports simple formatting. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Corresponds to the JSON property text

Returns:

  • (String)


2865
2866
2867
# File 'lib/google/apis/chat_v1/classes.rb', line 2865

def text
  @text
end

#top_labelString

The text that appears above text. Always truncates. Corresponds to the JSON property topLabel

Returns:

  • (String)


2870
2871
2872
# File 'lib/google/apis/chat_v1/classes.rb', line 2870

def top_label
  @top_label
end

#top_label_textGoogle::Apis::ChatV1::GoogleAppsCardV1TextParagraph

A paragraph of text that supports formatting. For an example in Google Chat apps, see Add a paragraph of formatted text. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property topLabelText



2883
2884
2885
# File 'lib/google/apis/chat_v1/classes.rb', line 2883

def top_label_text
  @top_label_text
end

#wrap_textBoolean Also known as: wrap_text?

The wrap text setting. If true, the text wraps and displays on multiple lines. Otherwise, the text is truncated. Only applies to text, not topLabel and bottomLabel. Corresponds to the JSON property wrapText

Returns:

  • (Boolean)


2890
2891
2892
# File 'lib/google/apis/chat_v1/classes.rb', line 2890

def wrap_text
  @wrap_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
# File 'lib/google/apis/chat_v1/classes.rb', line 2898

def update!(**args)
  @bottom_label = args[:bottom_label] if args.key?(:bottom_label)
  @bottom_label_text = args[:bottom_label_text] if args.key?(:bottom_label_text)
  @button = args[:button] if args.key?(:button)
  @content_text = args[:content_text] if args.key?(:content_text)
  @end_icon = args[:end_icon] if args.key?(:end_icon)
  @icon = args[:icon] if args.key?(:icon)
  @on_click = args[:on_click] if args.key?(:on_click)
  @start_icon = args[:start_icon] if args.key?(:start_icon)
  @start_icon_vertical_alignment = args[:start_icon_vertical_alignment] if args.key?(:start_icon_vertical_alignment)
  @switch_control = args[:switch_control] if args.key?(:switch_control)
  @text = args[:text] if args.key?(:text)
  @top_label = args[:top_label] if args.key?(:top_label)
  @top_label_text = args[:top_label_text] if args.key?(:top_label_text)
  @wrap_text = args[:wrap_text] if args.key?(:wrap_text)
end