Class: Google::Apis::ChatV1::GoogleAppsCardV1EventAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents an actionthat can be performed on an ui element. Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1EventAction

Returns a new instance of GoogleAppsCardV1EventAction.



2699
2700
2701
# File 'lib/google/apis/chat_v1/classes.rb', line 2699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_rule_idString

The unique identifier of the ActionRule. Corresponds to the JSON property actionRuleId

Returns:

  • (String)


2685
2686
2687
# File 'lib/google/apis/chat_v1/classes.rb', line 2685

def action_rule_id
  @action_rule_id
end

#common_widget_actionGoogle::Apis::ChatV1::GoogleAppsCardV1CommonWidgetAction

Represents an action that is not specific to a widget. Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps. Corresponds to the JSON property commonWidgetAction



2692
2693
2694
# File 'lib/google/apis/chat_v1/classes.rb', line 2692

def common_widget_action
  @common_widget_action
end

#post_event_triggersArray<Google::Apis::ChatV1::GoogleAppsCardV1Trigger>

The list of triggers that will be triggered after the EventAction is executed. Corresponds to the JSON property postEventTriggers



2697
2698
2699
# File 'lib/google/apis/chat_v1/classes.rb', line 2697

def post_event_triggers
  @post_event_triggers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2704
2705
2706
2707
2708
# File 'lib/google/apis/chat_v1/classes.rb', line 2704

def update!(**args)
  @action_rule_id = args[:action_rule_id] if args.key?(:action_rule_id)
  @common_widget_action = args[:common_widget_action] if args.key?(:common_widget_action)
  @post_event_triggers = args[:post_event_triggers] if args.key?(:post_event_triggers)
end