Class: Google::Apis::ChatV1::GoogleAppsCardV1ExpressionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents the data that is used to evaluate an expression. Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1ExpressionData

Returns a new instance of GoogleAppsCardV1ExpressionData.



2995
2996
2997
# File 'lib/google/apis/chat_v1/classes.rb', line 2995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsArray<Google::Apis::ChatV1::GoogleAppsCardV1Condition>

The list of conditions that are determined by the expression evaluation result. Corresponds to the JSON property conditions



2978
2979
2980
# File 'lib/google/apis/chat_v1/classes.rb', line 2978

def conditions
  @conditions
end

#event_actionsArray<Google::Apis::ChatV1::GoogleAppsCardV1EventAction>

The list of actions that the ExpressionData can be used. Corresponds to the JSON property eventActions



2983
2984
2985
# File 'lib/google/apis/chat_v1/classes.rb', line 2983

def event_actions
  @event_actions
end

#expressionString

The uncompiled expression. Corresponds to the JSON property expression

Returns:

  • (String)


2988
2989
2990
# File 'lib/google/apis/chat_v1/classes.rb', line 2988

def expression
  @expression
end

#idString

The unique identifier of the ExpressionData. Corresponds to the JSON property id

Returns:

  • (String)


2993
2994
2995
# File 'lib/google/apis/chat_v1/classes.rb', line 2993

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3000
3001
3002
3003
3004
3005
# File 'lib/google/apis/chat_v1/classes.rb', line 3000

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @event_actions = args[:event_actions] if args.key?(:event_actions)
  @expression = args[:expression] if args.key?(:expression)
  @id = args[:id] if args.key?(:id)
end