Class: Google::Apis::ChatV1::GoogleAppsCardV1Image
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1Image
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
An image that is specified by a URL and can have an onClick action. For an
example, see Add an image. Google Workspace add-ons and Chat apps:
Instance Attribute Summary collapse
-
#alt_text ⇒ String
The alternative text of this image that's used for accessibility.
-
#image_url ⇒ String
The HTTPS URL that hosts the image.
-
#on_click ⇒ Google::Apis::ChatV1::GoogleAppsCardV1OnClick
Represents how to respond when users click an interactive element on a card, such as a button.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1Image
constructor
A new instance of GoogleAppsCardV1Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1Image
Returns a new instance of GoogleAppsCardV1Image.
3151 3152 3153 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alt_text ⇒ String
The alternative text of this image that's used for accessibility.
Corresponds to the JSON property altText
3136 3137 3138 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3136 def alt_text @alt_text end |
#image_url ⇒ String
The HTTPS URL that hosts the image. For example: https://developers.google.
com/workspace/chat/images/quickstart-app-avatar.png
Corresponds to the JSON property imageUrl
3142 3143 3144 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3142 def image_url @image_url end |
#on_click ⇒ Google::Apis::ChatV1::GoogleAppsCardV1OnClick
Represents how to respond when users click an interactive element on a card,
such as a button. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property onClick
3149 3150 3151 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3149 def on_click @on_click end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3156 3157 3158 3159 3160 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3156 def update!(**args) @alt_text = args[:alt_text] if args.key?(:alt_text) @image_url = args[:image_url] if args.key?(:image_url) @on_click = args[:on_click] if args.key?(:on_click) end |