Class: Google::Apis::ChatV1::GoogleAppsCardV1ImageComponent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1ImageComponent

Returns a new instance of GoogleAppsCardV1ImageComponent.



3015
3016
3017
# File 'lib/google/apis/chat_v1/classes.rb', line 3015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alt_textString

The accessibility label for the image. Corresponds to the JSON property altText

Returns:

  • (String)


2993
2994
2995
# File 'lib/google/apis/chat_v1/classes.rb', line 2993

def alt_text
  @alt_text
end

#border_styleGoogle::Apis::ChatV1::GoogleAppsCardV1BorderStyle

The style options for the border of a card or widget, including the border type and color. Google Workspace add-ons and Chat apps: Corresponds to the JSON property borderStyle



3000
3001
3002
# File 'lib/google/apis/chat_v1/classes.rb', line 3000

def border_style
  @border_style
end

#crop_styleGoogle::Apis::ChatV1::GoogleAppsCardV1ImageCropStyle

Represents the crop style applied to an image. Google Workspace add-ons and Chat apps: For example, here' s how to apply a 16:9 aspect ratio: cropStyle ` "type": "RECTANGLE_CUSTOM", "aspectRatio": 16/9 ` Corresponds to the JSON property cropStyle



3008
3009
3010
# File 'lib/google/apis/chat_v1/classes.rb', line 3008

def crop_style
  @crop_style
end

#image_uriString

The image URL. Corresponds to the JSON property imageUri

Returns:

  • (String)


3013
3014
3015
# File 'lib/google/apis/chat_v1/classes.rb', line 3013

def image_uri
  @image_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3020
3021
3022
3023
3024
3025
# File 'lib/google/apis/chat_v1/classes.rb', line 3020

def update!(**args)
  @alt_text = args[:alt_text] if args.key?(:alt_text)
  @border_style = args[:border_style] if args.key?(:border_style)
  @crop_style = args[:crop_style] if args.key?(:crop_style)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
end