Class: Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A list of widgets that can be displayed in a containing layout, such as a CarouselCard. Google Chat apps :

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1NestedWidget

Returns a new instance of GoogleAppsCardV1NestedWidget.



3221
3222
3223
# File 'lib/google/apis/chat_v1/classes.rb', line 3221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#button_listGoogle::Apis::ChatV1::GoogleAppsCardV1ButtonList

A list of buttons layed out horizontally. For an example in Google Chat apps, see Add a button. Google Workspace add-ons and Chat apps: Corresponds to the JSON property buttonList



3198
3199
3200
# File 'lib/google/apis/chat_v1/classes.rb', line 3198

def button_list
  @button_list
end

#imageGoogle::Apis::ChatV1::GoogleAppsCardV1Image

An image that is specified by a URL and can have an onClick action. For an example, see Add an image. Google Workspace add-ons and Chat apps: Corresponds to the JSON property image



3206
3207
3208
# File 'lib/google/apis/chat_v1/classes.rb', line 3206

def image
  @image
end

#text_paragraphGoogle::Apis::ChatV1::GoogleAppsCardV1TextParagraph

A paragraph of text that supports formatting. For an example in Google Chat apps, see Add a paragraph of formatted text. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property textParagraph



3219
3220
3221
# File 'lib/google/apis/chat_v1/classes.rb', line 3219

def text_paragraph
  @text_paragraph
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3226
3227
3228
3229
3230
# File 'lib/google/apis/chat_v1/classes.rb', line 3226

def update!(**args)
  @button_list = args[:button_list] if args.key?(:button_list)
  @image = args[:image] if args.key?(:image)
  @text_paragraph = args[:text_paragraph] if args.key?(:text_paragraph)
end