Class: Google::Apis::ChatV1::GoogleAppsCardV1OverflowMenuItem

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

An option that users can invoke in an overflow menu. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1OverflowMenuItem

Returns a new instance of GoogleAppsCardV1OverflowMenuItem.



3336
3337
3338
# File 'lib/google/apis/chat_v1/classes.rb', line 3336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabledBoolean Also known as: disabled?

Whether the menu option is disabled. Defaults to false. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


3310
3311
3312
# File 'lib/google/apis/chat_v1/classes.rb', line 3310

def disabled
  @disabled
end

#on_clickGoogle::Apis::ChatV1::GoogleAppsCardV1OnClick

Represents how to respond when users click an interactive element on a card, such as a button. Google Workspace add-ons and Chat apps: Corresponds to the JSON property onClick



3318
3319
3320
# File 'lib/google/apis/chat_v1/classes.rb', line 3318

def on_click
  @on_click
end

#start_iconGoogle::Apis::ChatV1::GoogleAppsCardV1Icon

An icon displayed in a widget on a card. For an example in Google Chat apps, see Add an icon. Supports built-in and custom icons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property startIcon



3329
3330
3331
# File 'lib/google/apis/chat_v1/classes.rb', line 3329

def start_icon
  @start_icon
end

#textString

Required. The text that identifies or describes the item to users. Corresponds to the JSON property text

Returns:

  • (String)


3334
3335
3336
# File 'lib/google/apis/chat_v1/classes.rb', line 3334

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3341
3342
3343
3344
3345
3346
# File 'lib/google/apis/chat_v1/classes.rb', line 3341

def update!(**args)
  @disabled = args[:disabled] if args.key?(:disabled)
  @on_click = args[:on_click] if args.key?(:on_click)
  @start_icon = args[:start_icon] if args.key?(:start_icon)
  @text = args[:text] if args.key?(:text)
end