Class: Google::Apis::ChatV1::GoogleAppsCardV1PlatformDataSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

For a SelectionInput widget that uses a multiselect menu, a data source from Google Workspace. Used to populate items in a multiselect menu. Google Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1PlatformDataSource

Returns a new instance of GoogleAppsCardV1PlatformDataSource.



3546
3547
3548
# File 'lib/google/apis/chat_v1/classes.rb', line 3546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_data_sourceString

A data source shared by all Google Workspace applications, such as users in a Google Workspace organization. Corresponds to the JSON property commonDataSource

Returns:

  • (String)


3538
3539
3540
# File 'lib/google/apis/chat_v1/classes.rb', line 3538

def common_data_source
  @common_data_source
end

#host_app_data_sourceGoogle::Apis::ChatV1::HostAppDataSourceMarkup

A data source from a Google Workspace application. The data source populates available items for a widget. Corresponds to the JSON property hostAppDataSource



3544
3545
3546
# File 'lib/google/apis/chat_v1/classes.rb', line 3544

def host_app_data_source
  @host_app_data_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3551
3552
3553
3554
# File 'lib/google/apis/chat_v1/classes.rb', line 3551

def update!(**args)
  @common_data_source = args[:common_data_source] if args.key?(:common_data_source)
  @host_app_data_source = args[:host_app_data_source] if args.key?(:host_app_data_source)
end