Class: Google::Apis::ChatV1::GoogleAppsCardV1Section
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1Section
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A section contains a collection of widgets that are rendered vertically in the order that they're specified. Google Workspace add-ons and Chat apps:
Instance Attribute Summary collapse
-
#collapse_control ⇒ Google::Apis::ChatV1::GoogleAppsCardV1CollapseControl
Represent an expand and collapse control.
-
#collapsible ⇒ Boolean
(also: #collapsible?)
Indicates whether this section is collapsible.
-
#header ⇒ String
Text that appears at the top of a section.
-
#id ⇒ String
A unique ID assigned to the section that's used to identify the section to be mutated.
-
#uncollapsible_widgets_count ⇒ Fixnum
The number of uncollapsible widgets which remain visible even when a section is collapsed.
-
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1Widget>
All the widgets in the section.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1Section
constructor
A new instance of GoogleAppsCardV1Section.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1Section
Returns a new instance of GoogleAppsCardV1Section.
3691 3692 3693 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collapse_control ⇒ Google::Apis::ChatV1::GoogleAppsCardV1CollapseControl
Represent an expand and collapse control. Google Workspace add-ons and Chat
apps:
Corresponds to the JSON property collapseControl
3647 3648 3649 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3647 def collapse_control @collapse_control end |
#collapsible ⇒ Boolean Also known as: collapsible?
Indicates whether this section is collapsible. Collapsible sections hide some
or all widgets, but users can expand the section to reveal the hidden widgets
by clicking Show more. Users can hide the widgets again by clicking Show
less. To determine which widgets are hidden, specify
uncollapsibleWidgetsCount.
Corresponds to the JSON property collapsible
3656 3657 3658 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3656 def collapsible @collapsible end |
#header ⇒ String
Text that appears at the top of a section. Supports simple HTML formatted text.
For more information about formatting text, see Formatting text in Google
Chat apps and Formatting text in Google Workspace add-ons.
Corresponds to the JSON property header
3666 3667 3668 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3666 def header @header end |
#id ⇒ String
A unique ID assigned to the section that's used to identify the section to be
mutated. The ID has a character limit of 64 characters and should be in the
format of [a-zA-Z0-9-]+. Available for Google Workspace add-ons that extend
Google Workspace Studio. Unavailable for Google Chat apps.
Corresponds to the JSON property id
3674 3675 3676 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3674 def id @id end |
#uncollapsible_widgets_count ⇒ Fixnum
The number of uncollapsible widgets which remain visible even when a section
is collapsed. For example, when a section contains five widgets and the
uncollapsibleWidgetsCount is set to 2, the first two widgets are always
shown and the last three are collapsed by default. The
uncollapsibleWidgetsCount is taken into account only when collapsible is
true.
Corresponds to the JSON property uncollapsibleWidgetsCount
3684 3685 3686 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3684 def @uncollapsible_widgets_count end |
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1Widget>
All the widgets in the section. Must contain at least one widget.
Corresponds to the JSON property widgets
3689 3690 3691 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3689 def @widgets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3696 3697 3698 3699 3700 3701 3702 3703 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3696 def update!(**args) @collapse_control = args[:collapse_control] if args.key?(:collapse_control) @collapsible = args[:collapsible] if args.key?(:collapsible) @header = args[:header] if args.key?(:header) @id = args[:id] if args.key?(:id) @uncollapsible_widgets_count = args[:uncollapsible_widgets_count] if args.key?(:uncollapsible_widgets_count) @widgets = args[:widgets] if args.key?(:widgets) end |