Class: Google::Apis::ChatV1::GoogleAppsCardV1Suggestions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Suggested values that users can enter. These values appear when users click inside the text input field. As users type, the suggested values dynamically filter to match what the users have typed. For example, a text input field for programming language might suggest Java, JavaScript, Python, and C++. When users start typing Jav, the list of suggestions filters to show Java and JavaScript. Suggested values help guide users to enter values that your app can make sense of. When referring to JavaScript, some users might enter javascript and others java script. Suggesting JavaScript can standardize how users interact with your app. When specified, TextInput.type is always SINGLE_LINE, even if it's set to MULTIPLE_LINE. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1Suggestions

Returns a new instance of GoogleAppsCardV1Suggestions.



3844
3845
3846
# File 'lib/google/apis/chat_v1/classes.rb', line 3844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ChatV1::GoogleAppsCardV1SuggestionItem>

A list of suggestions used for autocomplete recommendations in text input fields. Corresponds to the JSON property items



3842
3843
3844
# File 'lib/google/apis/chat_v1/classes.rb', line 3842

def items
  @items
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3849
3850
3851
# File 'lib/google/apis/chat_v1/classes.rb', line 3849

def update!(**args)
  @items = args[:items] if args.key?(:items)
end