Class: Google::Apis::ChatV1::GoogleAppsCardV1SwitchControl

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Either a toggle-style switch or a checkbox inside a decoratedText widget. Google Workspace add-ons and Chat apps: Only supported in the decoratedText widget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1SwitchControl

Returns a new instance of GoogleAppsCardV1SwitchControl.



3974
3975
3976
# File 'lib/google/apis/chat_v1/classes.rb', line 3974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#control_typeString

How the switch appears in the user interface. Google Workspace add-ons and Chat apps: Corresponds to the JSON property controlType

Returns:

  • (String)


3944
3945
3946
# File 'lib/google/apis/chat_v1/classes.rb', line 3944

def control_type
  @control_type
end

#nameString

The name by which the switch widget is identified in a form input event. For details about working with form inputs, see Receive form data. Corresponds to the JSON property name

Returns:

  • (String)


3951
3952
3953
# File 'lib/google/apis/chat_v1/classes.rb', line 3951

def name
  @name
end

#on_change_actionGoogle::Apis::ChatV1::GoogleAppsCardV1Action

An action that describes the behavior when the form is submitted. For example, you can invoke an Apps Script script to handle the form. If the action is triggered, the form values are sent to the server. Google Workspace add-ons and Chat apps: Corresponds to the JSON property onChangeAction



3959
3960
3961
# File 'lib/google/apis/chat_v1/classes.rb', line 3959

def on_change_action
  @on_change_action
end

#selectedBoolean Also known as: selected?

When true, the switch is selected. Corresponds to the JSON property selected

Returns:

  • (Boolean)


3964
3965
3966
# File 'lib/google/apis/chat_v1/classes.rb', line 3964

def selected
  @selected
end

#valueString

The value entered by a user, returned as part of a form input event. For details about working with form inputs, see Receive form data. Corresponds to the JSON property value

Returns:

  • (String)


3972
3973
3974
# File 'lib/google/apis/chat_v1/classes.rb', line 3972

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3979
3980
3981
3982
3983
3984
3985
# File 'lib/google/apis/chat_v1/classes.rb', line 3979

def update!(**args)
  @control_type = args[:control_type] if args.key?(:control_type)
  @name = args[:name] if args.key?(:name)
  @on_change_action = args[:on_change_action] if args.key?(:on_change_action)
  @selected = args[:selected] if args.key?(:selected)
  @value = args[:value] if args.key?(:value)
end