Class: Google::Apis::ChatV1::GoogleAppsCardV1Widgets
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1Widgets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
The supported widgets that you can include in a column. Google Workspace add- ons and Chat apps
Instance Attribute Summary collapse
-
#button_list ⇒ Google::Apis::ChatV1::GoogleAppsCardV1ButtonList
A list of buttons layed out horizontally.
-
#chip_list ⇒ Google::Apis::ChatV1::GoogleAppsCardV1ChipList
A list of chips layed out horizontally, which can either scroll horizontally or wrap to the next line.
-
#date_time_picker ⇒ Google::Apis::ChatV1::GoogleAppsCardV1DateTimePicker
Lets users input a date, a time, or both a date and a time.
-
#decorated_text ⇒ Google::Apis::ChatV1::GoogleAppsCardV1DecoratedText
A widget that displays text with optional decorations such as a label above or below the text, an icon in front of the text, a selection widget, or a button after the text.
-
#image ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Image
An image that is specified by a URL and can have an
onClickaction. -
#selection_input ⇒ Google::Apis::ChatV1::GoogleAppsCardV1SelectionInput
A widget that creates one or more UI items that users can select.
-
#text_input ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextInput
A field in which users can enter text.
-
#text_paragraph ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1Widgets
constructor
A new instance of GoogleAppsCardV1Widgets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1Widgets
Returns a new instance of GoogleAppsCardV1Widgets.
4544 4545 4546 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#button_list ⇒ Google::Apis::ChatV1::GoogleAppsCardV1ButtonList
A list of buttons layed out horizontally. For an example in Google Chat apps,
see Add a button. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property buttonList
4456 4457 4458 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4456 def @button_list end |
#chip_list ⇒ Google::Apis::ChatV1::GoogleAppsCardV1ChipList
A list of chips layed out horizontally, which can either scroll horizontally
or wrap to the next line. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property chipList
4463 4464 4465 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4463 def chip_list @chip_list end |
#date_time_picker ⇒ Google::Apis::ChatV1::GoogleAppsCardV1DateTimePicker
Lets users input a date, a time, or both a date and a time. Supports form
submission validation. When Action.all_widgets_are_required is set to true
or this widget is specified in Action.required_widgets, the submission
action is blocked unless a value is selected. For an example in Google Chat
apps, see Let a user pick a date and time.
Users can input text or use the picker to select dates and times. If users
input an invalid date or time, the picker shows an error that prompts users to
input the information correctly. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property dateTimePicker
4477 4478 4479 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4477 def date_time_picker @date_time_picker end |
#decorated_text ⇒ Google::Apis::ChatV1::GoogleAppsCardV1DecoratedText
A widget that displays text with optional decorations such as a label above or
below the text, an icon in front of the text, a selection widget, or a button
after the text. For an example in Google Chat apps, see Display text with
decorative text. Google Workspace add-ons
and Chat apps:
Corresponds to the JSON property decoratedText
4487 4488 4489 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4487 def decorated_text @decorated_text end |
#image ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Image
An image that is specified by a URL and can have an onClick action. For an
example, see Add an image. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property image
4495 4496 4497 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4495 def image @image end |
#selection_input ⇒ Google::Apis::ChatV1::GoogleAppsCardV1SelectionInput
A widget that creates one or more UI items that users can select. Supports
form submission validation for dropdown and multiselect menus only. When
Action.all_widgets_are_required is set to true or this widget is specified
in Action.required_widgets, the submission action is blocked unless a value
is selected. For example, a dropdown menu or checkboxes. You can use this
widget to collect data that can be predicted or enumerated. For an example in
Google Chat apps, see Add selectable UI elements. Chat apps can process the
value of items that users select or input. For details about working with form
inputs, see Receive form data. To collect undefined or abstract data from users, use the
TextInput widget. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property selectionInput
4512 4513 4514 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4512 def selection_input @selection_input end |
#text_input ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextInput
A field in which users can enter text. Supports suggestions and on-change
actions. Supports form submission validation. When Action.
all_widgets_are_required is set to true or this widget is specified in
Action.required_widgets, the submission action is blocked unless a value is
entered. For an example in Google Chat apps, see Add a field in which a user
can enter text. Chat apps
receive and can process the value of entered text during form input events.
For details about working with form inputs, see Receive form data. When you need to collect
undefined or abstract data from users, use a text input. To collect defined or
enumerated data from users, use the SelectionInput widget. Google Workspace
add-ons and Chat apps:
Corresponds to the JSON property textInput
4529 4530 4531 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4529 def text_input @text_input end |
#text_paragraph ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting. For an example in Google Chat
apps, see Add a paragraph of formatted text.
For more information about formatting text, see Formatting text in Google
Chat apps and Formatting text in Google Workspace add-ons.
Google Workspace add-ons and Chat apps:
Corresponds to the JSON property textParagraph
4542 4543 4544 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4542 def text_paragraph @text_paragraph end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4549 4550 4551 4552 4553 4554 4555 4556 4557 4558 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4549 def update!(**args) @button_list = args[:button_list] if args.key?(:button_list) @chip_list = args[:chip_list] if args.key?(:chip_list) @date_time_picker = args[:date_time_picker] if args.key?(:date_time_picker) @decorated_text = args[:decorated_text] if args.key?(:decorated_text) @image = args[:image] if args.key?(:image) @selection_input = args[:selection_input] if args.key?(:selection_input) @text_input = args[:text_input] if args.key?(:text_input) @text_paragraph = args[:text_paragraph] if args.key?(:text_paragraph) end |