Class: Google::Apis::ChatV1::HostAppDataSourceMarkup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A data source from a Google Workspace application. The data source populates available items for a widget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostAppDataSourceMarkup

Returns a new instance of HostAppDataSourceMarkup.



4469
4470
4471
# File 'lib/google/apis/chat_v1/classes.rb', line 4469

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chat_data_sourceGoogle::Apis::ChatV1::ChatClientDataSourceMarkup

For a SelectionInput widget that uses a multiselect menu, a data source from Google Chat. The data source populates selection items for the multiselect menu. For example, a user can select Google Chat spaces that they're a member of. Google Chat apps: Corresponds to the JSON property chatDataSource



4460
4461
4462
# File 'lib/google/apis/chat_v1/classes.rb', line 4460

def chat_data_source
  @chat_data_source
end

#workflow_data_sourceGoogle::Apis::ChatV1::WorkflowDataSourceMarkup

  • Only supported by Google Workspace Workflow, but not Google Chat apps or Google Workspace add-ons. In a TextInput or SelectionInput widget with MULTI_SELECT type or a DateTimePicker, provide data source from Google. Corresponds to the JSON property workflowDataSource


4467
4468
4469
# File 'lib/google/apis/chat_v1/classes.rb', line 4467

def workflow_data_source
  @workflow_data_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4474
4475
4476
4477
# File 'lib/google/apis/chat_v1/classes.rb', line 4474

def update!(**args)
  @chat_data_source = args[:chat_data_source] if args.key?(:chat_data_source)
  @workflow_data_source = args[:workflow_data_source] if args.key?(:workflow_data_source)
end