Class: Google::Apis::ChatV1::MarkAsActiveRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Request message for the MarkAsActive method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MarkAsActiveRequest

Returns a new instance of MarkAsActiveRequest.



5082
5083
5084
# File 'lib/google/apis/chat_v1/classes.rb', line 5082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

The absolute timestamp when the ACTIVE state expires. Corresponds to the JSON property expireTime

Returns:

  • (String)


5073
5074
5075
# File 'lib/google/apis/chat_v1/classes.rb', line 5073

def expire_time
  @expire_time
end

#ttlString

The duration from the current time until the ACTIVE state expires. Using a short TTL can effectively reset the user's state to be based on activity after this brief duration. Corresponds to the JSON property ttl

Returns:

  • (String)


5080
5081
5082
# File 'lib/google/apis/chat_v1/classes.rb', line 5080

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5087
5088
5089
5090
# File 'lib/google/apis/chat_v1/classes.rb', line 5087

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @ttl = args[:ttl] if args.key?(:ttl)
end