Class: Google::Apis::ChatV1::MarkAsDoNotDisturbRequest
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::MarkAsDoNotDisturbRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Request message for the MarkAsDoNotDisturb method.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
The absolute timestamp when the DND state expires.
-
#ttl ⇒ String
The duration from the current time until the DND state expires.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MarkAsDoNotDisturbRequest
constructor
A new instance of MarkAsDoNotDisturbRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MarkAsDoNotDisturbRequest
Returns a new instance of MarkAsDoNotDisturbRequest.
5120 5121 5122 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
The absolute timestamp when the DND state expires.
Corresponds to the JSON property expireTime
5113 5114 5115 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5113 def expire_time @expire_time end |
#ttl ⇒ String
The duration from the current time until the DND state expires.
Corresponds to the JSON property ttl
5118 5119 5120 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5118 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5125 5126 5127 5128 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5125 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) @ttl = args[:ttl] if args.key?(:ttl) end |