Class: Google::Apis::ChatV1::MembershipUpdatedEventData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Event payload for an updated membership. Event type: google.workspace.chat. membership.v1.updated

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipUpdatedEventData

Returns a new instance of MembershipUpdatedEventData.



5158
5159
5160
# File 'lib/google/apis/chat_v1/classes.rb', line 5158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membershipGoogle::Apis::ChatV1::Membership

Represents a membership relation in Google Chat, such as whether a user or Chat app is invited to, part of, or absent from a space. Corresponds to the JSON property membership



5156
5157
5158
# File 'lib/google/apis/chat_v1/classes.rb', line 5156

def membership
  @membership
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5163
5164
5165
# File 'lib/google/apis/chat_v1/classes.rb', line 5163

def update!(**args)
  @membership = args[:membership] if args.key?(:membership)
end