Class: Google::Apis::ChatV1::Message

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A message in a Google Chat space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Message

Returns a new instance of Message.



5650
5651
5652
# File 'lib/google/apis/chat_v1/classes.rb', line 5650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessory_widgetsArray<Google::Apis::ChatV1::AccessoryWidget>

Optional. One or more interactive widgets that appear at the bottom of a message. You can add accessory widgets to messages that contain text, cards, or both text and cards. Not supported for messages that contain dialogs. For details, see Add interactive widgets at the bottom of a message. Creating a message with accessory widgets requires app authentication. Corresponds to the JSON property accessoryWidgets



5439
5440
5441
# File 'lib/google/apis/chat_v1/classes.rb', line 5439

def accessory_widgets
  @accessory_widgets
end

#action_responseGoogle::Apis::ChatV1::ActionResponse

Parameters that a Chat app can use to configure how its response is posted. Corresponds to the JSON property actionResponse



5444
5445
5446
# File 'lib/google/apis/chat_v1/classes.rb', line 5444

def action_response
  @action_response
end

#annotationsArray<Google::Apis::ChatV1::Annotation>

Output only. Annotations can be associated with the plain-text body of the message or with chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0. Corresponds to the JSON property annotations



5451
5452
5453
# File 'lib/google/apis/chat_v1/classes.rb', line 5451

def annotations
  @annotations
end

#argument_textString

Output only. Plain-text body of the message with all Chat app mentions stripped out. Corresponds to the JSON property argumentText

Returns:

  • (String)


5457
5458
5459
# File 'lib/google/apis/chat_v1/classes.rb', line 5457

def argument_text
  @argument_text
end

#attached_gifsArray<Google::Apis::ChatV1::AttachedGif>

Output only. GIF images that are attached to the message. Corresponds to the JSON property attachedGifs



5462
5463
5464
# File 'lib/google/apis/chat_v1/classes.rb', line 5462

def attached_gifs
  @attached_gifs
end

#attachmentArray<Google::Apis::ChatV1::Attachment>

Optional. User-uploaded attachment. Corresponds to the JSON property attachment



5467
5468
5469
# File 'lib/google/apis/chat_v1/classes.rb', line 5467

def attachment
  @attachment
end

#cardsArray<Google::Apis::ChatV1::Card>

Deprecated: Use cards_v2 instead. Rich, formatted, and interactive cards that you can use to display UI elements such as: formatted texts, buttons, and clickable images. Cards are normally displayed below the plain-text body of the message. cards and cards_v2 can have a maximum size of 32 KB. Corresponds to the JSON property cards

Returns:



5475
5476
5477
# File 'lib/google/apis/chat_v1/classes.rb', line 5475

def cards
  @cards
end

#cards_v2Array<Google::Apis::ChatV1::CardWithId>

Optional. An array of cards. Chat apps can create cards with app authentication. As part of the Developer Preview Program, if your Chat app authenticates as a user, it can create card messages. If your Chat app is not part of Developer Preview Program, it can't create cards with user authentication. To learn how to create a message that contains cards, see Send a message. Card builder Corresponds to the JSON property cardsV2



5490
5491
5492
# File 'lib/google/apis/chat_v1/classes.rb', line 5490

def cards_v2
  @cards_v2
end

#client_assigned_message_idString

Optional. A custom ID for the message. You can use field to identify a message, or to get, delete, or update a message. To set a custom ID, specify the messageId field when you create the message. For details, see Name a message. Corresponds to the JSON property clientAssignedMessageId

Returns:

  • (String)


5500
5501
5502
# File 'lib/google/apis/chat_v1/classes.rb', line 5500

def client_assigned_message_id
  @client_assigned_message_id
end

#create_timeString

Optional. Immutable. For spaces created in Chat, the time at which the message was created. This field is output only, except when used in import mode spaces. For import mode spaces, set this field to the historical timestamp at which the message was created in the source in order to preserve the original creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


5509
5510
5511
# File 'lib/google/apis/chat_v1/classes.rb', line 5509

def create_time
  @create_time
end

#delete_timeString

Output only. The time at which the message was deleted in Google Chat. If the message is never deleted, this field is empty. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5515
5516
5517
# File 'lib/google/apis/chat_v1/classes.rb', line 5515

def delete_time
  @delete_time
end

#deletion_metadataGoogle::Apis::ChatV1::DeletionMetadata

Information about a deleted message. A message is deleted when delete_time is set. Corresponds to the JSON property deletionMetadata



5521
5522
5523
# File 'lib/google/apis/chat_v1/classes.rb', line 5521

def 
  @deletion_metadata
end

#emoji_reaction_summariesArray<Google::Apis::ChatV1::EmojiReactionSummary>

Output only. The list of emoji reaction summaries on the message. Corresponds to the JSON property emojiReactionSummaries



5526
5527
5528
# File 'lib/google/apis/chat_v1/classes.rb', line 5526

def emoji_reaction_summaries
  @emoji_reaction_summaries
end

#fallback_textString

Optional. A plain-text description of the message's cards, used when the actual cards can't be displayed—for example, mobile notifications. Corresponds to the JSON property fallbackText

Returns:

  • (String)


5532
5533
5534
# File 'lib/google/apis/chat_v1/classes.rb', line 5532

def fallback_text
  @fallback_text
end

#formatted_textString

Output only. Contains the message text with markups added to communicate formatting. This field might not capture all formatting visible in the UI, but includes the following: * Markup syntax for bold, italic, strikethrough, monospace, monospace block, bulleted list, and block quote. * User mentions using the format . * Custom hyperlinks using the format `<`url`|`rendered_text`>` where the first string is the URL and the second is the rendered text—for example,. * Custom emoji using the format :emoji_name:—for example, : smile:. This doesn't apply to Unicode emoji, such as U+1F600 for a grinning face emoji. * Bullet list items using asterisks (*)—for example, * item. For more information, see View text formatting sent in a message Corresponds to the JSON property formattedText

Returns:

  • (String)


5550
5551
5552
# File 'lib/google/apis/chat_v1/classes.rb', line 5550

def formatted_text
  @formatted_text
end

#last_update_timeString

Output only. The time at which the message was last edited by a user. If the message has never been edited, this field is empty. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


5556
5557
5558
# File 'lib/google/apis/chat_v1/classes.rb', line 5556

def last_update_time
  @last_update_time
end

#matched_urlGoogle::Apis::ChatV1::MatchedUrl

A matched URL in a Chat message. Chat apps can preview matched URLs. For more information, see Preview links. Corresponds to the JSON property matchedUrl



5563
5564
5565
# File 'lib/google/apis/chat_v1/classes.rb', line 5563

def matched_url
  @matched_url
end

#nameString

Identifier. Resource name of the message. Format: spaces/space/messages/ messageWherespaceis the ID of the space where the message is posted andmessageis a system-assigned ID for the message. For example, `spaces/ AAAAAAAAAAA/messages/BBBBBBBBBBB.BBBBBBBBBBB`. If you set a custom ID when you create a message, you can use this ID to specify the message in a request by replacingmessage`with the value from theclientAssignedMessageIdfield. For example,spaces/AAAAAAAAAAA/messages/client-custom-name. For details, see [Name a message](https://developers.google.com/workspace/chat/create- messages#name_a_created_message). Corresponds to the JSON propertyname`

Returns:

  • (String)


5576
5577
5578
# File 'lib/google/apis/chat_v1/classes.rb', line 5576

def name
  @name
end

#private_message_viewerGoogle::Apis::ChatV1::User

A user in Google Chat. When returned as an output from a request, if your Chat app authenticates as a user, the output for a User resource only populates the user's name and type. Corresponds to the JSON property privateMessageViewer



5584
5585
5586
# File 'lib/google/apis/chat_v1/classes.rb', line 5584

def private_message_viewer
  @private_message_viewer
end

#quoted_message_metadataGoogle::Apis::ChatV1::QuotedMessageMetadata

Information about a message that another message quotes. When you update a message, you can't add or replace the quotedMessageMetadata field, but you can remove it. For example usage, see Quote another message. Corresponds to the JSON property quotedMessageMetadata



5592
5593
5594
# File 'lib/google/apis/chat_v1/classes.rb', line 5592

def 
  @quoted_message_metadata
end

#senderGoogle::Apis::ChatV1::User

A user in Google Chat. When returned as an output from a request, if your Chat app authenticates as a user, the output for a User resource only populates the user's name and type. Corresponds to the JSON property sender



5600
5601
5602
# File 'lib/google/apis/chat_v1/classes.rb', line 5600

def sender
  @sender
end

#silentBoolean Also known as: silent?

Output only. Whether this is a silent message. Silent messages are messages where Chat suppresses push notifications for recipients. Corresponds to the JSON property silent

Returns:

  • (Boolean)


5606
5607
5608
# File 'lib/google/apis/chat_v1/classes.rb', line 5606

def silent
  @silent
end

#slash_commandGoogle::Apis::ChatV1::SlashCommand

Metadata about a slash command in Google Chat. Corresponds to the JSON property slashCommand



5613
5614
5615
# File 'lib/google/apis/chat_v1/classes.rb', line 5613

def slash_command
  @slash_command
end

#spaceGoogle::Apis::ChatV1::Space

A space in Google Chat. Spaces are conversations between two or more users or 1:1 messages between a user and a Chat app. Corresponds to the JSON property space



5619
5620
5621
# File 'lib/google/apis/chat_v1/classes.rb', line 5619

def space
  @space
end

#textString

Optional. Plain-text body of the message. The first link to an image, video, or web page generates a preview chip. You can also @mention a Google Chat user, or everyone in the space. To learn about creating text messages, see Send a message. Corresponds to the JSON property text

Returns:

  • (String)


5629
5630
5631
# File 'lib/google/apis/chat_v1/classes.rb', line 5629

def text
  @text
end

#threadGoogle::Apis::ChatV1::Thread

A thread in a Google Chat space. For example usage, see Start or reply to a message thread. If you specify a thread when creating a message, you can set the messageReplyOption field to determine what happens if no matching thread is found. Corresponds to the JSON property thread



5639
5640
5641
# File 'lib/google/apis/chat_v1/classes.rb', line 5639

def thread
  @thread
end

#thread_replyBoolean Also known as: thread_reply?

Output only. When true, the message is a response in a reply thread. When false, the message is visible in the space's top-level conversation as either the first message of a thread or a message with no threaded replies. If the space doesn't support reply in threads, this field is always false. Corresponds to the JSON property threadReply

Returns:

  • (Boolean)


5647
5648
5649
# File 'lib/google/apis/chat_v1/classes.rb', line 5647

def thread_reply
  @thread_reply
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
# File 'lib/google/apis/chat_v1/classes.rb', line 5655

def update!(**args)
  @accessory_widgets = args[:accessory_widgets] if args.key?(:accessory_widgets)
  @action_response = args[:action_response] if args.key?(:action_response)
  @annotations = args[:annotations] if args.key?(:annotations)
  @argument_text = args[:argument_text] if args.key?(:argument_text)
  @attached_gifs = args[:attached_gifs] if args.key?(:attached_gifs)
  @attachment = args[:attachment] if args.key?(:attachment)
  @cards = args[:cards] if args.key?(:cards)
  @cards_v2 = args[:cards_v2] if args.key?(:cards_v2)
  @client_assigned_message_id = args[:client_assigned_message_id] if args.key?(:client_assigned_message_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @deletion_metadata = args[:deletion_metadata] if args.key?(:deletion_metadata)
  @emoji_reaction_summaries = args[:emoji_reaction_summaries] if args.key?(:emoji_reaction_summaries)
  @fallback_text = args[:fallback_text] if args.key?(:fallback_text)
  @formatted_text = args[:formatted_text] if args.key?(:formatted_text)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @matched_url = args[:matched_url] if args.key?(:matched_url)
  @name = args[:name] if args.key?(:name)
  @private_message_viewer = args[:private_message_viewer] if args.key?(:private_message_viewer)
  @quoted_message_metadata = args[:quoted_message_metadata] if args.key?(:quoted_message_metadata)
  @sender = args[:sender] if args.key?(:sender)
  @silent = args[:silent] if args.key?(:silent)
  @slash_command = args[:slash_command] if args.key?(:slash_command)
  @space = args[:space] if args.key?(:space)
  @text = args[:text] if args.key?(:text)
  @thread = args[:thread] if args.key?(:thread)
  @thread_reply = args[:thread_reply] if args.key?(:thread_reply)
end