Class: Google::Apis::ChatV1::PermissionSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Permission settings that you can specify when updating an existing named space. To set permission settings when creating a space, specify the PredefinedPermissionSettings field in your request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PermissionSettings

Returns a new instance of PermissionSettings.



5893
5894
5895
# File 'lib/google/apis/chat_v1/classes.rb', line 5893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#manage_appsGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property manageApps



5856
5857
5858
# File 'lib/google/apis/chat_v1/classes.rb', line 5856

def manage_apps
  @manage_apps
end

#manage_members_and_groupsGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property manageMembersAndGroups



5861
5862
5863
# File 'lib/google/apis/chat_v1/classes.rb', line 5861

def manage_members_and_groups
  @manage_members_and_groups
end

#manage_webhooksGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property manageWebhooks



5866
5867
5868
# File 'lib/google/apis/chat_v1/classes.rb', line 5866

def manage_webhooks
  @manage_webhooks
end

#modify_space_detailsGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property modifySpaceDetails



5871
5872
5873
# File 'lib/google/apis/chat_v1/classes.rb', line 5871

def modify_space_details
  @modify_space_details
end

#post_messagesGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property postMessages



5876
5877
5878
# File 'lib/google/apis/chat_v1/classes.rb', line 5876

def post_messages
  @post_messages
end

#reply_messagesGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property replyMessages



5881
5882
5883
# File 'lib/google/apis/chat_v1/classes.rb', line 5881

def reply_messages
  @reply_messages
end

#toggle_historyGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property toggleHistory



5886
5887
5888
# File 'lib/google/apis/chat_v1/classes.rb', line 5886

def toggle_history
  @toggle_history
end

#use_at_mention_allGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property useAtMentionAll



5891
5892
5893
# File 'lib/google/apis/chat_v1/classes.rb', line 5891

def use_at_mention_all
  @use_at_mention_all
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
# File 'lib/google/apis/chat_v1/classes.rb', line 5898

def update!(**args)
  @manage_apps = args[:manage_apps] if args.key?(:manage_apps)
  @manage_members_and_groups = args[:manage_members_and_groups] if args.key?(:manage_members_and_groups)
  @manage_webhooks = args[:manage_webhooks] if args.key?(:manage_webhooks)
  @modify_space_details = args[:modify_space_details] if args.key?(:modify_space_details)
  @post_messages = args[:post_messages] if args.key?(:post_messages)
  @reply_messages = args[:reply_messages] if args.key?(:reply_messages)
  @toggle_history = args[:toggle_history] if args.key?(:toggle_history)
  @use_at_mention_all = args[:use_at_mention_all] if args.key?(:use_at_mention_all)
end