Class: Google::Apis::ChatV1::PositionSectionResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Response message for positioning a section.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PositionSectionResponse

Returns a new instance of PositionSectionResponse.



5774
5775
5776
# File 'lib/google/apis/chat_v1/classes.rb', line 5774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sectionGoogle::Apis::ChatV1::GoogleChatV1Section

Represents a section in Google Chat. Sections help users organize their spaces. There are two types of sections: 1. System Sections: These are predefined sections managed by Google Chat. Their resource names are fixed, and they cannot be created, deleted, or have their display_name modified. Examples include: * users/ user/sections/default-direct-messages * users/user/sections/default- spaces * users/user/sections/default-apps 2. Custom Sections: These are sections created and managed by the user. Creating a custom section using CreateSection requires a display_name. Custom sections can be updated using UpdateSection and deleted using DeleteSection. Corresponds to the JSON property section



5772
5773
5774
# File 'lib/google/apis/chat_v1/classes.rb', line 5772

def section
  @section
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5779
5780
5781
# File 'lib/google/apis/chat_v1/classes.rb', line 5779

def update!(**args)
  @section = args[:section] if args.key?(:section)
end