Class: Google::Apis::ChatV1::QuotedMessageSnapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Provides a snapshot of the content of the quoted message at the time of quoting or forwarding

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotedMessageSnapshot

Returns a new instance of QuotedMessageSnapshot.



6167
6168
6169
# File 'lib/google/apis/chat_v1/classes.rb', line 6167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsArray<Google::Apis::ChatV1::Annotation>

Output only. Annotations parsed from the text body of the quoted message. Populated only for FORWARD quote type. Corresponds to the JSON property annotations



6140
6141
6142
# File 'lib/google/apis/chat_v1/classes.rb', line 6140

def annotations
  @annotations
end

#attachmentsArray<Google::Apis::ChatV1::Attachment>

Output only. Attachments that were part of the quoted message. These are copies of the quoted message's attachment metadata. Populated only for FORWARD quote type. Corresponds to the JSON property attachments



6147
6148
6149
# File 'lib/google/apis/chat_v1/classes.rb', line 6147

def attachments
  @attachments
end

#formatted_textString

Output only. Contains the quoted message text with markups added to support rich formatting like hyperlinks,custom emojis, markup, etc. Populated only for FORWARD quote type. Corresponds to the JSON property formattedText

Returns:

  • (String)


6154
6155
6156
# File 'lib/google/apis/chat_v1/classes.rb', line 6154

def formatted_text
  @formatted_text
end

#senderString

Output only. The quoted message's author name. Populated for both REPLY & FORWARD quote types. Corresponds to the JSON property sender

Returns:

  • (String)


6160
6161
6162
# File 'lib/google/apis/chat_v1/classes.rb', line 6160

def sender
  @sender
end

#textString

Output only. Snapshot of the quoted message's text content. Corresponds to the JSON property text

Returns:

  • (String)


6165
6166
6167
# File 'lib/google/apis/chat_v1/classes.rb', line 6165

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6172
6173
6174
6175
6176
6177
6178
# File 'lib/google/apis/chat_v1/classes.rb', line 6172

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @attachments = args[:attachments] if args.key?(:attachments)
  @formatted_text = args[:formatted_text] if args.key?(:formatted_text)
  @sender = args[:sender] if args.key?(:sender)
  @text = args[:text] if args.key?(:text)
end