Class: Google::Apis::ChatV1::RichLinkMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A rich link to a resource. Rich links can be associated with the plain-text body of the message or represent chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RichLinkMetadata

Returns a new instance of RichLinkMetadata.



6332
6333
6334
# File 'lib/google/apis/chat_v1/classes.rb', line 6332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Data for Calendar event links. Corresponds to the JSON property calendarEventLinkData



6305
6306
6307
# File 'lib/google/apis/chat_v1/classes.rb', line 6305

def calendar_event_link_data
  @calendar_event_link_data
end

Data for Chat space links. Corresponds to the JSON property chatSpaceLinkData



6310
6311
6312
# File 'lib/google/apis/chat_v1/classes.rb', line 6310

def chat_space_link_data
  @chat_space_link_data
end

Data for Google Drive links. Corresponds to the JSON property driveLinkData



6315
6316
6317
# File 'lib/google/apis/chat_v1/classes.rb', line 6315

def drive_link_data
  @drive_link_data
end

Data for Meet space links. Corresponds to the JSON property meetSpaceLinkData



6320
6321
6322
# File 'lib/google/apis/chat_v1/classes.rb', line 6320

def meet_space_link_data
  @meet_space_link_data
end

The rich link type. Corresponds to the JSON property richLinkType

Returns:

  • (String)


6325
6326
6327
# File 'lib/google/apis/chat_v1/classes.rb', line 6325

def rich_link_type
  @rich_link_type
end

#uriString

The URI of this link. Corresponds to the JSON property uri

Returns:

  • (String)


6330
6331
6332
# File 'lib/google/apis/chat_v1/classes.rb', line 6330

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6337
6338
6339
6340
6341
6342
6343
6344
# File 'lib/google/apis/chat_v1/classes.rb', line 6337

def update!(**args)
  @calendar_event_link_data = args[:calendar_event_link_data] if args.key?(:calendar_event_link_data)
  @chat_space_link_data = args[:chat_space_link_data] if args.key?(:chat_space_link_data)
  @drive_link_data = args[:drive_link_data] if args.key?(:drive_link_data)
  @meet_space_link_data = args[:meet_space_link_data] if args.key?(:meet_space_link_data)
  @rich_link_type = args[:rich_link_type] if args.key?(:rich_link_type)
  @uri = args[:uri] if args.key?(:uri)
end