Class: Google::Apis::ChatV1::SearchMessageResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A single result item from a message search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchMessageResult

Returns a new instance of SearchMessageResult.



6378
6379
6380
# File 'lib/google/apis/chat_v1/classes.rb', line 6378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageGoogle::Apis::ChatV1::Message

A message in a Google Chat space. Corresponds to the JSON property message



6354
6355
6356
# File 'lib/google/apis/chat_v1/classes.rb', line 6354

def message
  @message
end

#readBoolean Also known as: read?

Indicates if the matched message is read by the calling user. Only returned if the request view is SEARCH_MESSAGES_VIEW_FULL and the calling credentials include one of the following authorization scopes: - https://www. googleapis.com/auth/chat.users.readstate.readonly - https://www.googleapis. com/auth/chat.users.readstate Corresponds to the JSON property read

Returns:

  • (Boolean)


6364
6365
6366
# File 'lib/google/apis/chat_v1/classes.rb', line 6364

def read
  @read
end

#space_mute_settingString

The mute setting of the calling user for the space where the message is posted. The caller app can use this information to decide how to process the message depending on whether the space is muted for the user or not. Only returned if the request view is SEARCH_MESSAGES_VIEW_FULL and the calling credentials include the following authorization scope: - https://www. googleapis.com/auth/chat.users.spacesettings Corresponds to the JSON property spaceMuteSetting

Returns:

  • (String)


6376
6377
6378
# File 'lib/google/apis/chat_v1/classes.rb', line 6376

def space_mute_setting
  @space_mute_setting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6383
6384
6385
6386
6387
# File 'lib/google/apis/chat_v1/classes.rb', line 6383

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @read = args[:read] if args.key?(:read)
  @space_mute_setting = args[:space_mute_setting] if args.key?(:space_mute_setting)
end