Class: Google::Apis::ChatV1::SearchMessagesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::SearchMessagesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Response message for searching messages.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be used to retrieve the next page.
-
#results ⇒ Array<Google::Apis::ChatV1::SearchMessageResult>
The list of search results that matched the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchMessagesResponse
constructor
A new instance of SearchMessagesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchMessagesResponse
Returns a new instance of SearchMessagesResponse.
6539 6540 6541 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be used to retrieve the next page. If this field is empty,
there are no subsequent pages.
Corresponds to the JSON property nextPageToken
6532 6533 6534 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6532 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::ChatV1::SearchMessageResult>
The list of search results that matched the query.
Corresponds to the JSON property results
6537 6538 6539 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6537 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6544 6545 6546 6547 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6544 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) end |