Class: Google::Apis::ChatV1::SpaceReadState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A user's read state within a space, used to identify read and unread messages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpaceReadState

Returns a new instance of SpaceReadState.



7315
7316
7317
# File 'lib/google/apis/chat_v1/classes.rb', line 7315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_read_timeString

Optional. The time when the user's space read state was updated. Usually this corresponds with either the timestamp of the last read message, or a timestamp specified by the user to mark the last read position in a space. Corresponds to the JSON property lastReadTime

Returns:

  • (String)


7307
7308
7309
# File 'lib/google/apis/chat_v1/classes.rb', line 7307

def last_read_time
  @last_read_time
end

#nameString

Resource name of the space read state. Format: users/user/spaces/space/ spaceReadState Corresponds to the JSON property name

Returns:

  • (String)


7313
7314
7315
# File 'lib/google/apis/chat_v1/classes.rb', line 7313

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7320
7321
7322
7323
# File 'lib/google/apis/chat_v1/classes.rb', line 7320

def update!(**args)
  @last_read_time = args[:last_read_time] if args.key?(:last_read_time)
  @name = args[:name] if args.key?(:name)
end