Class: Google::Apis::ChatV1::ThreadReadState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A user's read state within a thread, used to identify read and unread messages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThreadReadState

Returns a new instance of ThreadReadState.



6984
6985
6986
# File 'lib/google/apis/chat_v1/classes.rb', line 6984

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_read_timeString

The time when the user's thread read state was updated. Usually this corresponds with the timestamp of the last read message in a thread. Corresponds to the JSON property lastReadTime

Returns:

  • (String)


6976
6977
6978
# File 'lib/google/apis/chat_v1/classes.rb', line 6976

def last_read_time
  @last_read_time
end

#nameString

Resource name of the thread read state. Format: users/user/spaces/space/ threads/thread/threadReadState Corresponds to the JSON property name

Returns:

  • (String)


6982
6983
6984
# File 'lib/google/apis/chat_v1/classes.rb', line 6982

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6989
6990
6991
6992
# File 'lib/google/apis/chat_v1/classes.rb', line 6989

def update!(**args)
  @last_read_time = args[:last_read_time] if args.key?(:last_read_time)
  @name = args[:name] if args.key?(:name)
end