Class: Google::Apis::ChatV1::UpdatedWidget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

For selectionInput widgets, returns autocomplete suggestions for a multiselect menu.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdatedWidget

Returns a new instance of UpdatedWidget.



7355
7356
7357
# File 'lib/google/apis/chat_v1/classes.rb', line 7355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#suggestionsGoogle::Apis::ChatV1::SelectionItems

List of widget autocomplete results. Corresponds to the JSON property suggestions



7347
7348
7349
# File 'lib/google/apis/chat_v1/classes.rb', line 7347

def suggestions
  @suggestions
end

#widgetString

The ID of the updated widget. The ID must match the one for the widget that triggered the update request. Corresponds to the JSON property widget

Returns:

  • (String)


7353
7354
7355
# File 'lib/google/apis/chat_v1/classes.rb', line 7353

def widget
  @widget
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7360
7361
7362
7363
# File 'lib/google/apis/chat_v1/classes.rb', line 7360

def update!(**args)
  @suggestions = args[:suggestions] if args.key?(:suggestions)
  @widget = args[:widget] if args.key?(:widget)
end