Class: Google::Apis::ChatV1::UserMentionMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::UserMentionMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Annotation metadata for user mentions (@).
Instance Attribute Summary collapse
-
#type ⇒ String
The type of user mention.
-
#user ⇒ Google::Apis::ChatV1::User
A user in Google Chat.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserMentionMetadata
constructor
A new instance of UserMentionMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserMentionMetadata
Returns a new instance of UserMentionMetadata.
7479 7480 7481 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7479 def initialize(**args) update!(**args) end |
Instance Attribute Details
#type ⇒ String
The type of user mention.
Corresponds to the JSON property type
7469 7470 7471 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7469 def type @type end |
#user ⇒ Google::Apis::ChatV1::User
A user in Google Chat. When returned as an output from a request, if your Chat
app authenticates as a user, the output for a User resource only
populates the user's name and type.
Corresponds to the JSON property user
7477 7478 7479 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7477 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7484 7485 7486 7487 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7484 def update!(**args) @type = args[:type] if args.key?(:type) @user = args[:user] if args.key?(:user) end |