Class: Google::Apis::ChatV1::WidgetMarkup
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::WidgetMarkup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A widget is a UI element that presents text and images.
Instance Attribute Summary collapse
-
#buttons ⇒ Array<Google::Apis::ChatV1::Button>
A list of buttons.
-
#image ⇒ Google::Apis::ChatV1::Image
An image that's specified by a URL and can have an
onclickaction. -
#key_value ⇒ Google::Apis::ChatV1::KeyValue
A UI element contains a key (label) and a value (content).
-
#text_paragraph ⇒ Google::Apis::ChatV1::TextParagraph
A paragraph of text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WidgetMarkup
constructor
A new instance of WidgetMarkup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WidgetMarkup
Returns a new instance of WidgetMarkup.
7232 7233 7234 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7232 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buttons ⇒ Array<Google::Apis::ChatV1::Button>
A list of buttons. Buttons is also oneof data and only one of these fields
should be set.
Corresponds to the JSON property buttons
7210 7211 7212 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7210 def @buttons end |
#image ⇒ Google::Apis::ChatV1::Image
An image that's specified by a URL and can have an onclick action.
Corresponds to the JSON property image
7215 7216 7217 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7215 def image @image end |
#key_value ⇒ Google::Apis::ChatV1::KeyValue
A UI element contains a key (label) and a value (content). This element can
also contain some actions such as onclick button.
Corresponds to the JSON property keyValue
7221 7222 7223 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7221 def key_value @key_value end |
#text_paragraph ⇒ Google::Apis::ChatV1::TextParagraph
A paragraph of text. Formatted text supported. For more information about
formatting text, see Formatting text in Google Chat apps and Formatting
text in Google Workspace Add-ons.
Corresponds to the JSON property textParagraph
7230 7231 7232 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7230 def text_paragraph @text_paragraph end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7237 7238 7239 7240 7241 7242 |
# File 'lib/google/apis/chat_v1/classes.rb', line 7237 def update!(**args) @buttons = args[:buttons] if args.key?(:buttons) @image = args[:image] if args.key?(:image) @key_value = args[:key_value] if args.key?(:key_value) @text_paragraph = args[:text_paragraph] if args.key?(:text_paragraph) end |