Class: Google::Apis::ChatV1::WorkflowDataSourceMarkup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

  • Only supported by Google Workspace Workflow, but not Google Chat apps or Google Workspace add-ons. In a TextInput or SelectionInput widget with MULTI_SELECT type or a DateTimePicker, provide data source from Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkflowDataSourceMarkup

Returns a new instance of WorkflowDataSourceMarkup.



7263
7264
7265
# File 'lib/google/apis/chat_v1/classes.rb', line 7263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_variablesBoolean Also known as: include_variables?

Whether to include variables from the previous step in the data source. Corresponds to the JSON property includeVariables

Returns:

  • (Boolean)


7255
7256
7257
# File 'lib/google/apis/chat_v1/classes.rb', line 7255

def include_variables
  @include_variables
end

#typeString

The type of data source. Corresponds to the JSON property type

Returns:

  • (String)


7261
7262
7263
# File 'lib/google/apis/chat_v1/classes.rb', line 7261

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7268
7269
7270
7271
# File 'lib/google/apis/chat_v1/classes.rb', line 7268

def update!(**args)
  @include_variables = args[:include_variables] if args.key?(:include_variables)
  @type = args[:type] if args.key?(:type)
end