Class: Google::Apis::ChatV1::Attachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

An attachment in Google Chat.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Attachment

Returns a new instance of Attachment.



347
348
349
# File 'lib/google/apis/chat_v1/classes.rb', line 347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_data_refGoogle::Apis::ChatV1::AttachmentDataRef

A reference to the attachment data. Corresponds to the JSON property attachmentDataRef



305
306
307
# File 'lib/google/apis/chat_v1/classes.rb', line 305

def attachment_data_ref
  @attachment_data_ref
end

#content_nameString

Output only. The original file name for the content, not the full path. Corresponds to the JSON property contentName

Returns:

  • (String)


310
311
312
# File 'lib/google/apis/chat_v1/classes.rb', line 310

def content_name
  @content_name
end

#content_typeString

Output only. The content type (MIME type) of the file. Corresponds to the JSON property contentType

Returns:

  • (String)


315
316
317
# File 'lib/google/apis/chat_v1/classes.rb', line 315

def content_type
  @content_type
end

#download_uriString

Output only. The download URL which should be used to allow a human user to download the attachment. Chat apps shouldn't use this URL to download attachment content. Corresponds to the JSON property downloadUri

Returns:

  • (String)


322
323
324
# File 'lib/google/apis/chat_v1/classes.rb', line 322

def download_uri
  @download_uri
end

#drive_data_refGoogle::Apis::ChatV1::DriveDataRef

A reference to the data of a drive attachment. Corresponds to the JSON property driveDataRef



327
328
329
# File 'lib/google/apis/chat_v1/classes.rb', line 327

def drive_data_ref
  @drive_data_ref
end

#nameString

Identifier. Resource name of the attachment. Format: spaces/space/messages/ message/attachments/attachment`. Corresponds to the JSON propertyname`

Returns:

  • (String)


333
334
335
# File 'lib/google/apis/chat_v1/classes.rb', line 333

def name
  @name
end

#sourceString

Output only. The source of the attachment. Corresponds to the JSON property source

Returns:

  • (String)


338
339
340
# File 'lib/google/apis/chat_v1/classes.rb', line 338

def source
  @source
end

#thumbnail_uriString

Output only. The thumbnail URL which should be used to preview the attachment to a human user. Chat apps shouldn't use this URL to download attachment content. Corresponds to the JSON property thumbnailUri

Returns:

  • (String)


345
346
347
# File 'lib/google/apis/chat_v1/classes.rb', line 345

def thumbnail_uri
  @thumbnail_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



352
353
354
355
356
357
358
359
360
361
# File 'lib/google/apis/chat_v1/classes.rb', line 352

def update!(**args)
  @attachment_data_ref = args[:attachment_data_ref] if args.key?(:attachment_data_ref)
  @content_name = args[:content_name] if args.key?(:content_name)
  @content_type = args[:content_type] if args.key?(:content_type)
  @download_uri = args[:download_uri] if args.key?(:download_uri)
  @drive_data_ref = args[:drive_data_ref] if args.key?(:drive_data_ref)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @thumbnail_uri = args[:thumbnail_uri] if args.key?(:thumbnail_uri)
end