Class: Google::Apis::ChatV1::ChatAppLogEntry

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

JSON payload of error messages. If the Cloud Logging API is enabled, these error messages are logged to Google Cloud Logging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChatAppLogEntry

Returns a new instance of ChatAppLogEntry.



631
632
633
# File 'lib/google/apis/chat_v1/classes.rb', line 631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploymentString

The deployment that caused the error. For Chat apps built in Apps Script, this is the deployment ID defined by Apps Script. Corresponds to the JSON property deployment

Returns:

  • (String)


613
614
615
# File 'lib/google/apis/chat_v1/classes.rb', line 613

def deployment
  @deployment
end

#deployment_functionString

The unencrypted callback_method name that was running when the error was encountered. Corresponds to the JSON property deploymentFunction

Returns:

  • (String)


619
620
621
# File 'lib/google/apis/chat_v1/classes.rb', line 619

def deployment_function
  @deployment_function
end

#errorGoogle::Apis::ChatV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



629
630
631
# File 'lib/google/apis/chat_v1/classes.rb', line 629

def error
  @error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



636
637
638
639
640
# File 'lib/google/apis/chat_v1/classes.rb', line 636

def update!(**args)
  @deployment = args[:deployment] if args.key?(:deployment)
  @deployment_function = args[:deployment_function] if args.key?(:deployment_function)
  @error = args[:error] if args.key?(:error)
end