Class: Google::Apis::ChatV1::CustomEmoji
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::CustomEmoji
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Represents a custom emoji.
Instance Attribute Summary collapse
-
#emoji_name ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#payload ⇒ Google::Apis::ChatV1::CustomEmojiPayload
Payload data for the custom emoji.
-
#temporary_image_uri ⇒ String
Output only.
-
#uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomEmoji
constructor
A new instance of CustomEmoji.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomEmoji
Returns a new instance of CustomEmoji.
1036 1037 1038 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1036 def initialize(**args) update!(**args) end |
Instance Attribute Details
#emoji_name ⇒ String
Optional. Immutable. User-provided name for the custom emoji, which is unique
within the organization. Required when the custom emoji is created, output
only otherwise. Emoji names must start and end with colons, must be lowercase
and can only contain alphanumeric characters, hyphens, and underscores.
Hyphens and underscores should be used to separate words and cannot be used
consecutively. Example: :valid-emoji-name:
Corresponds to the JSON property emojiName
1011 1012 1013 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1011 def emoji_name @emoji_name end |
#name ⇒ String
Identifier. The resource name of the custom emoji, assigned by the server.
Format: customEmojis/customEmoji`
Corresponds to the JSON propertyname`
1017 1018 1019 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1017 def name @name end |
#payload ⇒ Google::Apis::ChatV1::CustomEmojiPayload
Payload data for the custom emoji.
Corresponds to the JSON property payload
1022 1023 1024 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1022 def payload @payload end |
#temporary_image_uri ⇒ String
Output only. A temporary image URL for the custom emoji, valid for at least 10
minutes. Note that this is not populated in the response when the custom emoji
is created.
Corresponds to the JSON property temporaryImageUri
1029 1030 1031 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1029 def temporary_image_uri @temporary_image_uri end |
#uid ⇒ String
Output only. Unique key for the custom emoji resource.
Corresponds to the JSON property uid
1034 1035 1036 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1034 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1041 1042 1043 1044 1045 1046 1047 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1041 def update!(**args) @emoji_name = args[:emoji_name] if args.key?(:emoji_name) @name = args[:name] if args.key?(:name) @payload = args[:payload] if args.key?(:payload) @temporary_image_uri = args[:temporary_image_uri] if args.key?(:temporary_image_uri) @uid = args[:uid] if args.key?(:uid) end |