Class: Google::Apis::ChatV1::CustomEmoji

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents a custom emoji.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomEmoji

Returns a new instance of CustomEmoji.



991
992
993
# File 'lib/google/apis/chat_v1/classes.rb', line 991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emoji_nameString

Optional. Immutable. User-provided name for the custom emoji, which is unique within the organization. Required when the custom emoji is created, output only otherwise. Emoji names must start and end with colons, must be lowercase and can only contain alphanumeric characters, hyphens, and underscores. Hyphens and underscores should be used to separate words and cannot be used consecutively. Example: :valid-emoji-name: Corresponds to the JSON property emojiName

Returns:

  • (String)


966
967
968
# File 'lib/google/apis/chat_v1/classes.rb', line 966

def emoji_name
  @emoji_name
end

#nameString

Identifier. The resource name of the custom emoji, assigned by the server. Format: customEmojis/customEmoji` Corresponds to the JSON propertyname`

Returns:

  • (String)


972
973
974
# File 'lib/google/apis/chat_v1/classes.rb', line 972

def name
  @name
end

#payloadGoogle::Apis::ChatV1::CustomEmojiPayload

Payload data for the custom emoji. Corresponds to the JSON property payload



977
978
979
# File 'lib/google/apis/chat_v1/classes.rb', line 977

def payload
  @payload
end

#temporary_image_uriString

Output only. A temporary image URL for the custom emoji, valid for at least 10 minutes. Note that this is not populated in the response when the custom emoji is created. Corresponds to the JSON property temporaryImageUri

Returns:

  • (String)


984
985
986
# File 'lib/google/apis/chat_v1/classes.rb', line 984

def temporary_image_uri
  @temporary_image_uri
end

#uidString

Output only. Unique key for the custom emoji resource. Corresponds to the JSON property uid

Returns:

  • (String)


989
990
991
# File 'lib/google/apis/chat_v1/classes.rb', line 989

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



996
997
998
999
1000
1001
1002
# File 'lib/google/apis/chat_v1/classes.rb', line 996

def update!(**args)
  @emoji_name = args[:emoji_name] if args.key?(:emoji_name)
  @name = args[:name] if args.key?(:name)
  @payload = args[:payload] if args.key?(:payload)
  @temporary_image_uri = args[:temporary_image_uri] if args.key?(:temporary_image_uri)
  @uid = args[:uid] if args.key?(:uid)
end