Class: Google::Apis::ChatV1::FormAction
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::FormAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A form action describes the behavior when the form is submitted. For example, you can invoke Apps Script to handle the form.
Instance Attribute Summary collapse
-
#action_method_name ⇒ String
The method name is used to identify which part of the form triggered the form submission.
-
#parameters ⇒ Array<Google::Apis::ChatV1::ActionParameter>
List of action parameters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FormAction
constructor
A new instance of FormAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FormAction
Returns a new instance of FormAction.
1609 1610 1611 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1609 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_method_name ⇒ String
The method name is used to identify which part of the form triggered the form
submission. This information is echoed back to the Chat app as part of the
card click event. You can use the same method name for several elements that
trigger a common behavior.
Corresponds to the JSON property actionMethodName
1602 1603 1604 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1602 def action_method_name @action_method_name end |
#parameters ⇒ Array<Google::Apis::ChatV1::ActionParameter>
List of action parameters.
Corresponds to the JSON property parameters
1607 1608 1609 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1607 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1614 1615 1616 1617 |
# File 'lib/google/apis/chat_v1/classes.rb', line 1614 def update!(**args) @action_method_name = args[:action_method_name] if args.key?(:action_method_name) @parameters = args[:parameters] if args.key?(:parameters) end |