Class: Google::Apis::ChatV1::ForwardedMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Metadata about the source space from which a message was forwarded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardedMetadata

Returns a new instance of ForwardedMetadata.



1533
1534
1535
# File 'lib/google/apis/chat_v1/classes.rb', line 1533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spaceString

Output only. The resource name of the source space. Format: spaces/space Corresponds to the JSON property space

Returns:

  • (String)


1522
1523
1524
# File 'lib/google/apis/chat_v1/classes.rb', line 1522

def space
  @space
end

#space_display_nameString

Output only. The display name of the source space or DM at the time of forwarding. For SPACE, this is the space name. For DIRECT_MESSAGE, this is the other participant's name (e.g., "User A"). For GROUP_CHAT, this is a generated name based on members' first names, limited to 5 including the creator (e.g., "User A, User B"). Corresponds to the JSON property spaceDisplayName

Returns:

  • (String)


1531
1532
1533
# File 'lib/google/apis/chat_v1/classes.rb', line 1531

def space_display_name
  @space_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1538
1539
1540
1541
# File 'lib/google/apis/chat_v1/classes.rb', line 1538

def update!(**args)
  @space = args[:space] if args.key?(:space)
  @space_display_name = args[:space_display_name] if args.key?(:space_display_name)
end