Class: Google::Apis::ChatV1::GoogleAppsCardV1Action

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

An action that describes the behavior when the form is submitted. For example, you can invoke an Apps Script script to handle the form. If the action is triggered, the form values are sent to the server. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1Action

Returns a new instance of GoogleAppsCardV1Action.



1554
1555
1556
# File 'lib/google/apis/chat_v1/classes.rb', line 1554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_widgets_are_requiredBoolean Also known as: all_widgets_are_required?

Optional. If this is true, then all widgets are considered required by this action. Google Workspace add-ons and Chat apps: Corresponds to the JSON property allWidgetsAreRequired

Returns:

  • (Boolean)


1491
1492
1493
# File 'lib/google/apis/chat_v1/classes.rb', line 1491

def all_widgets_are_required
  @all_widgets_are_required
end

#functionString

A custom function to invoke when the containing element is clicked or otherwise activated. For example usage, see Read form data. Corresponds to the JSON property function

Returns:

  • (String)


1499
1500
1501
# File 'lib/google/apis/chat_v1/classes.rb', line 1499

def function
  @function
end

#interactionString

Optional. Required when opening a dialog. What to do in response to an interaction with a user, such as a user clicking a button in a card message. If unspecified, the app responds by executing an action—like opening a link or running a function—as normal. By specifying an interaction, the app can respond in special interactive ways. For example, by setting interaction to OPEN_DIALOG, the app can open a dialog. When specified, a loading indicator isn't shown. If specified for an add-on, the entire card is stripped and nothing is shown in the client. Google Chat apps: Corresponds to the JSON property interaction

Returns:

  • (String)


1513
1514
1515
# File 'lib/google/apis/chat_v1/classes.rb', line 1513

def interaction
  @interaction
end

#load_indicatorString

Specifies the loading indicator that the action displays while making the call to the action. Corresponds to the JSON property loadIndicator

Returns:

  • (String)


1519
1520
1521
# File 'lib/google/apis/chat_v1/classes.rb', line 1519

def load_indicator
  @load_indicator
end

#parametersArray<Google::Apis::ChatV1::GoogleAppsCardV1ActionParameter>

List of action parameters. Corresponds to the JSON property parameters



1524
1525
1526
# File 'lib/google/apis/chat_v1/classes.rb', line 1524

def parameters
  @parameters
end

#persist_valuesBoolean Also known as: persist_values?

Indicates whether form values persist after the action. The default value is false. If true, form values remain after the action is triggered. To let the user make changes while the action is being processed, set LoadIndicator to NONE. For card messages in Chat apps, you must also set the action's ResponseType to UPDATE_MESSAGE and use the same card_id from the card that contained the action. If false, the form values are cleared when the action is triggered. To prevent the user from making changes while the action is being processed, set LoadIndicator to SPINNER . Corresponds to the JSON property persistValues

Returns:

  • (Boolean)


1543
1544
1545
# File 'lib/google/apis/chat_v1/classes.rb', line 1543

def persist_values
  @persist_values
end

#required_widgetsArray<String>

Optional. Fill this list with the names of widgets that this Action needs for a valid submission. If the widgets listed here don't have a value when this Action is invoked, the form submission is aborted. Google Workspace add-ons and Chat apps: Corresponds to the JSON property requiredWidgets

Returns:

  • (Array<String>)


1552
1553
1554
# File 'lib/google/apis/chat_v1/classes.rb', line 1552

def required_widgets
  @required_widgets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1559
1560
1561
1562
1563
1564
1565
1566
1567
# File 'lib/google/apis/chat_v1/classes.rb', line 1559

def update!(**args)
  @all_widgets_are_required = args[:all_widgets_are_required] if args.key?(:all_widgets_are_required)
  @function = args[:function] if args.key?(:function)
  @interaction = args[:interaction] if args.key?(:interaction)
  @load_indicator = args[:load_indicator] if args.key?(:load_indicator)
  @parameters = args[:parameters] if args.key?(:parameters)
  @persist_values = args[:persist_values] if args.key?(:persist_values)
  @required_widgets = args[:required_widgets] if args.key?(:required_widgets)
end