Class: Google::Apis::ChatV1::GoogleAppsCardV1CarouselCard
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1CarouselCard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A card that can be displayed as a carousel item. Google Chat apps:
Instance Attribute Summary collapse
-
#footer_widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed at the bottom of the carousel card.
-
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed in the carousel card.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1CarouselCard
constructor
A new instance of GoogleAppsCardV1CarouselCard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1CarouselCard
Returns a new instance of GoogleAppsCardV1CarouselCard.
2279 2280 2281 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#footer_widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed at the bottom of the carousel card. The widgets
are displayed in the order that they are specified.
Corresponds to the JSON property footerWidgets
2271 2272 2273 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2271 def @footer_widgets end |
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed in the carousel card. The widgets are displayed in
the order that they are specified.
Corresponds to the JSON property widgets
2277 2278 2279 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2277 def @widgets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2284 2285 2286 2287 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2284 def update!(**args) @footer_widgets = args[:footer_widgets] if args.key?(:footer_widgets) @widgets = args[:widgets] if args.key?(:widgets) end |