Class: Google::Apis::ChatV1::GoogleAppsCardV1CarouselCard
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1CarouselCard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A card that can be displayed as a carousel item. Google Chat apps:
Instance Attribute Summary collapse
-
#footer_widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed at the bottom of the carousel card.
-
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed in the carousel card.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1CarouselCard
constructor
A new instance of GoogleAppsCardV1CarouselCard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1CarouselCard
Returns a new instance of GoogleAppsCardV1CarouselCard.
2174 2175 2176 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#footer_widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed at the bottom of the carousel card. The widgets
are displayed in the order that they are specified.
Corresponds to the JSON property footerWidgets
2166 2167 2168 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2166 def @footer_widgets end |
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed in the carousel card. The widgets are displayed in
the order that they are specified.
Corresponds to the JSON property widgets
2172 2173 2174 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2172 def @widgets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2179 2180 2181 2182 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2179 def update!(**args) @footer_widgets = args[:footer_widgets] if args.key?(:footer_widgets) @widgets = args[:widgets] if args.key?(:widgets) end |