Class: Google::Apis::ChatV1::GoogleAppsCardV1CarouselCard
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1CarouselCard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A card that can be displayed as a carousel item. Google Chat apps:
Instance Attribute Summary collapse
-
#footer_widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed at the bottom of the carousel card.
-
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed in the carousel card.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1CarouselCard
constructor
A new instance of GoogleAppsCardV1CarouselCard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1CarouselCard
Returns a new instance of GoogleAppsCardV1CarouselCard.
2108 2109 2110 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#footer_widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed at the bottom of the carousel card. The widgets
are displayed in the order that they are specified.
Corresponds to the JSON property footerWidgets
2100 2101 2102 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2100 def @footer_widgets end |
#widgets ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget>
A list of widgets displayed in the carousel card. The widgets are displayed in
the order that they are specified.
Corresponds to the JSON property widgets
2106 2107 2108 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2106 def @widgets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2113 2114 2115 2116 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2113 def update!(**args) @footer_widgets = args[:footer_widgets] if args.key?(:footer_widgets) @widgets = args[:widgets] if args.key?(:widgets) end |