Class: Google::Apis::ChatV1::GoogleAppsCardV1CollapseControl
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1CollapseControl
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Represent an expand and collapse control. Google Workspace add-ons and Chat apps:
Instance Attribute Summary collapse
-
#collapse_button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click.
-
#expand_button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click.
-
#horizontal_alignment ⇒ String
The horizontal alignment of the expand and collapse button.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1CollapseControl
constructor
A new instance of GoogleAppsCardV1CollapseControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1CollapseControl
Returns a new instance of GoogleAppsCardV1CollapseControl.
2241 2242 2243 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collapse_button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click. For an example in
Google Chat apps, see Add a button. To make an image a
clickable button, specify an Image (not an ImageComponent) and set an
onClick action. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property collapseButton
2224 2225 2226 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2224 def @collapse_button end |
#expand_button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click. For an example in
Google Chat apps, see Add a button. To make an image a
clickable button, specify an Image (not an ImageComponent) and set an
onClick action. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property expandButton
2234 2235 2236 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2234 def @expand_button end |
#horizontal_alignment ⇒ String
The horizontal alignment of the expand and collapse button.
Corresponds to the JSON property horizontalAlignment
2239 2240 2241 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2239 def horizontal_alignment @horizontal_alignment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2246 2247 2248 2249 2250 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2246 def update!(**args) @collapse_button = args[:collapse_button] if args.key?(:collapse_button) @expand_button = args[:expand_button] if args.key?(:expand_button) @horizontal_alignment = args[:horizontal_alignment] if args.key?(:horizontal_alignment) end |