Class: Google::Apis::ChatV1::GoogleAppsCardV1CommonWidgetAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents an action that is not specific to a widget. Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1CommonWidgetAction

Returns a new instance of GoogleAppsCardV1CommonWidgetAction.



2344
2345
2346
# File 'lib/google/apis/chat_v1/classes.rb', line 2344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#update_visibility_actionGoogle::Apis::ChatV1::GoogleAppsCardV1UpdateVisibilityAction

Represents an action that updates the visibility of a widget. Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps. Corresponds to the JSON property updateVisibilityAction



2342
2343
2344
# File 'lib/google/apis/chat_v1/classes.rb', line 2342

def update_visibility_action
  @update_visibility_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2349
2350
2351
# File 'lib/google/apis/chat_v1/classes.rb', line 2349

def update!(**args)
  @update_visibility_action = args[:update_visibility_action] if args.key?(:update_visibility_action)
end