Class: Google::Apis::ChatV1::GoogleAppsCardV1DataSourceConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A configuration object that helps configure the data sources for a widget. Available for Google Chat apps and Google Workspace add-ons that extend Google Workspace Studio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1DataSourceConfig

Returns a new instance of GoogleAppsCardV1DataSourceConfig.



2581
2582
2583
# File 'lib/google/apis/chat_v1/classes.rb', line 2581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#min_characters_triggerFixnum

The minimum number of characters the user must enter before this data provider is triggered (i.e., before it starts returning results). Corresponds to the JSON property minCharactersTrigger

Returns:

  • (Fixnum)


2564
2565
2566
# File 'lib/google/apis/chat_v1/classes.rb', line 2564

def min_characters_trigger
  @min_characters_trigger
end

#platform_data_sourceGoogle::Apis::ChatV1::GoogleAppsCardV1PlatformDataSource

For a SelectionInput widget that uses a multiselect menu, a data source from Google Workspace. Used to populate items in a multiselect menu. Google Chat apps: Corresponds to the JSON property platformDataSource



2571
2572
2573
# File 'lib/google/apis/chat_v1/classes.rb', line 2571

def platform_data_source
  @platform_data_source
end

#remote_data_sourceGoogle::Apis::ChatV1::GoogleAppsCardV1Action

An action that describes the behavior when the form is submitted. For example, you can invoke an Apps Script script to handle the form. If the action is triggered, the form values are sent to the server. Google Workspace add-ons and Chat apps: Corresponds to the JSON property remoteDataSource



2579
2580
2581
# File 'lib/google/apis/chat_v1/classes.rb', line 2579

def remote_data_source
  @remote_data_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2586
2587
2588
2589
2590
# File 'lib/google/apis/chat_v1/classes.rb', line 2586

def update!(**args)
  @min_characters_trigger = args[:min_characters_trigger] if args.key?(:min_characters_trigger)
  @platform_data_source = args[:platform_data_source] if args.key?(:platform_data_source)
  @remote_data_source = args[:remote_data_source] if args.key?(:remote_data_source)
end