Class: Google::Apis::ChatV1::GoogleAppsCardV1DataSourceConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A configuration object that helps configure the data sources for a widget. Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1DataSourceConfig

Returns a new instance of GoogleAppsCardV1DataSourceConfig.



2404
2405
2406
# File 'lib/google/apis/chat_v1/classes.rb', line 2404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#platform_data_sourceGoogle::Apis::ChatV1::GoogleAppsCardV1PlatformDataSource

For a SelectionInput widget that uses a multiselect menu, a data source from Google Workspace. Used to populate items in a multiselect menu. Google Chat apps: Corresponds to the JSON property platformDataSource



2394
2395
2396
# File 'lib/google/apis/chat_v1/classes.rb', line 2394

def platform_data_source
  @platform_data_source
end

#remote_data_sourceGoogle::Apis::ChatV1::GoogleAppsCardV1Action

An action that describes the behavior when the form is submitted. For example, you can invoke an Apps Script script to handle the form. If the action is triggered, the form values are sent to the server. Google Workspace add-ons and Chat apps: Corresponds to the JSON property remoteDataSource



2402
2403
2404
# File 'lib/google/apis/chat_v1/classes.rb', line 2402

def remote_data_source
  @remote_data_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2409
2410
2411
2412
# File 'lib/google/apis/chat_v1/classes.rb', line 2409

def update!(**args)
  @platform_data_source = args[:platform_data_source] if args.key?(:platform_data_source)
  @remote_data_source = args[:remote_data_source] if args.key?(:remote_data_source)
end