Class: Google::Apis::ChatV1::GoogleAppsCardV1DecoratedText

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A widget that displays text with optional decorations such as a label above or below the text, an icon in front of the text, a selection widget, or a button after the text. For an example in Google Chat apps, see Display text with decorative text. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1DecoratedText

Returns a new instance of GoogleAppsCardV1DecoratedText.



2813
2814
2815
# File 'lib/google/apis/chat_v1/classes.rb', line 2813

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bottom_labelString

The text that appears below text. Always wraps. Corresponds to the JSON property bottomLabel

Returns:

  • (String)


2686
2687
2688
# File 'lib/google/apis/chat_v1/classes.rb', line 2686

def bottom_label
  @bottom_label
end

#bottom_label_textGoogle::Apis::ChatV1::GoogleAppsCardV1TextParagraph

A paragraph of text that supports formatting. For an example in Google Chat apps, see Add a paragraph of formatted text. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property bottomLabelText



2699
2700
2701
# File 'lib/google/apis/chat_v1/classes.rb', line 2699

def bottom_label_text
  @bottom_label_text
end

#buttonGoogle::Apis::ChatV1::GoogleAppsCardV1Button

A text, icon, or text and icon button that users can click. For an example in Google Chat apps, see Add a button. To make an image a clickable button, specify an Image (not an ImageComponent) and set an onClick action. Google Workspace add-ons and Chat apps: Corresponds to the JSON property button



2709
2710
2711
# File 'lib/google/apis/chat_v1/classes.rb', line 2709

def button
  @button
end

#content_textGoogle::Apis::ChatV1::GoogleAppsCardV1TextParagraph

A paragraph of text that supports formatting. For an example in Google Chat apps, see Add a paragraph of formatted text. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property contentText



2722
2723
2724
# File 'lib/google/apis/chat_v1/classes.rb', line 2722

def content_text
  @content_text
end

#end_iconGoogle::Apis::ChatV1::GoogleAppsCardV1Icon

An icon displayed in a widget on a card. For an example in Google Chat apps, see Add an icon. Supports built-in and custom icons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property endIcon



2733
2734
2735
# File 'lib/google/apis/chat_v1/classes.rb', line 2733

def end_icon
  @end_icon
end

#iconGoogle::Apis::ChatV1::GoogleAppsCardV1Icon

An icon displayed in a widget on a card. For an example in Google Chat apps, see Add an icon. Supports built-in and custom icons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property icon



2744
2745
2746
# File 'lib/google/apis/chat_v1/classes.rb', line 2744

def icon
  @icon
end

#on_clickGoogle::Apis::ChatV1::GoogleAppsCardV1OnClick

Represents how to respond when users click an interactive element on a card, such as a button. Google Workspace add-ons and Chat apps: Corresponds to the JSON property onClick



2751
2752
2753
# File 'lib/google/apis/chat_v1/classes.rb', line 2751

def on_click
  @on_click
end

#start_iconGoogle::Apis::ChatV1::GoogleAppsCardV1Icon

An icon displayed in a widget on a card. For an example in Google Chat apps, see Add an icon. Supports built-in and custom icons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property startIcon



2762
2763
2764
# File 'lib/google/apis/chat_v1/classes.rb', line 2762

def start_icon
  @start_icon
end

#start_icon_vertical_alignmentString

Optional. Vertical alignment of the start icon. If not set, the icon will be vertically centered. Google Chat apps: Corresponds to the JSON property startIconVerticalAlignment

Returns:

  • (String)


2769
2770
2771
# File 'lib/google/apis/chat_v1/classes.rb', line 2769

def start_icon_vertical_alignment
  @start_icon_vertical_alignment
end

#switch_controlGoogle::Apis::ChatV1::GoogleAppsCardV1SwitchControl

Either a toggle-style switch or a checkbox inside a decoratedText widget. Google Workspace add-ons and Chat apps: Only supported in the decoratedText widget. Corresponds to the JSON property switchControl



2776
2777
2778
# File 'lib/google/apis/chat_v1/classes.rb', line 2776

def switch_control
  @switch_control
end

#textString

Required. The primary text. Supports simple formatting. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Corresponds to the JSON property text

Returns:

  • (String)


2785
2786
2787
# File 'lib/google/apis/chat_v1/classes.rb', line 2785

def text
  @text
end

#top_labelString

The text that appears above text. Always truncates. Corresponds to the JSON property topLabel

Returns:

  • (String)


2790
2791
2792
# File 'lib/google/apis/chat_v1/classes.rb', line 2790

def top_label
  @top_label
end

#top_label_textGoogle::Apis::ChatV1::GoogleAppsCardV1TextParagraph

A paragraph of text that supports formatting. For an example in Google Chat apps, see Add a paragraph of formatted text. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Google Workspace add-ons and Chat apps: Corresponds to the JSON property topLabelText



2803
2804
2805
# File 'lib/google/apis/chat_v1/classes.rb', line 2803

def top_label_text
  @top_label_text
end

#wrap_textBoolean Also known as: wrap_text?

The wrap text setting. If true, the text wraps and displays on multiple lines. Otherwise, the text is truncated. Only applies to text, not topLabel and bottomLabel. Corresponds to the JSON property wrapText

Returns:

  • (Boolean)


2810
2811
2812
# File 'lib/google/apis/chat_v1/classes.rb', line 2810

def wrap_text
  @wrap_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
# File 'lib/google/apis/chat_v1/classes.rb', line 2818

def update!(**args)
  @bottom_label = args[:bottom_label] if args.key?(:bottom_label)
  @bottom_label_text = args[:bottom_label_text] if args.key?(:bottom_label_text)
  @button = args[:button] if args.key?(:button)
  @content_text = args[:content_text] if args.key?(:content_text)
  @end_icon = args[:end_icon] if args.key?(:end_icon)
  @icon = args[:icon] if args.key?(:icon)
  @on_click = args[:on_click] if args.key?(:on_click)
  @start_icon = args[:start_icon] if args.key?(:start_icon)
  @start_icon_vertical_alignment = args[:start_icon_vertical_alignment] if args.key?(:start_icon_vertical_alignment)
  @switch_control = args[:switch_control] if args.key?(:switch_control)
  @text = args[:text] if args.key?(:text)
  @top_label = args[:top_label] if args.key?(:top_label)
  @top_label_text = args[:top_label_text] if args.key?(:top_label_text)
  @wrap_text = args[:wrap_text] if args.key?(:wrap_text)
end