Class: Google::Apis::ChatV1::GoogleAppsCardV1DecoratedText
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1DecoratedText
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A widget that displays text with optional decorations such as a label above or below the text, an icon in front of the text, a selection widget, or a button after the text. For an example in Google Chat apps, see Display text with decorative text. Google Workspace add-ons and Chat apps:
Instance Attribute Summary collapse
-
#bottom_label ⇒ String
The text that appears below
text. -
#bottom_label_text ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting.
-
#button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click.
-
#content_text ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting.
-
#end_icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Icon
An icon displayed in a widget on a card.
-
#icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Icon
An icon displayed in a widget on a card.
-
#on_click ⇒ Google::Apis::ChatV1::GoogleAppsCardV1OnClick
Represents how to respond when users click an interactive element on a card, such as a button.
-
#start_icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Icon
An icon displayed in a widget on a card.
-
#start_icon_vertical_alignment ⇒ String
Optional.
-
#switch_control ⇒ Google::Apis::ChatV1::GoogleAppsCardV1SwitchControl
Either a toggle-style switch or a checkbox inside a
decoratedTextwidget. -
#text ⇒ String
Required.
-
#top_label ⇒ String
The text that appears above
text. -
#top_label_text ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting.
-
#wrap_text ⇒ Boolean
(also: #wrap_text?)
The wrap text setting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1DecoratedText
constructor
A new instance of GoogleAppsCardV1DecoratedText.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1DecoratedText
Returns a new instance of GoogleAppsCardV1DecoratedText.
2708 2709 2710 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2708 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bottom_label ⇒ String
The text that appears below text. Always wraps.
Corresponds to the JSON property bottomLabel
2581 2582 2583 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2581 def bottom_label @bottom_label end |
#bottom_label_text ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting. For an example in Google Chat
apps, see Add a paragraph of formatted text.
For more information about formatting text, see Formatting text in Google
Chat apps and Formatting text in Google Workspace add-ons.
Google Workspace add-ons and Chat apps:
Corresponds to the JSON property bottomLabelText
2594 2595 2596 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2594 def bottom_label_text @bottom_label_text end |
#button ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Button
A text, icon, or text and icon button that users can click. For an example in
Google Chat apps, see Add a button. To make an image a
clickable button, specify an Image (not an ImageComponent) and set an
onClick action. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property button
2604 2605 2606 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2604 def @button end |
#content_text ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting. For an example in Google Chat
apps, see Add a paragraph of formatted text.
For more information about formatting text, see Formatting text in Google
Chat apps and Formatting text in Google Workspace add-ons.
Google Workspace add-ons and Chat apps:
Corresponds to the JSON property contentText
2617 2618 2619 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2617 def content_text @content_text end |
#end_icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Icon
An icon displayed in a widget on a card. For an example in Google Chat apps,
see Add an icon. Supports built-in and custom icons. Google
Workspace add-ons and Chat apps:
Corresponds to the JSON property endIcon
2628 2629 2630 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2628 def end_icon @end_icon end |
#icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Icon
An icon displayed in a widget on a card. For an example in Google Chat apps,
see Add an icon. Supports built-in and custom icons. Google
Workspace add-ons and Chat apps:
Corresponds to the JSON property icon
2639 2640 2641 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2639 def icon @icon end |
#on_click ⇒ Google::Apis::ChatV1::GoogleAppsCardV1OnClick
Represents how to respond when users click an interactive element on a card,
such as a button. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property onClick
2646 2647 2648 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2646 def on_click @on_click end |
#start_icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Icon
An icon displayed in a widget on a card. For an example in Google Chat apps,
see Add an icon. Supports built-in and custom icons. Google
Workspace add-ons and Chat apps:
Corresponds to the JSON property startIcon
2657 2658 2659 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2657 def start_icon @start_icon end |
#start_icon_vertical_alignment ⇒ String
Optional. Vertical alignment of the start icon. If not set, the icon will be
vertically centered. Google Chat apps:
Corresponds to the JSON property startIconVerticalAlignment
2664 2665 2666 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2664 def start_icon_vertical_alignment @start_icon_vertical_alignment end |
#switch_control ⇒ Google::Apis::ChatV1::GoogleAppsCardV1SwitchControl
Either a toggle-style switch or a checkbox inside a decoratedText widget.
Google Workspace add-ons and Chat apps: Only supported in the decoratedText widget.
Corresponds to the JSON property switchControl
2671 2672 2673 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2671 def switch_control @switch_control end |
#text ⇒ String
Required. The primary text. Supports simple formatting. For more information
about formatting text, see Formatting text in Google Chat apps and
Formatting text in Google Workspace add-ons.
Corresponds to the JSON property text
2680 2681 2682 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2680 def text @text end |
#top_label ⇒ String
The text that appears above text. Always truncates.
Corresponds to the JSON property topLabel
2685 2686 2687 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2685 def top_label @top_label end |
#top_label_text ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting. For an example in Google Chat
apps, see Add a paragraph of formatted text.
For more information about formatting text, see Formatting text in Google
Chat apps and Formatting text in Google Workspace add-ons.
Google Workspace add-ons and Chat apps:
Corresponds to the JSON property topLabelText
2698 2699 2700 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2698 def top_label_text @top_label_text end |
#wrap_text ⇒ Boolean Also known as: wrap_text?
The wrap text setting. If true, the text wraps and displays on multiple
lines. Otherwise, the text is truncated. Only applies to text, not topLabel
and bottomLabel.
Corresponds to the JSON property wrapText
2705 2706 2707 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2705 def wrap_text @wrap_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 |
# File 'lib/google/apis/chat_v1/classes.rb', line 2713 def update!(**args) @bottom_label = args[:bottom_label] if args.key?(:bottom_label) @bottom_label_text = args[:bottom_label_text] if args.key?(:bottom_label_text) @button = args[:button] if args.key?(:button) @content_text = args[:content_text] if args.key?(:content_text) @end_icon = args[:end_icon] if args.key?(:end_icon) @icon = args[:icon] if args.key?(:icon) @on_click = args[:on_click] if args.key?(:on_click) @start_icon = args[:start_icon] if args.key?(:start_icon) @start_icon_vertical_alignment = args[:start_icon_vertical_alignment] if args.key?(:start_icon_vertical_alignment) @switch_control = args[:switch_control] if args.key?(:switch_control) @text = args[:text] if args.key?(:text) @top_label = args[:top_label] if args.key?(:top_label) @top_label_text = args[:top_label_text] if args.key?(:top_label_text) @wrap_text = args[:wrap_text] if args.key?(:wrap_text) end |