Class: Google::Apis::ChatV1::GoogleAppsCardV1ExpressionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents the data that is used to evaluate an expression. Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1ExpressionData

Returns a new instance of GoogleAppsCardV1ExpressionData.



2810
2811
2812
# File 'lib/google/apis/chat_v1/classes.rb', line 2810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsArray<Google::Apis::ChatV1::GoogleAppsCardV1Condition>

The list of conditions that are determined by the expression evaluation result. Corresponds to the JSON property conditions



2793
2794
2795
# File 'lib/google/apis/chat_v1/classes.rb', line 2793

def conditions
  @conditions
end

#event_actionsArray<Google::Apis::ChatV1::GoogleAppsCardV1EventAction>

The list of actions that the ExpressionData can be used. Corresponds to the JSON property eventActions



2798
2799
2800
# File 'lib/google/apis/chat_v1/classes.rb', line 2798

def event_actions
  @event_actions
end

#expressionString

The uncompiled expression. Corresponds to the JSON property expression

Returns:

  • (String)


2803
2804
2805
# File 'lib/google/apis/chat_v1/classes.rb', line 2803

def expression
  @expression
end

#idString

The unique identifier of the ExpressionData. Corresponds to the JSON property id

Returns:

  • (String)


2808
2809
2810
# File 'lib/google/apis/chat_v1/classes.rb', line 2808

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2815
2816
2817
2818
2819
2820
# File 'lib/google/apis/chat_v1/classes.rb', line 2815

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @event_actions = args[:event_actions] if args.key?(:event_actions)
  @expression = args[:expression] if args.key?(:expression)
  @id = args[:id] if args.key?(:id)
end