Class: Google::Apis::ChatV1::GoogleAppsCardV1ExpressionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents the data that is used to evaluate an expression. Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1ExpressionData

Returns a new instance of GoogleAppsCardV1ExpressionData.



2737
2738
2739
# File 'lib/google/apis/chat_v1/classes.rb', line 2737

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsArray<Google::Apis::ChatV1::GoogleAppsCardV1Condition>

The list of conditions that are determined by the expression evaluation result. Corresponds to the JSON property conditions



2720
2721
2722
# File 'lib/google/apis/chat_v1/classes.rb', line 2720

def conditions
  @conditions
end

#event_actionsArray<Google::Apis::ChatV1::GoogleAppsCardV1EventAction>

The list of actions that the ExpressionData can be used. Corresponds to the JSON property eventActions



2725
2726
2727
# File 'lib/google/apis/chat_v1/classes.rb', line 2725

def event_actions
  @event_actions
end

#expressionString

The uncompiled expression. Corresponds to the JSON property expression

Returns:

  • (String)


2730
2731
2732
# File 'lib/google/apis/chat_v1/classes.rb', line 2730

def expression
  @expression
end

#idString

The unique identifier of the ExpressionData. Corresponds to the JSON property id

Returns:

  • (String)


2735
2736
2737
# File 'lib/google/apis/chat_v1/classes.rb', line 2735

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2742
2743
2744
2745
2746
2747
# File 'lib/google/apis/chat_v1/classes.rb', line 2742

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @event_actions = args[:event_actions] if args.key?(:event_actions)
  @expression = args[:expression] if args.key?(:expression)
  @id = args[:id] if args.key?(:id)
end