Class: Google::Apis::ChatV1::GoogleAppsCardV1Icon
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1Icon
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
An icon displayed in a widget on a card. For an example in Google Chat apps, see Add an icon. Supports built-in and custom icons. Google Workspace add-ons and Chat apps:
Instance Attribute Summary collapse
-
#alt_text ⇒ String
Optional.
-
#icon_url ⇒ String
Display a custom icon hosted at an HTTPS URL.
-
#image_type ⇒ String
The crop style applied to the image.
-
#known_icon ⇒ String
Display one of the built-in icons provided by Google Workspace.
-
#material_icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1MaterialIcon
A Google Material Icon, which includes over 2500+ options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1Icon
constructor
A new instance of GoogleAppsCardV1Icon.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1Icon
Returns a new instance of GoogleAppsCardV1Icon.
3192 3193 3194 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alt_text ⇒ String
Optional. A description of the icon used for accessibility. If unspecified,
the default value Button is provided. As a best practice, you should set a
helpful description for what the icon displays, and if applicable, what it
does. For example, A user's account portrait, or Opens a new browser tab
and navigates to the Google Chat developer documentation at https://developers.
google.com/workspace/chat. If the icon is set in a Button, the altText
appears as helper text when the user hovers over the button. However, if the
button also sets text, the icon's altText is ignored.
Corresponds to the JSON property altText
3159 3160 3161 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3159 def alt_text @alt_text end |
#icon_url ⇒ String
Display a custom icon hosted at an HTTPS URL. For example: "iconUrl": "
https://developers.google.com/workspace/chat/images/quickstart-app-avatar.png"
Supported file types include .png and .jpg.
Corresponds to the JSON property iconUrl
3166 3167 3168 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3166 def icon_url @icon_url end |
#image_type ⇒ String
The crop style applied to the image. In some cases, applying a CIRCLE crop
causes the image to be drawn larger than a built-in icon.
Corresponds to the JSON property imageType
3172 3173 3174 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3172 def image_type @image_type end |
#known_icon ⇒ String
Display one of the built-in icons provided by Google Workspace. For example,
to display an airplane icon, specify AIRPLANE. For a bus, specify BUS. For
a full list of supported icons, see built-in icons.
Corresponds to the JSON property knownIcon
3180 3181 3182 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3180 def known_icon @known_icon end |
#material_icon ⇒ Google::Apis::ChatV1::GoogleAppsCardV1MaterialIcon
A Google Material Icon, which includes over
2500+ options. For example, to display a checkbox icon with customized weight and grade, write the
following: ` "name": "check_box", "fill": true, "weight": 300, "grade": -
25 ` Google Chat apps:
Corresponds to the JSON property materialIcon
3190 3191 3192 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3190 def material_icon @material_icon end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3197 3198 3199 3200 3201 3202 3203 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3197 def update!(**args) @alt_text = args[:alt_text] if args.key?(:alt_text) @icon_url = args[:icon_url] if args.key?(:icon_url) @image_type = args[:image_type] if args.key?(:image_type) @known_icon = args[:known_icon] if args.key?(:known_icon) @material_icon = args[:material_icon] if args.key?(:material_icon) end |