Class: Google::Apis::ChatV1::GoogleAppsCardV1Image

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

An image that is specified by a URL and can have an onClick action. For an example, see Add an image. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1Image

Returns a new instance of GoogleAppsCardV1Image.



3046
3047
3048
# File 'lib/google/apis/chat_v1/classes.rb', line 3046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alt_textString

The alternative text of this image that's used for accessibility. Corresponds to the JSON property altText

Returns:

  • (String)


3031
3032
3033
# File 'lib/google/apis/chat_v1/classes.rb', line 3031

def alt_text
  @alt_text
end

#image_urlString

The HTTPS URL that hosts the image. For example: https://developers.google. com/workspace/chat/images/quickstart-app-avatar.png Corresponds to the JSON property imageUrl

Returns:

  • (String)


3037
3038
3039
# File 'lib/google/apis/chat_v1/classes.rb', line 3037

def image_url
  @image_url
end

#on_clickGoogle::Apis::ChatV1::GoogleAppsCardV1OnClick

Represents how to respond when users click an interactive element on a card, such as a button. Google Workspace add-ons and Chat apps: Corresponds to the JSON property onClick



3044
3045
3046
# File 'lib/google/apis/chat_v1/classes.rb', line 3044

def on_click
  @on_click
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3051
3052
3053
3054
3055
# File 'lib/google/apis/chat_v1/classes.rb', line 3051

def update!(**args)
  @alt_text = args[:alt_text] if args.key?(:alt_text)
  @image_url = args[:image_url] if args.key?(:image_url)
  @on_click = args[:on_click] if args.key?(:on_click)
end