Class: Google::Apis::ChatV1::GoogleAppsCardV1Image

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

An image that is specified by a URL and can have an onClick action. For an example, see Add an image. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1Image

Returns a new instance of GoogleAppsCardV1Image.



2973
2974
2975
# File 'lib/google/apis/chat_v1/classes.rb', line 2973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alt_textString

The alternative text of this image that's used for accessibility. Corresponds to the JSON property altText

Returns:

  • (String)


2958
2959
2960
# File 'lib/google/apis/chat_v1/classes.rb', line 2958

def alt_text
  @alt_text
end

#image_urlString

The HTTPS URL that hosts the image. For example: https://developers.google. com/workspace/chat/images/quickstart-app-avatar.png Corresponds to the JSON property imageUrl

Returns:

  • (String)


2964
2965
2966
# File 'lib/google/apis/chat_v1/classes.rb', line 2964

def image_url
  @image_url
end

#on_clickGoogle::Apis::ChatV1::GoogleAppsCardV1OnClick

Represents how to respond when users click an interactive element on a card, such as a button. Google Workspace add-ons and Chat apps: Corresponds to the JSON property onClick



2971
2972
2973
# File 'lib/google/apis/chat_v1/classes.rb', line 2971

def on_click
  @on_click
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2978
2979
2980
2981
2982
# File 'lib/google/apis/chat_v1/classes.rb', line 2978

def update!(**args)
  @alt_text = args[:alt_text] if args.key?(:alt_text)
  @image_url = args[:image_url] if args.key?(:image_url)
  @on_click = args[:on_click] if args.key?(:on_click)
end