Class: Google::Apis::ChatV1::GoogleAppsCardV1MaterialIcon
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1MaterialIcon
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A Google Material Icon, which includes over
2500+ options. For example, to display a checkbox icon with customized weight and grade, write the
following: ` "name": "check_box", "fill": true, "weight": 300, "grade": -
25 ` Google Chat apps:
Instance Attribute Summary collapse
-
#fill ⇒ Boolean
(also: #fill?)
Whether the icon renders as filled.
-
#grade ⇒ Fixnum
Weight and grade affect a symbol’s thickness.
-
#name ⇒ String
The icon name defined in the Google Material Icon, for example,
check_box. -
#weight ⇒ Fixnum
The stroke weight of the icon.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1MaterialIcon
constructor
A new instance of GoogleAppsCardV1MaterialIcon.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1MaterialIcon
Returns a new instance of GoogleAppsCardV1MaterialIcon.
3278 3279 3280 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fill ⇒ Boolean Also known as: fill?
Whether the icon renders as filled. Default value is false. To preview
different icon settings, go to Google Font Icons and adjust the settings under Customize.
Corresponds to the JSON property fill
3250 3251 3252 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3250 def fill @fill end |
#grade ⇒ Fixnum
Weight and grade affect a symbol’s thickness. Adjustments to grade are more
granular than adjustments to weight and have a small impact on the size of the
symbol. Choose from -25, 0, 200. If absent, default value is 0. If any other
value is specified, the default value is used. To preview different icon
settings, go to Google Font Icons and adjust
the settings under Customize.
Corresponds to the JSON property grade
3261 3262 3263 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3261 def grade @grade end |
#name ⇒ String
The icon name defined in the Google Material Icon, for example, check_box. Any invalid names are abandoned and replaced
with empty string and results in the icon failing to render.
Corresponds to the JSON property name
3268 3269 3270 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3268 def name @name end |
#weight ⇒ Fixnum
The stroke weight of the icon. Choose from 100, 200, 300, 400, 500, 600, 700.
If absent, default value is 400. If any other value is specified, the default
value is used. To preview different icon settings, go to Google Font Icons and adjust the settings under Customize.
Corresponds to the JSON property weight
3276 3277 3278 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3276 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3283 3284 3285 3286 3287 3288 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3283 def update!(**args) @fill = args[:fill] if args.key?(:fill) @grade = args[:grade] if args.key?(:grade) @name = args[:name] if args.key?(:name) @weight = args[:weight] if args.key?(:weight) end |