Class: Google::Apis::ChatV1::GoogleAppsCardV1MaterialIcon

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A Google Material Icon, which includes over 2500+ options. For example, to display a checkbox icon with customized weight and grade, write the following: ` "name": "check_box", "fill": true, "weight": 300, "grade": - 25 ` Google Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1MaterialIcon

Returns a new instance of GoogleAppsCardV1MaterialIcon.



3100
3101
3102
# File 'lib/google/apis/chat_v1/classes.rb', line 3100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fillBoolean Also known as: fill?

Whether the icon renders as filled. Default value is false. To preview different icon settings, go to Google Font Icons and adjust the settings under Customize. Corresponds to the JSON property fill

Returns:

  • (Boolean)


3072
3073
3074
# File 'lib/google/apis/chat_v1/classes.rb', line 3072

def fill
  @fill
end

#gradeFixnum

Weight and grade affect a symbol’s thickness. Adjustments to grade are more granular than adjustments to weight and have a small impact on the size of the symbol. Choose from -25, 0, 200. If absent, default value is 0. If any other value is specified, the default value is used. To preview different icon settings, go to Google Font Icons and adjust the settings under Customize. Corresponds to the JSON property grade

Returns:

  • (Fixnum)


3083
3084
3085
# File 'lib/google/apis/chat_v1/classes.rb', line 3083

def grade
  @grade
end

#nameString

The icon name defined in the Google Material Icon, for example, check_box. Any invalid names are abandoned and replaced with empty string and results in the icon failing to render. Corresponds to the JSON property name

Returns:

  • (String)


3090
3091
3092
# File 'lib/google/apis/chat_v1/classes.rb', line 3090

def name
  @name
end

#weightFixnum

The stroke weight of the icon. Choose from 100, 200, 300, 400, 500, 600, 700. If absent, default value is 400. If any other value is specified, the default value is used. To preview different icon settings, go to Google Font Icons and adjust the settings under Customize. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


3098
3099
3100
# File 'lib/google/apis/chat_v1/classes.rb', line 3098

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3105
3106
3107
3108
3109
3110
# File 'lib/google/apis/chat_v1/classes.rb', line 3105

def update!(**args)
  @fill = args[:fill] if args.key?(:fill)
  @grade = args[:grade] if args.key?(:grade)
  @name = args[:name] if args.key?(:name)
  @weight = args[:weight] if args.key?(:weight)
end