Class: Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1NestedWidget
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A list of widgets that can be displayed in a containing layout, such as a
CarouselCard. Google Chat apps
:
Instance Attribute Summary collapse
-
#button_list ⇒ Google::Apis::ChatV1::GoogleAppsCardV1ButtonList
A list of buttons layed out horizontally.
-
#image ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Image
An image that is specified by a URL and can have an
onClickaction. -
#text_paragraph ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1NestedWidget
constructor
A new instance of GoogleAppsCardV1NestedWidget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1NestedWidget
Returns a new instance of GoogleAppsCardV1NestedWidget.
3148 3149 3150 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#button_list ⇒ Google::Apis::ChatV1::GoogleAppsCardV1ButtonList
A list of buttons layed out horizontally. For an example in Google Chat apps,
see Add a button. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property buttonList
3125 3126 3127 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3125 def @button_list end |
#image ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Image
An image that is specified by a URL and can have an onClick action. For an
example, see Add an image. Google Workspace add-ons and Chat apps:
Corresponds to the JSON property image
3133 3134 3135 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3133 def image @image end |
#text_paragraph ⇒ Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
A paragraph of text that supports formatting. For an example in Google Chat
apps, see Add a paragraph of formatted text.
For more information about formatting text, see Formatting text in Google
Chat apps and Formatting text in Google Workspace add-ons.
Google Workspace add-ons and Chat apps:
Corresponds to the JSON property textParagraph
3146 3147 3148 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3146 def text_paragraph @text_paragraph end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3153 3154 3155 3156 3157 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3153 def update!(**args) @button_list = args[:button_list] if args.key?(:button_list) @image = args[:image] if args.key?(:image) @text_paragraph = args[:text_paragraph] if args.key?(:text_paragraph) end |