Class: Google::Apis::ChatV1::GoogleAppsCardV1OnClick

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents how to respond when users click an interactive element on a card, such as a button. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1OnClick

Returns a new instance of GoogleAppsCardV1OnClick.



3229
3230
3231
# File 'lib/google/apis/chat_v1/classes.rb', line 3229

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::ChatV1::GoogleAppsCardV1Action

An action that describes the behavior when the form is submitted. For example, you can invoke an Apps Script script to handle the form. If the action is triggered, the form values are sent to the server. Google Workspace add-ons and Chat apps: Corresponds to the JSON property action



3172
3173
3174
# File 'lib/google/apis/chat_v1/classes.rb', line 3172

def action
  @action
end

#cardGoogle::Apis::ChatV1::GoogleAppsCardV1Card

A card interface displayed in a Google Chat message or Google Workspace add-on. Cards support a defined layout, interactive UI elements like buttons, and rich media like images. Use cards to present detailed information, gather information from users, and guide users to take a next step. Card builder To learn how to build cards, see the following documentation: * For Google Chat apps, see Design the components of a card or dialog. * For Google Workspace add-ons, see Card- based interfaces. Note: You can add up to 100 widgets per card. Any widgets beyond this limit are ignored. This limit applies to both card messages and dialogs in Google Chat apps, and to cards in Google Workspace add-ons. Example: Card message for a Google Chat app Example contact card To create the sample card message in Google Chat, use the following JSON: ` "cardsV2": [ ` " cardId": "unique-card-id", "card": ` "header": ` "title": "Sasha", "subtitle": "Software Engineer", "imageUrl": "https://developers.google.com/workspace/chat/ images/quickstart-app-avatar.png", "imageType": "CIRCLE", "imageAltText": " Avatar for Sasha" `, "sections": [ ` "header": "Contact Info", "collapsible": true, "uncollapsibleWidgetsCount": 1, "widgets": [ ` "decoratedText": ` " startIcon": ` "knownIcon": "EMAIL" `, "text": "sasha@example.com" ` `, ` " decoratedText": ` "startIcon": ` "knownIcon": "PERSON" `, "text": "Online" ` `, ` "decoratedText": ` "startIcon": ` "knownIcon": "PHONE" `, "text": "+1 (555) 555-1234" ` `, ` "buttonList": ` "buttons": [ ` "text": "Share", "onClick": ` " openLink": ` "url": "https://example.com/share" ` ` `, ` "text": "Edit", " onClick": ` "action": ` "function": "goToView", "parameters": [ ` "key": " viewType", "value": "EDIT" ` ] ` ` ` ] ` ` ] ` ] ` ` ] ` Corresponds to the JSON property card



3203
3204
3205
# File 'lib/google/apis/chat_v1/classes.rb', line 3203

def card
  @card
end

An action that describes the behavior when the form is submitted. For example, you can invoke an Apps Script script to handle the form. If the action is triggered, the form values are sent to the server. Google Workspace add-ons and Chat apps: Corresponds to the JSON property openDynamicLinkAction



3211
3212
3213
# File 'lib/google/apis/chat_v1/classes.rb', line 3211

def open_dynamic_link_action
  @open_dynamic_link_action
end

Represents an onClick event that opens a hyperlink. Google Workspace add- ons and Chat apps: Corresponds to the JSON property openLink



3217
3218
3219
# File 'lib/google/apis/chat_v1/classes.rb', line 3217

def open_link
  @open_link
end

#overflow_menuGoogle::Apis::ChatV1::GoogleAppsCardV1OverflowMenu

A widget that presents a pop-up menu with one or more actions that users can invoke. For example, showing non-primary actions in a card. You can use this widget when actions don't fit in the available space. To use, specify this widget in the OnClick action of widgets that support it. For example, in a Button. Google Workspace add-ons and Chat apps: Corresponds to the JSON property overflowMenu



3227
3228
3229
# File 'lib/google/apis/chat_v1/classes.rb', line 3227

def overflow_menu
  @overflow_menu
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3234
3235
3236
3237
3238
3239
3240
# File 'lib/google/apis/chat_v1/classes.rb', line 3234

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @card = args[:card] if args.key?(:card)
  @open_dynamic_link_action = args[:open_dynamic_link_action] if args.key?(:open_dynamic_link_action)
  @open_link = args[:open_link] if args.key?(:open_link)
  @overflow_menu = args[:overflow_menu] if args.key?(:overflow_menu)
end