Class: Google::Apis::ChatV1::GoogleAppsCardV1OpenLink

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents an onClick event that opens a hyperlink. Google Workspace add- ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1OpenLink

Returns a new instance of GoogleAppsCardV1OpenLink.



3266
3267
3268
# File 'lib/google/apis/chat_v1/classes.rb', line 3266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#on_closeString

Whether the client forgets about a link after opening it, or observes it until the window closes. Google Workspace add-ons: Corresponds to the JSON property onClose

Returns:

  • (String)


3253
3254
3255
# File 'lib/google/apis/chat_v1/classes.rb', line 3253

def on_close
  @on_close
end

#open_asString

How to open a link. Google Workspace add-ons: Corresponds to the JSON property openAs

Returns:

  • (String)


3259
3260
3261
# File 'lib/google/apis/chat_v1/classes.rb', line 3259

def open_as
  @open_as
end

#urlString

The URL to open. HTTP URLs are converted to HTTPS. Corresponds to the JSON property url

Returns:

  • (String)


3264
3265
3266
# File 'lib/google/apis/chat_v1/classes.rb', line 3264

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3271
3272
3273
3274
3275
# File 'lib/google/apis/chat_v1/classes.rb', line 3271

def update!(**args)
  @on_close = args[:on_close] if args.key?(:on_close)
  @open_as = args[:open_as] if args.key?(:open_as)
  @url = args[:url] if args.key?(:url)
end