Class: Google::Apis::ChatV1::GoogleAppsCardV1Section

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A section contains a collection of widgets that are rendered vertically in the order that they're specified. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1Section

Returns a new instance of GoogleAppsCardV1Section.



3506
3507
3508
# File 'lib/google/apis/chat_v1/classes.rb', line 3506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collapse_controlGoogle::Apis::ChatV1::GoogleAppsCardV1CollapseControl

Represent an expand and collapse control. Google Workspace add-ons and Chat apps: Corresponds to the JSON property collapseControl



3462
3463
3464
# File 'lib/google/apis/chat_v1/classes.rb', line 3462

def collapse_control
  @collapse_control
end

#collapsibleBoolean Also known as: collapsible?

Indicates whether this section is collapsible. Collapsible sections hide some or all widgets, but users can expand the section to reveal the hidden widgets by clicking Show more. Users can hide the widgets again by clicking Show less. To determine which widgets are hidden, specify uncollapsibleWidgetsCount. Corresponds to the JSON property collapsible

Returns:

  • (Boolean)


3471
3472
3473
# File 'lib/google/apis/chat_v1/classes.rb', line 3471

def collapsible
  @collapsible
end

#headerString

Text that appears at the top of a section. Supports simple HTML formatted text. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Corresponds to the JSON property header

Returns:

  • (String)


3481
3482
3483
# File 'lib/google/apis/chat_v1/classes.rb', line 3481

def header
  @header
end

#idString

A unique ID assigned to the section that's used to identify the section to be mutated. The ID has a character limit of 64 characters and should be in the format of [a-zA-Z0-9-]+. Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps. Corresponds to the JSON property id

Returns:

  • (String)


3489
3490
3491
# File 'lib/google/apis/chat_v1/classes.rb', line 3489

def id
  @id
end

#uncollapsible_widgets_countFixnum

The number of uncollapsible widgets which remain visible even when a section is collapsed. For example, when a section contains five widgets and the uncollapsibleWidgetsCount is set to 2, the first two widgets are always shown and the last three are collapsed by default. The uncollapsibleWidgetsCount is taken into account only when collapsible is true. Corresponds to the JSON property uncollapsibleWidgetsCount

Returns:

  • (Fixnum)


3499
3500
3501
# File 'lib/google/apis/chat_v1/classes.rb', line 3499

def uncollapsible_widgets_count
  @uncollapsible_widgets_count
end

#widgetsArray<Google::Apis::ChatV1::GoogleAppsCardV1Widget>

All the widgets in the section. Must contain at least one widget. Corresponds to the JSON property widgets



3504
3505
3506
# File 'lib/google/apis/chat_v1/classes.rb', line 3504

def widgets
  @widgets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3511
3512
3513
3514
3515
3516
3517
3518
# File 'lib/google/apis/chat_v1/classes.rb', line 3511

def update!(**args)
  @collapse_control = args[:collapse_control] if args.key?(:collapse_control)
  @collapsible = args[:collapsible] if args.key?(:collapsible)
  @header = args[:header] if args.key?(:header)
  @id = args[:id] if args.key?(:id)
  @uncollapsible_widgets_count = args[:uncollapsible_widgets_count] if args.key?(:uncollapsible_widgets_count)
  @widgets = args[:widgets] if args.key?(:widgets)
end