Class: Google::Apis::ChatV1::GoogleAppsCardV1SelectionItem
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1SelectionItem
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
An item that users can select in a selection input, such as a checkbox or switch. Supports up to 100 items. Google Workspace add-ons and Chat apps:
Instance Attribute Summary collapse
-
#bottom_text ⇒ String
For multiselect menus, a text description or label that's displayed below the item's
textfield. -
#selected ⇒ Boolean
(also: #selected?)
Whether the item is selected by default.
-
#start_icon_uri ⇒ String
Corresponds to the JSON property
startIconUri. -
#text ⇒ String
The text that identifies or describes the item to users.
-
#value ⇒ String
The value associated with this item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1SelectionItem
constructor
A new instance of GoogleAppsCardV1SelectionItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1SelectionItem
Returns a new instance of GoogleAppsCardV1SelectionItem.
3868 3869 3870 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bottom_text ⇒ String
For multiselect menus, a text description or label that's displayed below the
item's text field.
Corresponds to the JSON property bottomText
3841 3842 3843 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3841 def bottom_text @bottom_text end |
#selected ⇒ Boolean Also known as: selected?
Whether the item is selected by default. If the selection input only accepts
one value (such as for radio buttons or a dropdown menu), only set this field
for one item.
Corresponds to the JSON property selected
3848 3849 3850 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3848 def selected @selected end |
#start_icon_uri ⇒ String
Corresponds to the JSON property startIconUri
3854 3855 3856 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3854 def start_icon_uri @start_icon_uri end |
#text ⇒ String
The text that identifies or describes the item to users.
Corresponds to the JSON property text
3859 3860 3861 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3859 def text @text end |
#value ⇒ String
The value associated with this item. The client should use this as a form
input value. For details about working with form inputs, see Receive form
data.
Corresponds to the JSON property value
3866 3867 3868 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3866 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3873 3874 3875 3876 3877 3878 3879 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3873 def update!(**args) @bottom_text = args[:bottom_text] if args.key?(:bottom_text) @selected = args[:selected] if args.key?(:selected) @start_icon_uri = args[:start_icon_uri] if args.key?(:start_icon_uri) @text = args[:text] if args.key?(:text) @value = args[:value] if args.key?(:value) end |