Class: Google::Apis::ChatV1::GoogleAppsCardV1SelectionItem

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

An item that users can select in a selection input, such as a checkbox or switch. Supports up to 100 items. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1SelectionItem

Returns a new instance of GoogleAppsCardV1SelectionItem.



3788
3789
3790
# File 'lib/google/apis/chat_v1/classes.rb', line 3788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bottom_textString

For multiselect menus, a text description or label that's displayed below the item's text field. Corresponds to the JSON property bottomText

Returns:

  • (String)


3761
3762
3763
# File 'lib/google/apis/chat_v1/classes.rb', line 3761

def bottom_text
  @bottom_text
end

#selectedBoolean Also known as: selected?

Whether the item is selected by default. If the selection input only accepts one value (such as for radio buttons or a dropdown menu), only set this field for one item. Corresponds to the JSON property selected

Returns:

  • (Boolean)


3768
3769
3770
# File 'lib/google/apis/chat_v1/classes.rb', line 3768

def selected
  @selected
end

#start_icon_uriString

Corresponds to the JSON property startIconUri

Returns:

  • (String)


3774
3775
3776
# File 'lib/google/apis/chat_v1/classes.rb', line 3774

def start_icon_uri
  @start_icon_uri
end

#textString

The text that identifies or describes the item to users. Corresponds to the JSON property text

Returns:

  • (String)


3779
3780
3781
# File 'lib/google/apis/chat_v1/classes.rb', line 3779

def text
  @text
end

#valueString

The value associated with this item. The client should use this as a form input value. For details about working with form inputs, see Receive form data. Corresponds to the JSON property value

Returns:

  • (String)


3786
3787
3788
# File 'lib/google/apis/chat_v1/classes.rb', line 3786

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3793
3794
3795
3796
3797
3798
3799
# File 'lib/google/apis/chat_v1/classes.rb', line 3793

def update!(**args)
  @bottom_text = args[:bottom_text] if args.key?(:bottom_text)
  @selected = args[:selected] if args.key?(:selected)
  @start_icon_uri = args[:start_icon_uri] if args.key?(:start_icon_uri)
  @text = args[:text] if args.key?(:text)
  @value = args[:value] if args.key?(:value)
end