Class: Google::Apis::ChatV1::GoogleAppsCardV1Suggestions
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1Suggestions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Suggested values that users can enter. These values appear when users click
inside the text input field. As users type, the suggested values dynamically
filter to match what the users have typed. For example, a text input field for
programming language might suggest Java, JavaScript, Python, and C++. When
users start typing Jav, the list of suggestions filters to show Java and
JavaScript. Suggested values help guide users to enter values that your app
can make sense of. When referring to JavaScript, some users might enter
javascript and others java script. Suggesting JavaScript can standardize
how users interact with your app. When specified, TextInput.type is always
SINGLE_LINE, even if it's set to MULTIPLE_LINE. Google Workspace add-ons
and Chat apps:
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1SuggestionItem>
A list of suggestions used for autocomplete recommendations in text input fields.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1Suggestions
constructor
A new instance of GoogleAppsCardV1Suggestions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1Suggestions
Returns a new instance of GoogleAppsCardV1Suggestions.
3738 3739 3740 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3738 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::ChatV1::GoogleAppsCardV1SuggestionItem>
A list of suggestions used for autocomplete recommendations in text input
fields.
Corresponds to the JSON property items
3736 3737 3738 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3736 def items @items end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3743 3744 3745 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3743 def update!(**args) @items = args[:items] if args.key?(:items) end |