Class: Google::Apis::ChatV1::GoogleAppsCardV1SwitchControl

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Either a toggle-style switch or a checkbox inside a decoratedText widget. Google Workspace add-ons and Chat apps: Only supported in the decoratedText widget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1SwitchControl

Returns a new instance of GoogleAppsCardV1SwitchControl.



3894
3895
3896
# File 'lib/google/apis/chat_v1/classes.rb', line 3894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#control_typeString

How the switch appears in the user interface. Google Workspace add-ons and Chat apps: Corresponds to the JSON property controlType

Returns:

  • (String)


3864
3865
3866
# File 'lib/google/apis/chat_v1/classes.rb', line 3864

def control_type
  @control_type
end

#nameString

The name by which the switch widget is identified in a form input event. For details about working with form inputs, see Receive form data. Corresponds to the JSON property name

Returns:

  • (String)


3871
3872
3873
# File 'lib/google/apis/chat_v1/classes.rb', line 3871

def name
  @name
end

#on_change_actionGoogle::Apis::ChatV1::GoogleAppsCardV1Action

An action that describes the behavior when the form is submitted. For example, you can invoke an Apps Script script to handle the form. If the action is triggered, the form values are sent to the server. Google Workspace add-ons and Chat apps: Corresponds to the JSON property onChangeAction



3879
3880
3881
# File 'lib/google/apis/chat_v1/classes.rb', line 3879

def on_change_action
  @on_change_action
end

#selectedBoolean Also known as: selected?

When true, the switch is selected. Corresponds to the JSON property selected

Returns:

  • (Boolean)


3884
3885
3886
# File 'lib/google/apis/chat_v1/classes.rb', line 3884

def selected
  @selected
end

#valueString

The value entered by a user, returned as part of a form input event. For details about working with form inputs, see Receive form data. Corresponds to the JSON property value

Returns:

  • (String)


3892
3893
3894
# File 'lib/google/apis/chat_v1/classes.rb', line 3892

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3899
3900
3901
3902
3903
3904
3905
# File 'lib/google/apis/chat_v1/classes.rb', line 3899

def update!(**args)
  @control_type = args[:control_type] if args.key?(:control_type)
  @name = args[:name] if args.key?(:name)
  @on_change_action = args[:on_change_action] if args.key?(:on_change_action)
  @selected = args[:selected] if args.key?(:selected)
  @value = args[:value] if args.key?(:value)
end