Class: Google::Apis::ChatV1::GoogleAppsCardV1SwitchControl
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1SwitchControl
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Either a toggle-style switch or a checkbox inside a decoratedText widget.
Google Workspace add-ons and Chat apps: Only supported in the decoratedText widget.
Instance Attribute Summary collapse
-
#control_type ⇒ String
How the switch appears in the user interface.
-
#name ⇒ String
The name by which the switch widget is identified in a form input event.
-
#on_change_action ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Action
An action that describes the behavior when the form is submitted.
-
#selected ⇒ Boolean
(also: #selected?)
When
true, the switch is selected. -
#value ⇒ String
The value entered by a user, returned as part of a form input event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1SwitchControl
constructor
A new instance of GoogleAppsCardV1SwitchControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1SwitchControl
Returns a new instance of GoogleAppsCardV1SwitchControl.
3788 3789 3790 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3788 def initialize(**args) update!(**args) end |
Instance Attribute Details
#control_type ⇒ String
How the switch appears in the user interface. Google Workspace add-ons and
Chat apps:
Corresponds to the JSON property controlType
3758 3759 3760 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3758 def control_type @control_type end |
#name ⇒ String
The name by which the switch widget is identified in a form input event. For
details about working with form inputs, see Receive form data.
Corresponds to the JSON property name
3765 3766 3767 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3765 def name @name end |
#on_change_action ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Action
An action that describes the behavior when the form is submitted. For example,
you can invoke an Apps Script script to handle the form. If the action is
triggered, the form values are sent to the server. Google Workspace add-ons
and Chat apps:
Corresponds to the JSON property onChangeAction
3773 3774 3775 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3773 def on_change_action @on_change_action end |
#selected ⇒ Boolean Also known as: selected?
When true, the switch is selected.
Corresponds to the JSON property selected
3778 3779 3780 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3778 def selected @selected end |
#value ⇒ String
The value entered by a user, returned as part of a form input event. For
details about working with form inputs, see Receive form data.
Corresponds to the JSON property value
3786 3787 3788 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3786 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3793 3794 3795 3796 3797 3798 3799 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3793 def update!(**args) @control_type = args[:control_type] if args.key?(:control_type) @name = args[:name] if args.key?(:name) @on_change_action = args[:on_change_action] if args.key?(:on_change_action) @selected = args[:selected] if args.key?(:selected) @value = args[:value] if args.key?(:value) end |