Class: Google::Apis::ChatV1::GoogleAppsCardV1SwitchControl
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1SwitchControl
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Either a toggle-style switch or a checkbox inside a decoratedText widget.
Google Workspace add-ons and Chat apps: Only supported in the decoratedText widget.
Instance Attribute Summary collapse
-
#control_type ⇒ String
How the switch appears in the user interface.
-
#name ⇒ String
The name by which the switch widget is identified in a form input event.
-
#on_change_action ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Action
An action that describes the behavior when the form is submitted.
-
#selected ⇒ Boolean
(also: #selected?)
When
true, the switch is selected. -
#value ⇒ String
The value entered by a user, returned as part of a form input event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1SwitchControl
constructor
A new instance of GoogleAppsCardV1SwitchControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1SwitchControl
Returns a new instance of GoogleAppsCardV1SwitchControl.
3789 3790 3791 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3789 def initialize(**args) update!(**args) end |
Instance Attribute Details
#control_type ⇒ String
How the switch appears in the user interface. Google Workspace add-ons and
Chat apps:
Corresponds to the JSON property controlType
3759 3760 3761 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3759 def control_type @control_type end |
#name ⇒ String
The name by which the switch widget is identified in a form input event. For
details about working with form inputs, see Receive form data.
Corresponds to the JSON property name
3766 3767 3768 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3766 def name @name end |
#on_change_action ⇒ Google::Apis::ChatV1::GoogleAppsCardV1Action
An action that describes the behavior when the form is submitted. For example,
you can invoke an Apps Script script to handle the form. If the action is
triggered, the form values are sent to the server. Google Workspace add-ons
and Chat apps:
Corresponds to the JSON property onChangeAction
3774 3775 3776 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3774 def on_change_action @on_change_action end |
#selected ⇒ Boolean Also known as: selected?
When true, the switch is selected.
Corresponds to the JSON property selected
3779 3780 3781 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3779 def selected @selected end |
#value ⇒ String
The value entered by a user, returned as part of a form input event. For
details about working with form inputs, see Receive form data.
Corresponds to the JSON property value
3787 3788 3789 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3787 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3794 3795 3796 3797 3798 3799 3800 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3794 def update!(**args) @control_type = args[:control_type] if args.key?(:control_type) @name = args[:name] if args.key?(:name) @on_change_action = args[:on_change_action] if args.key?(:on_change_action) @selected = args[:selected] if args.key?(:selected) @value = args[:value] if args.key?(:value) end |