Class: Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::GoogleAppsCardV1TextParagraph
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A paragraph of text that supports formatting. For an example in Google Chat apps, see Add a paragraph of formatted text. For more information about formatting text, see Formatting text in Google Chat apps and Formatting text in Google Workspace add-ons. Google Workspace add-ons and Chat apps:
Instance Attribute Summary collapse
-
#max_lines ⇒ Fixnum
The maximum number of lines of text that are displayed in the widget.
-
#text ⇒ String
The text that's shown in the widget.
-
#text_syntax ⇒ String
The syntax of the text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCardV1TextParagraph
constructor
A new instance of GoogleAppsCardV1TextParagraph.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCardV1TextParagraph
Returns a new instance of GoogleAppsCardV1TextParagraph.
3886 3887 3888 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_lines ⇒ Fixnum
The maximum number of lines of text that are displayed in the widget. If the
text exceeds the specified maximum number of lines, the excess content is
concealed behind a show more button. If the text is equal or shorter than
the specified maximum number of lines, a show more button isn't displayed.
The default value is 0, in which case all context is displayed. Negative
values are ignored.
Corresponds to the JSON property maxLines
3873 3874 3875 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3873 def max_lines @max_lines end |
#text ⇒ String
The text that's shown in the widget.
Corresponds to the JSON property text
3878 3879 3880 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3878 def text @text end |
#text_syntax ⇒ String
The syntax of the text. If not set, the text is rendered as HTML. Google Chat
apps:
Corresponds to the JSON property textSyntax
3884 3885 3886 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3884 def text_syntax @text_syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3891 3892 3893 3894 3895 |
# File 'lib/google/apis/chat_v1/classes.rb', line 3891 def update!(**args) @max_lines = args[:max_lines] if args.key?(:max_lines) @text = args[:text] if args.key?(:text) @text_syntax = args[:text_syntax] if args.key?(:text_syntax) end |