Class: Google::Apis::ChatV1::GoogleAppsCardV1Validation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents the necessary data for validating the widget it's attached to. Google Workspace add-ons and Chat apps:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCardV1Validation

Returns a new instance of GoogleAppsCardV1Validation.



3958
3959
3960
# File 'lib/google/apis/chat_v1/classes.rb', line 3958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#character_limitFixnum

Specify the character limit for text input widgets. Note that this is only used for text input and is ignored for other widgets. Google Workspace add- ons and Chat apps: Corresponds to the JSON property characterLimit

Returns:

  • (Fixnum)


3950
3951
3952
# File 'lib/google/apis/chat_v1/classes.rb', line 3950

def character_limit
  @character_limit
end

#input_typeString

Specify the type of the input widgets. Google Workspace add-ons and Chat apps: Corresponds to the JSON property inputType

Returns:

  • (String)


3956
3957
3958
# File 'lib/google/apis/chat_v1/classes.rb', line 3956

def input_type
  @input_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3963
3964
3965
3966
# File 'lib/google/apis/chat_v1/classes.rb', line 3963

def update!(**args)
  @character_limit = args[:character_limit] if args.key?(:character_limit)
  @input_type = args[:input_type] if args.key?(:input_type)
end