Class: Google::Apis::ChatV1::HostAppDataSourceMarkup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A data source from a Google Workspace application. The data source populates available items for a widget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostAppDataSourceMarkup

Returns a new instance of HostAppDataSourceMarkup.



4344
4345
4346
# File 'lib/google/apis/chat_v1/classes.rb', line 4344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chat_data_sourceGoogle::Apis::ChatV1::ChatClientDataSourceMarkup

For a SelectionInput widget that uses a multiselect menu, a data source from Google Chat. The data source populates selection items for the multiselect menu. For example, a user can select Google Chat spaces that they're a member of. Google Chat apps: Corresponds to the JSON property chatDataSource



4335
4336
4337
# File 'lib/google/apis/chat_v1/classes.rb', line 4335

def chat_data_source
  @chat_data_source
end

#workflow_data_sourceGoogle::Apis::ChatV1::WorkflowDataSourceMarkup

  • Only supported by Google Workspace Workflow, but not Google Chat apps or Google Workspace add-ons. In a TextInput or SelectionInput widget with MULTI_SELECT type or a DateTimePicker, provide data source from Google. Corresponds to the JSON property workflowDataSource


4342
4343
4344
# File 'lib/google/apis/chat_v1/classes.rb', line 4342

def workflow_data_source
  @workflow_data_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4349
4350
4351
4352
# File 'lib/google/apis/chat_v1/classes.rb', line 4349

def update!(**args)
  @chat_data_source = args[:chat_data_source] if args.key?(:chat_data_source)
  @workflow_data_source = args[:workflow_data_source] if args.key?(:workflow_data_source)
end