Class: Google::Apis::ChatV1::Image

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

An image that's specified by a URL and can have an onclick action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Image

Returns a new instance of Image.



4503
4504
4505
# File 'lib/google/apis/chat_v1/classes.rb', line 4503

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_ratioFloat

The aspect ratio of this image (width and height). This field lets you reserve the right height for the image while waiting for it to load. It's not meant to override the built-in aspect ratio of the image. If unset, the server fills it by prefetching the image. Corresponds to the JSON property aspectRatio

Returns:

  • (Float)


4491
4492
4493
# File 'lib/google/apis/chat_v1/classes.rb', line 4491

def aspect_ratio
  @aspect_ratio
end

#image_urlString

The URL of the image. Corresponds to the JSON property imageUrl

Returns:

  • (String)


4496
4497
4498
# File 'lib/google/apis/chat_v1/classes.rb', line 4496

def image_url
  @image_url
end

#on_clickGoogle::Apis::ChatV1::OnClick

An onclick action (for example, open a link). Corresponds to the JSON property onClick



4501
4502
4503
# File 'lib/google/apis/chat_v1/classes.rb', line 4501

def on_click
  @on_click
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4508
4509
4510
4511
4512
# File 'lib/google/apis/chat_v1/classes.rb', line 4508

def update!(**args)
  @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio)
  @image_url = args[:image_url] if args.key?(:image_url)
  @on_click = args[:on_click] if args.key?(:on_click)
end