Class: Google::Apis::ChatV1::Inputs

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Types of data that users can input on cards or dialogs. The input type depends on the type of values that the widget accepts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Inputs

Returns a new instance of Inputs.



4686
4687
4688
# File 'lib/google/apis/chat_v1/classes.rb', line 4686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_inputGoogle::Apis::ChatV1::DateInput

Date input values. Corresponds to the JSON property dateInput



4667
4668
4669
# File 'lib/google/apis/chat_v1/classes.rb', line 4667

def date_input
  @date_input
end

#date_time_inputGoogle::Apis::ChatV1::DateTimeInput

Date and time input values. Corresponds to the JSON property dateTimeInput



4672
4673
4674
# File 'lib/google/apis/chat_v1/classes.rb', line 4672

def date_time_input
  @date_time_input
end

#string_inputsGoogle::Apis::ChatV1::StringInputs

Input parameter for regular widgets. For single-valued widgets, it is a single value list. For multi-valued widgets, such as checkbox, all the values are presented. Corresponds to the JSON property stringInputs



4679
4680
4681
# File 'lib/google/apis/chat_v1/classes.rb', line 4679

def string_inputs
  @string_inputs
end

#time_inputGoogle::Apis::ChatV1::TimeInput

Time input values. Corresponds to the JSON property timeInput



4684
4685
4686
# File 'lib/google/apis/chat_v1/classes.rb', line 4684

def time_input
  @time_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4691
4692
4693
4694
4695
4696
# File 'lib/google/apis/chat_v1/classes.rb', line 4691

def update!(**args)
  @date_input = args[:date_input] if args.key?(:date_input)
  @date_time_input = args[:date_time_input] if args.key?(:date_time_input)
  @string_inputs = args[:string_inputs] if args.key?(:string_inputs)
  @time_input = args[:time_input] if args.key?(:time_input)
end