Class: Google::Apis::ChatV1::Inputs

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Types of data that users can input on cards or dialogs. The input type depends on the type of values that the widget accepts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Inputs

Returns a new instance of Inputs.



4455
4456
4457
# File 'lib/google/apis/chat_v1/classes.rb', line 4455

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_inputGoogle::Apis::ChatV1::DateInput

Date input values. Corresponds to the JSON property dateInput



4436
4437
4438
# File 'lib/google/apis/chat_v1/classes.rb', line 4436

def date_input
  @date_input
end

#date_time_inputGoogle::Apis::ChatV1::DateTimeInput

Date and time input values. Corresponds to the JSON property dateTimeInput



4441
4442
4443
# File 'lib/google/apis/chat_v1/classes.rb', line 4441

def date_time_input
  @date_time_input
end

#string_inputsGoogle::Apis::ChatV1::StringInputs

Input parameter for regular widgets. For single-valued widgets, it is a single value list. For multi-valued widgets, such as checkbox, all the values are presented. Corresponds to the JSON property stringInputs



4448
4449
4450
# File 'lib/google/apis/chat_v1/classes.rb', line 4448

def string_inputs
  @string_inputs
end

#time_inputGoogle::Apis::ChatV1::TimeInput

Time input values. Corresponds to the JSON property timeInput



4453
4454
4455
# File 'lib/google/apis/chat_v1/classes.rb', line 4453

def time_input
  @time_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4460
4461
4462
4463
4464
4465
# File 'lib/google/apis/chat_v1/classes.rb', line 4460

def update!(**args)
  @date_input = args[:date_input] if args.key?(:date_input)
  @date_time_input = args[:date_time_input] if args.key?(:date_time_input)
  @string_inputs = args[:string_inputs] if args.key?(:string_inputs)
  @time_input = args[:time_input] if args.key?(:time_input)
end