Class: Google::Apis::ChatV1::KeyValue
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::KeyValue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A UI element contains a key (label) and a value (content). This element can
also contain some actions such as onclick button.
Instance Attribute Summary collapse
-
#bottom_label ⇒ String
The text of the bottom label.
-
#button ⇒ Google::Apis::ChatV1::Button
A button.
-
#content ⇒ String
The text of the content.
-
#content_multiline ⇒ Boolean
(also: #content_multiline?)
If the content should be multiline.
-
#icon ⇒ String
An enum value that's replaced by the Chat API with the corresponding icon image.
-
#icon_url ⇒ String
The icon specified by a URL.
-
#on_click ⇒ Google::Apis::ChatV1::OnClick
An
onclickaction (for example, open a link). -
#top_label ⇒ String
The text of the top label.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyValue
constructor
A new instance of KeyValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyValue
Returns a new instance of KeyValue.
4838 4839 4840 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bottom_label ⇒ String
The text of the bottom label. Formatted text supported. For more information
about formatting text, see Formatting text in Google Chat apps and
Formatting text in Google Workspace Add-ons.
Corresponds to the JSON property bottomLabel
4791 4792 4793 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4791 def bottom_label @bottom_label end |
#button ⇒ Google::Apis::ChatV1::Button
A button. Can be a text button or an image button.
Corresponds to the JSON property button
4796 4797 4798 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4796 def @button end |
#content ⇒ String
The text of the content. Formatted text supported and always required. For
more information about formatting text, see Formatting text in Google Chat
apps and Formatting text in Google Workspace Add-ons.
Corresponds to the JSON property content
4805 4806 4807 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4805 def content @content end |
#content_multiline ⇒ Boolean Also known as: content_multiline?
If the content should be multiline.
Corresponds to the JSON property contentMultiline
4810 4811 4812 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4810 def content_multiline @content_multiline end |
#icon ⇒ String
An enum value that's replaced by the Chat API with the corresponding icon
image.
Corresponds to the JSON property icon
4817 4818 4819 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4817 def icon @icon end |
#icon_url ⇒ String
The icon specified by a URL.
Corresponds to the JSON property iconUrl
4822 4823 4824 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4822 def icon_url @icon_url end |
#on_click ⇒ Google::Apis::ChatV1::OnClick
An onclick action (for example, open a link).
Corresponds to the JSON property onClick
4827 4828 4829 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4827 def on_click @on_click end |
#top_label ⇒ String
The text of the top label. Formatted text supported. For more information
about formatting text, see Formatting text in Google Chat apps and
Formatting text in Google Workspace Add-ons.
Corresponds to the JSON property topLabel
4836 4837 4838 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4836 def top_label @top_label end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4843 4844 4845 4846 4847 4848 4849 4850 4851 4852 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4843 def update!(**args) @bottom_label = args[:bottom_label] if args.key?(:bottom_label) @button = args[:button] if args.key?(:button) @content = args[:content] if args.key?(:content) @content_multiline = args[:content_multiline] if args.key?(:content_multiline) @icon = args[:icon] if args.key?(:icon) @icon_url = args[:icon_url] if args.key?(:icon_url) @on_click = args[:on_click] if args.key?(:on_click) @top_label = args[:top_label] if args.key?(:top_label) end |