Class: Google::Apis::ChatV1::MarkAsActiveRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Request message for the MarkAsActive method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MarkAsActiveRequest

Returns a new instance of MarkAsActiveRequest.



5002
5003
5004
# File 'lib/google/apis/chat_v1/classes.rb', line 5002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

The absolute timestamp when the ACTIVE state expires. Corresponds to the JSON property expireTime

Returns:

  • (String)


4993
4994
4995
# File 'lib/google/apis/chat_v1/classes.rb', line 4993

def expire_time
  @expire_time
end

#ttlString

The duration from the current time until the ACTIVE state expires. Using a short TTL can effectively reset the user's state to be based on activity after this brief duration. Corresponds to the JSON property ttl

Returns:

  • (String)


5000
5001
5002
# File 'lib/google/apis/chat_v1/classes.rb', line 5000

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5007
5008
5009
5010
# File 'lib/google/apis/chat_v1/classes.rb', line 5007

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @ttl = args[:ttl] if args.key?(:ttl)
end