Class: Google::Apis::ChatV1::MarkAsDoNotDisturbRequest
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::MarkAsDoNotDisturbRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Request message for the MarkAsDoNotDisturb method.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
The absolute timestamp when the DND state expires.
-
#ttl ⇒ String
The duration from the current time until the DND state expires.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MarkAsDoNotDisturbRequest
constructor
A new instance of MarkAsDoNotDisturbRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MarkAsDoNotDisturbRequest
Returns a new instance of MarkAsDoNotDisturbRequest.
5040 5041 5042 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
The absolute timestamp when the DND state expires.
Corresponds to the JSON property expireTime
5033 5034 5035 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5033 def expire_time @expire_time end |
#ttl ⇒ String
The duration from the current time until the DND state expires.
Corresponds to the JSON property ttl
5038 5039 5040 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5038 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5045 5046 5047 5048 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5045 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) @ttl = args[:ttl] if args.key?(:ttl) end |