Class: Google::Apis::ChatV1::Membership

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents a membership relation in Google Chat, such as whether a user or Chat app is invited to, part of, or absent from a space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Membership

Returns a new instance of Membership.



5003
5004
5005
# File 'lib/google/apis/chat_v1/classes.rb', line 5003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Optional. Immutable. The creation time of the membership, such as when a member joined or was invited to join a space. This field is output only, except when used to import historical memberships in import mode spaces. Corresponds to the JSON property createTime

Returns:

  • (String)


4963
4964
4965
# File 'lib/google/apis/chat_v1/classes.rb', line 4963

def create_time
  @create_time
end

#delete_timeString

Optional. Immutable. The deletion time of the membership, such as when a member left or was removed from a space. This field is output only, except when used to import historical memberships in import mode spaces. Corresponds to the JSON property deleteTime

Returns:

  • (String)


4970
4971
4972
# File 'lib/google/apis/chat_v1/classes.rb', line 4970

def delete_time
  @delete_time
end

#group_memberGoogle::Apis::ChatV1::Group

A Google Group in Google Chat. Corresponds to the JSON property groupMember



4975
4976
4977
# File 'lib/google/apis/chat_v1/classes.rb', line 4975

def group_member
  @group_member
end

#memberGoogle::Apis::ChatV1::User

A user in Google Chat. When returned as an output from a request, if your Chat app authenticates as a user, the output for a User resource only populates the user's name and type. Corresponds to the JSON property member



4983
4984
4985
# File 'lib/google/apis/chat_v1/classes.rb', line 4983

def member
  @member
end

#nameString

Identifier. Resource name of the membership, assigned by the server. Format: spaces/space/members/member` Corresponds to the JSON propertyname`

Returns:

  • (String)


4989
4990
4991
# File 'lib/google/apis/chat_v1/classes.rb', line 4989

def name
  @name
end

#roleString

Optional. User's role within a Chat space, which determines their permitted actions in the space. This field can only be used as input in UpdateMembership. Corresponds to the JSON property role

Returns:

  • (String)


4996
4997
4998
# File 'lib/google/apis/chat_v1/classes.rb', line 4996

def role
  @role
end

#stateString

Output only. State of the membership. Corresponds to the JSON property state

Returns:

  • (String)


5001
5002
5003
# File 'lib/google/apis/chat_v1/classes.rb', line 5001

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5008
5009
5010
5011
5012
5013
5014
5015
5016
# File 'lib/google/apis/chat_v1/classes.rb', line 5008

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @group_member = args[:group_member] if args.key?(:group_member)
  @member = args[:member] if args.key?(:member)
  @name = args[:name] if args.key?(:name)
  @role = args[:role] if args.key?(:role)
  @state = args[:state] if args.key?(:state)
end