Class: Google::Apis::ChatV1::Membership

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents a membership relation in Google Chat, such as whether a user or Chat app is invited to, part of, or absent from a space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Membership

Returns a new instance of Membership.



4825
4826
4827
# File 'lib/google/apis/chat_v1/classes.rb', line 4825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Optional. Immutable. The creation time of the membership, such as when a member joined or was invited to join a space. This field is output only, except when used to import historical memberships in import mode spaces. Corresponds to the JSON property createTime

Returns:

  • (String)


4785
4786
4787
# File 'lib/google/apis/chat_v1/classes.rb', line 4785

def create_time
  @create_time
end

#delete_timeString

Optional. Immutable. The deletion time of the membership, such as when a member left or was removed from a space. This field is output only, except when used to import historical memberships in import mode spaces. Corresponds to the JSON property deleteTime

Returns:

  • (String)


4792
4793
4794
# File 'lib/google/apis/chat_v1/classes.rb', line 4792

def delete_time
  @delete_time
end

#group_memberGoogle::Apis::ChatV1::Group

A Google Group in Google Chat. Corresponds to the JSON property groupMember



4797
4798
4799
# File 'lib/google/apis/chat_v1/classes.rb', line 4797

def group_member
  @group_member
end

#memberGoogle::Apis::ChatV1::User

A user in Google Chat. When returned as an output from a request, if your Chat app authenticates as a user, the output for a User resource only populates the user's name and type. Corresponds to the JSON property member



4805
4806
4807
# File 'lib/google/apis/chat_v1/classes.rb', line 4805

def member
  @member
end

#nameString

Identifier. Resource name of the membership, assigned by the server. Format: spaces/space/members/member` Corresponds to the JSON propertyname`

Returns:

  • (String)


4811
4812
4813
# File 'lib/google/apis/chat_v1/classes.rb', line 4811

def name
  @name
end

#roleString

Optional. User's role within a Chat space, which determines their permitted actions in the space. This field can only be used as input in UpdateMembership. Corresponds to the JSON property role

Returns:

  • (String)


4818
4819
4820
# File 'lib/google/apis/chat_v1/classes.rb', line 4818

def role
  @role
end

#stateString

Output only. State of the membership. Corresponds to the JSON property state

Returns:

  • (String)


4823
4824
4825
# File 'lib/google/apis/chat_v1/classes.rb', line 4823

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4830
4831
4832
4833
4834
4835
4836
4837
4838
# File 'lib/google/apis/chat_v1/classes.rb', line 4830

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @group_member = args[:group_member] if args.key?(:group_member)
  @member = args[:member] if args.key?(:member)
  @name = args[:name] if args.key?(:name)
  @role = args[:role] if args.key?(:role)
  @state = args[:state] if args.key?(:state)
end