Class: Google::Apis::ChatV1::MembershipCount

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Represents the count of memberships of a space, grouped into categories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipCount

Returns a new instance of MembershipCount.



5094
5095
5096
# File 'lib/google/apis/chat_v1/classes.rb', line 5094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#joined_direct_human_user_countFixnum

Output only. Count of human users that have directly joined the space, not counting users joined by having membership in a joined group. Corresponds to the JSON property joinedDirectHumanUserCount

Returns:

  • (Fixnum)


5087
5088
5089
# File 'lib/google/apis/chat_v1/classes.rb', line 5087

def joined_direct_human_user_count
  @joined_direct_human_user_count
end

#joined_group_countFixnum

Output only. Count of all groups that have directly joined the space. Corresponds to the JSON property joinedGroupCount

Returns:

  • (Fixnum)


5092
5093
5094
# File 'lib/google/apis/chat_v1/classes.rb', line 5092

def joined_group_count
  @joined_group_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5099
5100
5101
5102
# File 'lib/google/apis/chat_v1/classes.rb', line 5099

def update!(**args)
  @joined_direct_human_user_count = args[:joined_direct_human_user_count] if args.key?(:joined_direct_human_user_count)
  @joined_group_count = args[:joined_group_count] if args.key?(:joined_group_count)
end