Class: Google::Apis::ChatV1::MembershipCount
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::MembershipCount
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Represents the count of memberships of a space, grouped into categories.
Instance Attribute Summary collapse
-
#joined_direct_human_user_count ⇒ Fixnum
Output only.
-
#joined_group_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MembershipCount
constructor
A new instance of MembershipCount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MembershipCount
Returns a new instance of MembershipCount.
4916 4917 4918 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#joined_direct_human_user_count ⇒ Fixnum
Output only. Count of human users that have directly joined the space, not
counting users joined by having membership in a joined group.
Corresponds to the JSON property joinedDirectHumanUserCount
4909 4910 4911 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4909 def joined_direct_human_user_count @joined_direct_human_user_count end |
#joined_group_count ⇒ Fixnum
Output only. Count of all groups that have directly joined the space.
Corresponds to the JSON property joinedGroupCount
4914 4915 4916 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4914 def joined_group_count @joined_group_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4921 4922 4923 4924 |
# File 'lib/google/apis/chat_v1/classes.rb', line 4921 def update!(**args) @joined_direct_human_user_count = args[:joined_direct_human_user_count] if args.key?(:joined_direct_human_user_count) @joined_group_count = args[:joined_group_count] if args.key?(:joined_group_count) end |