Class: Google::Apis::ChatV1::MoveSectionItemRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Request message for moving a section item across sections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MoveSectionItemRequest

Returns a new instance of MoveSectionItemRequest.



5565
5566
5567
# File 'lib/google/apis/chat_v1/classes.rb', line 5565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_sectionString

Required. The resource name of the section to move the section item to. Format: users/user/sections/section` Corresponds to the JSON propertytargetSection`

Returns:

  • (String)


5563
5564
5565
# File 'lib/google/apis/chat_v1/classes.rb', line 5563

def target_section
  @target_section
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5570
5571
5572
# File 'lib/google/apis/chat_v1/classes.rb', line 5570

def update!(**args)
  @target_section = args[:target_section] if args.key?(:target_section)
end