Class: Google::Apis::ChatV1::MoveSectionItemRequest
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::MoveSectionItemRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Request message for moving a section item across sections.
Instance Attribute Summary collapse
-
#target_section ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MoveSectionItemRequest
constructor
A new instance of MoveSectionItemRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MoveSectionItemRequest
Returns a new instance of MoveSectionItemRequest.
5552 5553 5554 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_section ⇒ String
Required. The resource name of the section to move the section item to. Format:
users/user/sections/section`
Corresponds to the JSON propertytargetSection`
5550 5551 5552 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5550 def target_section @target_section end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5557 5558 5559 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5557 def update!(**args) @target_section = args[:target_section] if args.key?(:target_section) end |