Class: Google::Apis::ChatV1::PermissionSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Permission settings that you can specify when updating an existing named space. To set permission settings when creating a space, specify the PredefinedPermissionSettings field in your request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PermissionSettings

Returns a new instance of PermissionSettings.



5709
5710
5711
# File 'lib/google/apis/chat_v1/classes.rb', line 5709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#manage_appsGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property manageApps



5672
5673
5674
# File 'lib/google/apis/chat_v1/classes.rb', line 5672

def manage_apps
  @manage_apps
end

#manage_members_and_groupsGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property manageMembersAndGroups



5677
5678
5679
# File 'lib/google/apis/chat_v1/classes.rb', line 5677

def manage_members_and_groups
  @manage_members_and_groups
end

#manage_webhooksGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property manageWebhooks



5682
5683
5684
# File 'lib/google/apis/chat_v1/classes.rb', line 5682

def manage_webhooks
  @manage_webhooks
end

#modify_space_detailsGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property modifySpaceDetails



5687
5688
5689
# File 'lib/google/apis/chat_v1/classes.rb', line 5687

def modify_space_details
  @modify_space_details
end

#post_messagesGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property postMessages



5692
5693
5694
# File 'lib/google/apis/chat_v1/classes.rb', line 5692

def post_messages
  @post_messages
end

#reply_messagesGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property replyMessages



5697
5698
5699
# File 'lib/google/apis/chat_v1/classes.rb', line 5697

def reply_messages
  @reply_messages
end

#toggle_historyGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property toggleHistory



5702
5703
5704
# File 'lib/google/apis/chat_v1/classes.rb', line 5702

def toggle_history
  @toggle_history
end

#use_at_mention_allGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property useAtMentionAll



5707
5708
5709
# File 'lib/google/apis/chat_v1/classes.rb', line 5707

def use_at_mention_all
  @use_at_mention_all
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5714
5715
5716
5717
5718
5719
5720
5721
5722
5723
# File 'lib/google/apis/chat_v1/classes.rb', line 5714

def update!(**args)
  @manage_apps = args[:manage_apps] if args.key?(:manage_apps)
  @manage_members_and_groups = args[:manage_members_and_groups] if args.key?(:manage_members_and_groups)
  @manage_webhooks = args[:manage_webhooks] if args.key?(:manage_webhooks)
  @modify_space_details = args[:modify_space_details] if args.key?(:modify_space_details)
  @post_messages = args[:post_messages] if args.key?(:post_messages)
  @reply_messages = args[:reply_messages] if args.key?(:reply_messages)
  @toggle_history = args[:toggle_history] if args.key?(:toggle_history)
  @use_at_mention_all = args[:use_at_mention_all] if args.key?(:use_at_mention_all)
end