Class: Google::Apis::ChatV1::PermissionSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Permission settings that you can specify when updating an existing named space. To set permission settings when creating a space, specify the PredefinedPermissionSettings field in your request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PermissionSettings

Returns a new instance of PermissionSettings.



5488
5489
5490
# File 'lib/google/apis/chat_v1/classes.rb', line 5488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#manage_appsGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property manageApps



5451
5452
5453
# File 'lib/google/apis/chat_v1/classes.rb', line 5451

def manage_apps
  @manage_apps
end

#manage_members_and_groupsGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property manageMembersAndGroups



5456
5457
5458
# File 'lib/google/apis/chat_v1/classes.rb', line 5456

def manage_members_and_groups
  @manage_members_and_groups
end

#manage_webhooksGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property manageWebhooks



5461
5462
5463
# File 'lib/google/apis/chat_v1/classes.rb', line 5461

def manage_webhooks
  @manage_webhooks
end

#modify_space_detailsGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property modifySpaceDetails



5466
5467
5468
# File 'lib/google/apis/chat_v1/classes.rb', line 5466

def modify_space_details
  @modify_space_details
end

#post_messagesGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property postMessages



5471
5472
5473
# File 'lib/google/apis/chat_v1/classes.rb', line 5471

def post_messages
  @post_messages
end

#reply_messagesGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property replyMessages



5476
5477
5478
# File 'lib/google/apis/chat_v1/classes.rb', line 5476

def reply_messages
  @reply_messages
end

#toggle_historyGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property toggleHistory



5481
5482
5483
# File 'lib/google/apis/chat_v1/classes.rb', line 5481

def toggle_history
  @toggle_history
end

#use_at_mention_allGoogle::Apis::ChatV1::PermissionSetting

Represents a space permission setting. Corresponds to the JSON property useAtMentionAll



5486
5487
5488
# File 'lib/google/apis/chat_v1/classes.rb', line 5486

def use_at_mention_all
  @use_at_mention_all
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
# File 'lib/google/apis/chat_v1/classes.rb', line 5493

def update!(**args)
  @manage_apps = args[:manage_apps] if args.key?(:manage_apps)
  @manage_members_and_groups = args[:manage_members_and_groups] if args.key?(:manage_members_and_groups)
  @manage_webhooks = args[:manage_webhooks] if args.key?(:manage_webhooks)
  @modify_space_details = args[:modify_space_details] if args.key?(:modify_space_details)
  @post_messages = args[:post_messages] if args.key?(:post_messages)
  @reply_messages = args[:reply_messages] if args.key?(:reply_messages)
  @toggle_history = args[:toggle_history] if args.key?(:toggle_history)
  @use_at_mention_all = args[:use_at_mention_all] if args.key?(:use_at_mention_all)
end