Class: Google::Apis::ChatV1::PositionSectionRequest
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::PositionSectionRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Request message for positioning a section.
Instance Attribute Summary collapse
-
#relative_position ⇒ String
Optional.
-
#sort_order ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PositionSectionRequest
constructor
A new instance of PositionSectionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PositionSectionRequest
Returns a new instance of PositionSectionRequest.
6014 6015 6016 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#relative_position ⇒ String
Optional. The relative position of the section in the list of sections.
Corresponds to the JSON property relativePosition
6003 6004 6005 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6003 def relative_position @relative_position end |
#sort_order ⇒ Fixnum
Optional. The absolute position of the section in the list of sections. The
position must be greater than 0. If the position is greater than the number of
sections, the section will be appended to the end of the list. This operation
inserts the section at the given position and shifts the original section at
that position, and those below it, to the next position.
Corresponds to the JSON property sortOrder
6012 6013 6014 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6012 def sort_order @sort_order end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6019 6020 6021 6022 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6019 def update!(**args) @relative_position = args[:relative_position] if args.key?(:relative_position) @sort_order = args[:sort_order] if args.key?(:sort_order) end |