Class: Google::Apis::ChatV1::Principal
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::Principal
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A principal representing an entity granted access.
Instance Attribute Summary collapse
-
#audience ⇒ Google::Apis::ChatV1::Audience
A target audience in Google Chat.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Principal
constructor
A new instance of Principal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Principal
Returns a new instance of Principal.
6062 6063 6064 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6062 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience ⇒ Google::Apis::ChatV1::Audience
A target audience in Google Chat. A target audience represents a group of
users within a Google Workspace organization, defined by an administrator.
Target audiences are used to configure access and visibility settings for
resources, such as making a space discoverable to a specific group of users.
For more details, see Target audiences and Make a space discoverable to a target audience.
Corresponds to the JSON property audience
6060 6061 6062 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6060 def audience @audience end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6067 6068 6069 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6067 def update!(**args) @audience = args[:audience] if args.key?(:audience) end |