Class: Google::Apis::ChatV1::QuotedMessageMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::QuotedMessageMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Information about a message that another message quotes. When you update a
message, you can't add or replace the quotedMessageMetadata field, but you
can remove it. For example usage, see Quote another message.
Instance Attribute Summary collapse
-
#forwarded_metadata ⇒ Google::Apis::ChatV1::ForwardedMetadata
Metadata about the source space from which a message was forwarded.
-
#last_update_time ⇒ String
Required.
-
#name ⇒ String
Required.
-
#quote_type ⇒ String
Optional.
-
#quoted_message_snapshot ⇒ Google::Apis::ChatV1::QuotedMessageSnapshot
Provides a snapshot of the content of the quoted message at the time of quoting or forwarding Corresponds to the JSON property
quotedMessageSnapshot.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuotedMessageMetadata
constructor
A new instance of QuotedMessageMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuotedMessageMetadata
Returns a new instance of QuotedMessageMetadata.
5835 5836 5837 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5835 def initialize(**args) update!(**args) end |
Instance Attribute Details
#forwarded_metadata ⇒ Google::Apis::ChatV1::ForwardedMetadata
Metadata about the source space from which a message was forwarded.
Corresponds to the JSON property forwardedMetadata
5806 5807 5808 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5806 def @forwarded_metadata end |
#last_update_time ⇒ String
Required. The timestamp when the quoted message was created or when the quoted
message was last updated. If the message was edited, use this field,
last_update_time. If the message was never edited, use create_time. If
last_update_time doesn't match the latest version of the quoted message, the
request fails.
Corresponds to the JSON property lastUpdateTime
5815 5816 5817 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5815 def last_update_time @last_update_time end |
#name ⇒ String
Required. Resource name of the message that is quoted. Format: spaces/space/
messages/message`
Corresponds to the JSON propertyname`
5821 5822 5823 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5821 def name @name end |
#quote_type ⇒ String
Optional. Specifies the quote type. If not set, defaults to REPLY in the
message read/write path for backward compatibility.
Corresponds to the JSON property quoteType
5827 5828 5829 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5827 def quote_type @quote_type end |
#quoted_message_snapshot ⇒ Google::Apis::ChatV1::QuotedMessageSnapshot
Provides a snapshot of the content of the quoted message at the time of
quoting or forwarding
Corresponds to the JSON property quotedMessageSnapshot
5833 5834 5835 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5833 def @quoted_message_snapshot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5840 5841 5842 5843 5844 5845 5846 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5840 def update!(**args) @forwarded_metadata = args[:forwarded_metadata] if args.key?(:forwarded_metadata) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @name = args[:name] if args.key?(:name) @quote_type = args[:quote_type] if args.key?(:quote_type) @quoted_message_snapshot = args[:quoted_message_snapshot] if args.key?(:quoted_message_snapshot) end |