Class: Google::Apis::ChatV1::QuotedMessageMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Information about a message that another message quotes. When you create a message, you can quote messages within the same thread, or quote a root message to create a new root message. However, you can't quote a message reply from a different thread. When you update a message, you can't add or replace the quotedMessageMetadata field, but you can remove it. For example usage, see Quote another message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotedMessageMetadata

Returns a new instance of QuotedMessageMetadata.



5530
5531
5532
# File 'lib/google/apis/chat_v1/classes.rb', line 5530

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_update_timeString

Required. The timestamp when the quoted message was created or when the quoted message was last updated. If the message was edited, use this field, last_update_time. If the message was never edited, use create_time. If last_update_time doesn't match the latest version of the quoted message, the request fails. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


5522
5523
5524
# File 'lib/google/apis/chat_v1/classes.rb', line 5522

def last_update_time
  @last_update_time
end

#nameString

Required. Resource name of the message that is quoted. Format: spaces/space/ messages/message` Corresponds to the JSON propertyname`

Returns:

  • (String)


5528
5529
5530
# File 'lib/google/apis/chat_v1/classes.rb', line 5528

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5535
5536
5537
5538
# File 'lib/google/apis/chat_v1/classes.rb', line 5535

def update!(**args)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @name = args[:name] if args.key?(:name)
end