Class: Google::Apis::ChatV1::QuotedMessageSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::QuotedMessageSnapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Provides a snapshot of the content of the quoted message at the time of quoting or forwarding
Instance Attribute Summary collapse
-
#annotations ⇒ Array<Google::Apis::ChatV1::Annotation>
Output only.
-
#attachments ⇒ Array<Google::Apis::ChatV1::Attachment>
Output only.
-
#formatted_text ⇒ String
Output only.
-
#sender ⇒ String
Output only.
-
#text ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuotedMessageSnapshot
constructor
A new instance of QuotedMessageSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuotedMessageSnapshot
Returns a new instance of QuotedMessageSnapshot.
6161 6162 6163 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Array<Google::Apis::ChatV1::Annotation>
Output only. Annotations parsed from the text body of the quoted message.
Populated only for FORWARD quote type.
Corresponds to the JSON property annotations
6134 6135 6136 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6134 def annotations @annotations end |
#attachments ⇒ Array<Google::Apis::ChatV1::Attachment>
Output only. Attachments that were part of the quoted message. These are
copies of the quoted message's attachment metadata. Populated only for FORWARD
quote type.
Corresponds to the JSON property attachments
6141 6142 6143 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6141 def @attachments end |
#formatted_text ⇒ String
Output only. Contains the quoted message text with markups added to support
rich formatting like hyperlinks,custom emojis, markup, etc. Populated only for
FORWARD quote type.
Corresponds to the JSON property formattedText
6148 6149 6150 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6148 def formatted_text @formatted_text end |
#sender ⇒ String
Output only. The quoted message's author name. Populated for both REPLY &
FORWARD quote types.
Corresponds to the JSON property sender
6154 6155 6156 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6154 def sender @sender end |
#text ⇒ String
Output only. Snapshot of the quoted message's text content.
Corresponds to the JSON property text
6159 6160 6161 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6159 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6166 6167 6168 6169 6170 6171 6172 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6166 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @attachments = args[:attachments] if args.key?(:attachments) @formatted_text = args[:formatted_text] if args.key?(:formatted_text) @sender = args[:sender] if args.key?(:sender) @text = args[:text] if args.key?(:text) end |