Class: Google::Apis::ChatV1::QuotedMessageSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::QuotedMessageSnapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Provides a snapshot of the content of the quoted message at the time of quoting or forwarding
Instance Attribute Summary collapse
-
#annotations ⇒ Array<Google::Apis::ChatV1::Annotation>
Output only.
-
#attachments ⇒ Array<Google::Apis::ChatV1::Attachment>
Output only.
-
#formatted_text ⇒ String
Output only.
-
#sender ⇒ String
Output only.
-
#text ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuotedMessageSnapshot
constructor
A new instance of QuotedMessageSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuotedMessageSnapshot
Returns a new instance of QuotedMessageSnapshot.
5885 5886 5887 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Array<Google::Apis::ChatV1::Annotation>
Output only. Annotations parsed from the text body of the quoted message.
Populated only for FORWARD quote type.
Corresponds to the JSON property annotations
5858 5859 5860 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5858 def annotations @annotations end |
#attachments ⇒ Array<Google::Apis::ChatV1::Attachment>
Output only. Attachments that were part of the quoted message. These are
copies of the quoted message's attachment metadata. Populated only for FORWARD
quote type.
Corresponds to the JSON property attachments
5865 5866 5867 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5865 def @attachments end |
#formatted_text ⇒ String
Output only. Contains the quoted message text with markups added to support
rich formatting like hyperlinks,custom emojis, markup, etc. Populated only for
FORWARD quote type.
Corresponds to the JSON property formattedText
5872 5873 5874 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5872 def formatted_text @formatted_text end |
#sender ⇒ String
Output only. The quoted message's author name. Populated for both REPLY &
FORWARD quote types.
Corresponds to the JSON property sender
5878 5879 5880 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5878 def sender @sender end |
#text ⇒ String
Output only. Snapshot of the quoted message's text content.
Corresponds to the JSON property text
5883 5884 5885 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5883 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5890 5891 5892 5893 5894 5895 5896 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5890 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @attachments = args[:attachments] if args.key?(:attachments) @formatted_text = args[:formatted_text] if args.key?(:formatted_text) @sender = args[:sender] if args.key?(:sender) @text = args[:text] if args.key?(:text) end |