Class: Google::Apis::ChatV1::QuotedMessageSnapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Provides a snapshot of the content of the quoted message at the time of quoting or forwarding

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotedMessageSnapshot

Returns a new instance of QuotedMessageSnapshot.



5883
5884
5885
# File 'lib/google/apis/chat_v1/classes.rb', line 5883

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsArray<Google::Apis::ChatV1::Annotation>

Output only. Annotations parsed from the text body of the quoted message. Populated only for FORWARD quote type. Corresponds to the JSON property annotations



5856
5857
5858
# File 'lib/google/apis/chat_v1/classes.rb', line 5856

def annotations
  @annotations
end

#attachmentsArray<Google::Apis::ChatV1::Attachment>

Output only. Attachments that were part of the quoted message. These are copies of the quoted message's attachment metadata. Populated only for FORWARD quote type. Corresponds to the JSON property attachments



5863
5864
5865
# File 'lib/google/apis/chat_v1/classes.rb', line 5863

def attachments
  @attachments
end

#formatted_textString

Output only. Contains the quoted message text with markups added to support rich formatting like hyperlinks,custom emojis, markup, etc. Populated only for FORWARD quote type. Corresponds to the JSON property formattedText

Returns:

  • (String)


5870
5871
5872
# File 'lib/google/apis/chat_v1/classes.rb', line 5870

def formatted_text
  @formatted_text
end

#senderString

Output only. The quoted message's author name. Populated for both REPLY & FORWARD quote types. Corresponds to the JSON property sender

Returns:

  • (String)


5876
5877
5878
# File 'lib/google/apis/chat_v1/classes.rb', line 5876

def sender
  @sender
end

#textString

Output only. Snapshot of the quoted message's text content. Corresponds to the JSON property text

Returns:

  • (String)


5881
5882
5883
# File 'lib/google/apis/chat_v1/classes.rb', line 5881

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5888
5889
5890
5891
5892
5893
5894
# File 'lib/google/apis/chat_v1/classes.rb', line 5888

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @attachments = args[:attachments] if args.key?(:attachments)
  @formatted_text = args[:formatted_text] if args.key?(:formatted_text)
  @sender = args[:sender] if args.key?(:sender)
  @text = args[:text] if args.key?(:text)
end