Class: Google::Apis::ChatV1::Reaction
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::Reaction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A reaction to a message.
Instance Attribute Summary collapse
-
#emoji ⇒ Google::Apis::ChatV1::Emoji
An emoji that is used as a reaction to a message.
-
#name ⇒ String
Identifier.
-
#user ⇒ Google::Apis::ChatV1::User
A user in Google Chat.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reaction
constructor
A new instance of Reaction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reaction
Returns a new instance of Reaction.
5564 5565 5566 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5564 def initialize(**args) update!(**args) end |
Instance Attribute Details
#emoji ⇒ Google::Apis::ChatV1::Emoji
An emoji that is used as a reaction to a message.
Corresponds to the JSON property emoji
5548 5549 5550 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5548 def emoji @emoji end |
#name ⇒ String
Identifier. The resource name of the reaction. Format: spaces/space/
messages/message/reactions/reaction`
Corresponds to the JSON propertyname`
5554 5555 5556 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5554 def name @name end |
#user ⇒ Google::Apis::ChatV1::User
A user in Google Chat. When returned as an output from a request, if your Chat
app authenticates as a user, the output for a User resource only
populates the user's name and type.
Corresponds to the JSON property user
5562 5563 5564 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5562 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5569 5570 5571 5572 5573 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5569 def update!(**args) @emoji = args[:emoji] if args.key?(:emoji) @name = args[:name] if args.key?(:name) @user = args[:user] if args.key?(:user) end |