Class: Google::Apis::ChatV1::RichLinkMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A rich link to a resource. Rich links can be associated with the plain-text body of the message or represent chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RichLinkMetadata

Returns a new instance of RichLinkMetadata.



6326
6327
6328
# File 'lib/google/apis/chat_v1/classes.rb', line 6326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Data for Calendar event links. Corresponds to the JSON property calendarEventLinkData



6299
6300
6301
# File 'lib/google/apis/chat_v1/classes.rb', line 6299

def calendar_event_link_data
  @calendar_event_link_data
end

Data for Chat space links. Corresponds to the JSON property chatSpaceLinkData



6304
6305
6306
# File 'lib/google/apis/chat_v1/classes.rb', line 6304

def chat_space_link_data
  @chat_space_link_data
end

Data for Google Drive links. Corresponds to the JSON property driveLinkData



6309
6310
6311
# File 'lib/google/apis/chat_v1/classes.rb', line 6309

def drive_link_data
  @drive_link_data
end

Data for Meet space links. Corresponds to the JSON property meetSpaceLinkData



6314
6315
6316
# File 'lib/google/apis/chat_v1/classes.rb', line 6314

def meet_space_link_data
  @meet_space_link_data
end

The rich link type. Corresponds to the JSON property richLinkType

Returns:

  • (String)


6319
6320
6321
# File 'lib/google/apis/chat_v1/classes.rb', line 6319

def rich_link_type
  @rich_link_type
end

#uriString

The URI of this link. Corresponds to the JSON property uri

Returns:

  • (String)


6324
6325
6326
# File 'lib/google/apis/chat_v1/classes.rb', line 6324

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6331
6332
6333
6334
6335
6336
6337
6338
# File 'lib/google/apis/chat_v1/classes.rb', line 6331

def update!(**args)
  @calendar_event_link_data = args[:calendar_event_link_data] if args.key?(:calendar_event_link_data)
  @chat_space_link_data = args[:chat_space_link_data] if args.key?(:chat_space_link_data)
  @drive_link_data = args[:drive_link_data] if args.key?(:drive_link_data)
  @meet_space_link_data = args[:meet_space_link_data] if args.key?(:meet_space_link_data)
  @rich_link_type = args[:rich_link_type] if args.key?(:rich_link_type)
  @uri = args[:uri] if args.key?(:uri)
end