Class: Google::Apis::ChatV1::RichLinkMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A rich link to a resource. Rich links can be associated with the plain-text body of the message or represent chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RichLinkMetadata

Returns a new instance of RichLinkMetadata.



6221
6222
6223
# File 'lib/google/apis/chat_v1/classes.rb', line 6221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Data for Calendar event links. Corresponds to the JSON property calendarEventLinkData



6194
6195
6196
# File 'lib/google/apis/chat_v1/classes.rb', line 6194

def calendar_event_link_data
  @calendar_event_link_data
end

Data for Chat space links. Corresponds to the JSON property chatSpaceLinkData



6199
6200
6201
# File 'lib/google/apis/chat_v1/classes.rb', line 6199

def chat_space_link_data
  @chat_space_link_data
end

Data for Google Drive links. Corresponds to the JSON property driveLinkData



6204
6205
6206
# File 'lib/google/apis/chat_v1/classes.rb', line 6204

def drive_link_data
  @drive_link_data
end

Data for Meet space links. Corresponds to the JSON property meetSpaceLinkData



6209
6210
6211
# File 'lib/google/apis/chat_v1/classes.rb', line 6209

def meet_space_link_data
  @meet_space_link_data
end

The rich link type. Corresponds to the JSON property richLinkType

Returns:

  • (String)


6214
6215
6216
# File 'lib/google/apis/chat_v1/classes.rb', line 6214

def rich_link_type
  @rich_link_type
end

#uriString

The URI of this link. Corresponds to the JSON property uri

Returns:

  • (String)


6219
6220
6221
# File 'lib/google/apis/chat_v1/classes.rb', line 6219

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6226
6227
6228
6229
6230
6231
6232
6233
# File 'lib/google/apis/chat_v1/classes.rb', line 6226

def update!(**args)
  @calendar_event_link_data = args[:calendar_event_link_data] if args.key?(:calendar_event_link_data)
  @chat_space_link_data = args[:chat_space_link_data] if args.key?(:chat_space_link_data)
  @drive_link_data = args[:drive_link_data] if args.key?(:drive_link_data)
  @meet_space_link_data = args[:meet_space_link_data] if args.key?(:meet_space_link_data)
  @rich_link_type = args[:rich_link_type] if args.key?(:rich_link_type)
  @uri = args[:uri] if args.key?(:uri)
end