Class: Google::Apis::ChatV1::RichLinkMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

A rich link to a resource. Rich links can be associated with the plain-text body of the message or represent chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RichLinkMetadata

Returns a new instance of RichLinkMetadata.



5692
5693
5694
# File 'lib/google/apis/chat_v1/classes.rb', line 5692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Data for Calendar event links. Corresponds to the JSON property calendarEventLinkData



5665
5666
5667
# File 'lib/google/apis/chat_v1/classes.rb', line 5665

def calendar_event_link_data
  @calendar_event_link_data
end

Data for Chat space links. Corresponds to the JSON property chatSpaceLinkData



5670
5671
5672
# File 'lib/google/apis/chat_v1/classes.rb', line 5670

def chat_space_link_data
  @chat_space_link_data
end

Data for Google Drive links. Corresponds to the JSON property driveLinkData



5675
5676
5677
# File 'lib/google/apis/chat_v1/classes.rb', line 5675

def drive_link_data
  @drive_link_data
end

Data for Meet space links. Corresponds to the JSON property meetSpaceLinkData



5680
5681
5682
# File 'lib/google/apis/chat_v1/classes.rb', line 5680

def meet_space_link_data
  @meet_space_link_data
end

The rich link type. Corresponds to the JSON property richLinkType

Returns:

  • (String)


5685
5686
5687
# File 'lib/google/apis/chat_v1/classes.rb', line 5685

def rich_link_type
  @rich_link_type
end

#uriString

The URI of this link. Corresponds to the JSON property uri

Returns:

  • (String)


5690
5691
5692
# File 'lib/google/apis/chat_v1/classes.rb', line 5690

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5697
5698
5699
5700
5701
5702
5703
5704
# File 'lib/google/apis/chat_v1/classes.rb', line 5697

def update!(**args)
  @calendar_event_link_data = args[:calendar_event_link_data] if args.key?(:calendar_event_link_data)
  @chat_space_link_data = args[:chat_space_link_data] if args.key?(:chat_space_link_data)
  @drive_link_data = args[:drive_link_data] if args.key?(:drive_link_data)
  @meet_space_link_data = args[:meet_space_link_data] if args.key?(:meet_space_link_data)
  @rich_link_type = args[:rich_link_type] if args.key?(:rich_link_type)
  @uri = args[:uri] if args.key?(:uri)
end