Class: Google::Apis::ChatV1::SearchSpacesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::SearchSpacesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Response with a list of spaces corresponding to the search spaces request.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be used to retrieve the next page.
-
#results ⇒ Array<Google::Apis::ChatV1::SearchSpaceResult>
Output only.
-
#spaces ⇒ Array<Google::Apis::ChatV1::Space>
Deprecated: Please use the new
resultsfield instead. -
#total_size ⇒ Fixnum
The total number of spaces that match the query, across all pages.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchSpacesResponse
constructor
A new instance of SearchSpacesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchSpacesResponse
Returns a new instance of SearchSpacesResponse.
6598 6599 6600 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be used to retrieve the next page. If this field is empty,
there are no subsequent pages.
Corresponds to the JSON property nextPageToken
6578 6579 6580 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6578 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::ChatV1::SearchSpaceResult>
Output only. The list of search results that matched the query.
Corresponds to the JSON property results
6583 6584 6585 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6583 def results @results end |
#spaces ⇒ Array<Google::Apis::ChatV1::Space>
Deprecated: Please use the new results field instead. A page of the
requested spaces. This field will be populated only when useAdminAccess is
set to true and deprecated in favor of the new results field.
Corresponds to the JSON property spaces
6590 6591 6592 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6590 def spaces @spaces end |
#total_size ⇒ Fixnum
The total number of spaces that match the query, across all pages. If the
result is over 10,000 spaces, this value is an estimate.
Corresponds to the JSON property totalSize
6596 6597 6598 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6596 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6603 6604 6605 6606 6607 6608 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6603 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) @spaces = args[:spaces] if args.key?(:spaces) @total_size = args[:total_size] if args.key?(:total_size) end |