Class: Google::Apis::ChatV1::SearchSpacesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::SearchSpacesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Response with a list of spaces corresponding to the search spaces request.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be used to retrieve the next page.
-
#spaces ⇒ Array<Google::Apis::ChatV1::Space>
Deprecated: Please use the new
resultsfield instead. -
#total_size ⇒ Fixnum
The total number of spaces that match the query, across all pages.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchSpacesResponse
constructor
A new instance of SearchSpacesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchSpacesResponse
Returns a new instance of SearchSpacesResponse.
6364 6365 6366 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be used to retrieve the next page. If this field is empty,
there are no subsequent pages.
Corresponds to the JSON property nextPageToken
6349 6350 6351 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6349 def next_page_token @next_page_token end |
#spaces ⇒ Array<Google::Apis::ChatV1::Space>
Deprecated: Please use the new results field instead. A page of the
requested spaces. This field will be populated only when useAdminAccess is
set to true and deprecated in favor of the new results field.
Corresponds to the JSON property spaces
6356 6357 6358 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6356 def spaces @spaces end |
#total_size ⇒ Fixnum
The total number of spaces that match the query, across all pages. If the
result is over 10,000 spaces, this value is an estimate.
Corresponds to the JSON property totalSize
6362 6363 6364 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6362 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6369 6370 6371 6372 6373 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6369 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @spaces = args[:spaces] if args.key?(:spaces) @total_size = args[:total_size] if args.key?(:total_size) end |