Class: Google::Apis::ChatV1::SearchSpacesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Response with a list of spaces corresponding to the search spaces request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSpacesResponse

Returns a new instance of SearchSpacesResponse.



6259
6260
6261
# File 'lib/google/apis/chat_v1/classes.rb', line 6259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token that can be used to retrieve the next page. If this field is empty, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6244
6245
6246
# File 'lib/google/apis/chat_v1/classes.rb', line 6244

def next_page_token
  @next_page_token
end

#spacesArray<Google::Apis::ChatV1::Space>

Deprecated: Please use the new results field instead. A page of the requested spaces. This field will be populated only when useAdminAccess is set to true and deprecated in favor of the new results field. Corresponds to the JSON property spaces

Returns:



6251
6252
6253
# File 'lib/google/apis/chat_v1/classes.rb', line 6251

def spaces
  @spaces
end

#total_sizeFixnum

The total number of spaces that match the query, across all pages. If the result is over 10,000 spaces, this value is an estimate. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


6257
6258
6259
# File 'lib/google/apis/chat_v1/classes.rb', line 6257

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6264
6265
6266
6267
6268
# File 'lib/google/apis/chat_v1/classes.rb', line 6264

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spaces = args[:spaces] if args.key?(:spaces)
  @total_size = args[:total_size] if args.key?(:total_size)
end