Class: Google::Apis::ChatV1::SearchSpacesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Response with a list of spaces corresponding to the search spaces request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchSpacesResponse

Returns a new instance of SearchSpacesResponse.



6076
6077
6078
# File 'lib/google/apis/chat_v1/classes.rb', line 6076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token that can be used to retrieve the next page. If this field is empty, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6063
6064
6065
# File 'lib/google/apis/chat_v1/classes.rb', line 6063

def next_page_token
  @next_page_token
end

#spacesArray<Google::Apis::ChatV1::Space>

A page of the requested spaces. Corresponds to the JSON property spaces

Returns:



6068
6069
6070
# File 'lib/google/apis/chat_v1/classes.rb', line 6068

def spaces
  @spaces
end

#total_sizeFixnum

The total number of spaces that match the query, across all pages. If the result is over 10,000 spaces, this value is an estimate. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


6074
6075
6076
# File 'lib/google/apis/chat_v1/classes.rb', line 6074

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6081
6082
6083
6084
6085
# File 'lib/google/apis/chat_v1/classes.rb', line 6081

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spaces = args[:spaces] if args.key?(:spaces)
  @total_size = args[:total_size] if args.key?(:total_size)
end