Class: Google::Apis::ChatV1::SearchSpacesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::SearchSpacesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Response with a list of spaces corresponding to the search spaces request.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be used to retrieve the next page.
-
#spaces ⇒ Array<Google::Apis::ChatV1::Space>
A page of the requested spaces.
-
#total_size ⇒ Fixnum
The total number of spaces that match the query, across all pages.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchSpacesResponse
constructor
A new instance of SearchSpacesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchSpacesResponse
Returns a new instance of SearchSpacesResponse.
6077 6078 6079 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be used to retrieve the next page. If this field is empty,
there are no subsequent pages.
Corresponds to the JSON property nextPageToken
6064 6065 6066 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6064 def next_page_token @next_page_token end |
#spaces ⇒ Array<Google::Apis::ChatV1::Space>
A page of the requested spaces.
Corresponds to the JSON property spaces
6069 6070 6071 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6069 def spaces @spaces end |
#total_size ⇒ Fixnum
The total number of spaces that match the query, across all pages. If the
result is over 10,000 spaces, this value is an estimate.
Corresponds to the JSON property totalSize
6075 6076 6077 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6075 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6082 6083 6084 6085 6086 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6082 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @spaces = args[:spaces] if args.key?(:spaces) @total_size = args[:total_size] if args.key?(:total_size) end |