Class: Google::Apis::ChatV1::SearchSpacesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::SearchSpacesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
Response with a list of spaces corresponding to the search spaces request.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be used to retrieve the next page.
-
#spaces ⇒ Array<Google::Apis::ChatV1::Space>
A page of the requested spaces.
-
#total_size ⇒ Fixnum
The total number of spaces that match the query, across all pages.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchSpacesResponse
constructor
A new instance of SearchSpacesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchSpacesResponse
Returns a new instance of SearchSpacesResponse.
5728 5729 5730 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5728 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be used to retrieve the next page. If this field is empty,
there are no subsequent pages.
Corresponds to the JSON property nextPageToken
5715 5716 5717 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5715 def next_page_token @next_page_token end |
#spaces ⇒ Array<Google::Apis::ChatV1::Space>
A page of the requested spaces.
Corresponds to the JSON property spaces
5720 5721 5722 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5720 def spaces @spaces end |
#total_size ⇒ Fixnum
The total number of spaces that match the query, across all pages. If the
result is over 10,000 spaces, this value is an estimate.
Corresponds to the JSON property totalSize
5726 5727 5728 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5726 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5733 5734 5735 5736 5737 |
# File 'lib/google/apis/chat_v1/classes.rb', line 5733 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @spaces = args[:spaces] if args.key?(:spaces) @total_size = args[:total_size] if args.key?(:total_size) end |