Class: Google::Apis::ChatV1::Space
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::Space
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
A space in Google Chat. Spaces are conversations between two or more users or 1:1 messages between a user and a Chat app.
Instance Attribute Summary collapse
-
#access_settings ⇒ Google::Apis::ChatV1::AccessSettings
Represents the access setting of the space.
-
#admin_installed ⇒ Boolean
(also: #admin_installed?)
Output only.
-
#create_time ⇒ String
Optional.
-
#customer ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#external_user_allowed ⇒ Boolean
(also: #external_user_allowed?)
Optional.
-
#import_mode ⇒ Boolean
(also: #import_mode?)
Optional.
-
#import_mode_expire_time ⇒ String
Output only.
-
#last_active_time ⇒ String
Output only.
-
#membership_count ⇒ Google::Apis::ChatV1::MembershipCount
Represents the count of memberships of a space, grouped into categories.
-
#name ⇒ String
Identifier.
-
#permission_settings ⇒ Google::Apis::ChatV1::PermissionSettings
Permission settings that you can specify when updating an existing named space.
-
#predefined_permission_settings ⇒ String
Optional.
-
#single_user_bot_dm ⇒ Boolean
(also: #single_user_bot_dm?)
Optional.
-
#space_details ⇒ Google::Apis::ChatV1::SpaceDetails
Details about the space including description and rules.
-
#space_history_state ⇒ String
Optional.
-
#space_threading_state ⇒ String
Output only.
-
#space_type ⇒ String
Optional.
-
#space_uri ⇒ String
Output only.
-
#threaded ⇒ Boolean
(also: #threaded?)
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Space
constructor
A new instance of Space.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Space
Returns a new instance of Space.
6467 6468 6469 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_settings ⇒ Google::Apis::ChatV1::AccessSettings
Represents the access setting of the space.
Corresponds to the JSON property accessSettings
6307 6308 6309 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6307 def access_settings @access_settings end |
#admin_installed ⇒ Boolean Also known as: admin_installed?
Output only. For direct message (DM) spaces with a Chat app, whether the space
was created by a Google Workspace administrator. Administrators can install
and set up a direct message with a Chat app on behalf of users in their
organization. To support admin install, your Chat app must feature direct
messaging.
Corresponds to the JSON property adminInstalled
6316 6317 6318 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6316 def admin_installed @admin_installed end |
#create_time ⇒ String
Optional. Immutable. For spaces created in Chat, the time the space was
created. This field is output only, except when used in import mode spaces.
For import mode spaces, set this field to the historical timestamp at which
the space was created in the source in order to preserve the original creation
time. Only populated in the output when spaceType is GROUP_CHAT or SPACE.
Corresponds to the JSON property createTime
6326 6327 6328 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6326 def create_time @create_time end |
#customer ⇒ String
Optional. Immutable. The customer id of the domain of the space. Required only
when creating a space with app authentication and SpaceType is SPACE,
otherwise should not be set. In the format customers/customer`, where
customeris theidfrom the [Admin SDK customer resource](https://
developers.google.com/admin-sdk/directory/reference/rest/v1/customers).
Private apps can also use thecustomers/my_customeralias to create the
space in the same Google Workspace organization as the app. This field isn't
populated for direct messages (DMs) or when the space is created by non-Google
Workspace users.
Corresponds to the JSON propertycustomer`
6340 6341 6342 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6340 def customer @customer end |
#display_name ⇒ String
Optional. The space's display name. Required when creating a space with
a spaceType of SPACE. If you receive the error message ALREADY_EXISTS
when creating a space or updating the displayName, try a different
displayName. An existing space within the Google Workspace organization might
already use this display name. For direct messages, this field might be empty.
Supports up to 128 characters.
Corresponds to the JSON property displayName
6351 6352 6353 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6351 def display_name @display_name end |
#external_user_allowed ⇒ Boolean Also known as: external_user_allowed?
Optional. Immutable. Whether this space permits any Google Chat user as a
member. Input when creating a space in a Google Workspace organization. Omit
this field when creating spaces in the following conditions: * The
authenticated user uses a consumer account (unmanaged user account). By
default, a space created by a consumer account permits any Google Chat user.
For existing spaces, this field is output only.
Corresponds to the JSON property externalUserAllowed
6361 6362 6363 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6361 def external_user_allowed @external_user_allowed end |
#import_mode ⇒ Boolean Also known as: import_mode?
Optional. Whether this space is created in Import Mode as part of a data
migration into Google Workspace. While spaces are being imported, they aren't
visible to users until the import is complete. Creating a space in Import
Moderequires user authentication.
Corresponds to the JSON property importMode
6371 6372 6373 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6371 def import_mode @import_mode end |
#import_mode_expire_time ⇒ String
Output only. The time when the space will be automatically deleted by the
system if it remains in import mode. Each space created in import mode must
exit this mode before this expire time using spaces.completeImport. This
field is only populated for spaces that were created with import mode.
Corresponds to the JSON property importModeExpireTime
6380 6381 6382 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6380 def import_mode_expire_time @import_mode_expire_time end |
#last_active_time ⇒ String
Output only. Timestamp of the last message in the space.
Corresponds to the JSON property lastActiveTime
6385 6386 6387 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6385 def last_active_time @last_active_time end |
#membership_count ⇒ Google::Apis::ChatV1::MembershipCount
Represents the count of memberships of a space, grouped into categories.
Corresponds to the JSON property membershipCount
6390 6391 6392 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6390 def membership_count @membership_count end |
#name ⇒ String
Identifier. Resource name of the space. Format: spaces/spaceWherespace
represents the system-assigned ID for the space. You can obtain the space ID
by calling the spaces.list() method or from the space URL. For example,
if the space URL is https://mail.google.com/mail/u/0/#chat/space/AAAAAAAAA,
the space ID is AAAAAAAAA.
Corresponds to the JSON property name
6400 6401 6402 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6400 def name @name end |
#permission_settings ⇒ Google::Apis::ChatV1::PermissionSettings
Permission settings that
you can specify when updating an existing named space. To set permission
settings when creating a space, specify the PredefinedPermissionSettings
field in your request.
Corresponds to the JSON property permissionSettings
6408 6409 6410 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6408 def @permission_settings end |
#predefined_permission_settings ⇒ String
Optional. Input only. Predefined space permission settings, input only when
creating a space. If the field is not set, a collaboration space is created.
After you create the space, settings are populated in the PermissionSettings
field. Setting predefined permission settings supports: - App authentication
with administrator approval
with the chat.app.spaces or chat.app.spaces.create scopes. - User
authentication
Corresponds to the JSON property predefinedPermissionSettings
6421 6422 6423 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6421 def @predefined_permission_settings end |
#single_user_bot_dm ⇒ Boolean Also known as: single_user_bot_dm?
Optional. Whether the space is a DM between a Chat app and a single human.
Corresponds to the JSON property singleUserBotDm
6426 6427 6428 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6426 def single_user_bot_dm @single_user_bot_dm end |
#space_details ⇒ Google::Apis::ChatV1::SpaceDetails
Details about the space including description and rules.
Corresponds to the JSON property spaceDetails
6432 6433 6434 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6432 def space_details @space_details end |
#space_history_state ⇒ String
Optional. The message history state for messages and threads in this space.
Corresponds to the JSON property spaceHistoryState
6437 6438 6439 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6437 def space_history_state @space_history_state end |
#space_threading_state ⇒ String
Output only. The threading state in the Chat space.
Corresponds to the JSON property spaceThreadingState
6442 6443 6444 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6442 def space_threading_state @space_threading_state end |
#space_type ⇒ String
Optional. The type of space. Required when creating a space or updating the
space type of a space. Output only for other usage.
Corresponds to the JSON property spaceType
6448 6449 6450 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6448 def space_type @space_type end |
#space_uri ⇒ String
Output only. The URI for a user to access the space.
Corresponds to the JSON property spaceUri
6453 6454 6455 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6453 def space_uri @space_uri end |
#threaded ⇒ Boolean Also known as: threaded?
Output only. Deprecated: Use spaceThreadingState instead. Whether messages
are threaded in this space.
Corresponds to the JSON property threaded
6459 6460 6461 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6459 def threaded @threaded end |
#type ⇒ String
Output only. Deprecated: Use space_type instead. The type of a space.
Corresponds to the JSON property type
6465 6466 6467 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6465 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6472 6473 6474 6475 6476 6477 6478 6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6472 def update!(**args) @access_settings = args[:access_settings] if args.key?(:access_settings) @admin_installed = args[:admin_installed] if args.key?(:admin_installed) @create_time = args[:create_time] if args.key?(:create_time) @customer = args[:customer] if args.key?(:customer) @display_name = args[:display_name] if args.key?(:display_name) @external_user_allowed = args[:external_user_allowed] if args.key?(:external_user_allowed) @import_mode = args[:import_mode] if args.key?(:import_mode) @import_mode_expire_time = args[:import_mode_expire_time] if args.key?(:import_mode_expire_time) @last_active_time = args[:last_active_time] if args.key?(:last_active_time) @membership_count = args[:membership_count] if args.key?(:membership_count) @name = args[:name] if args.key?(:name) @permission_settings = args[:permission_settings] if args.key?(:permission_settings) @predefined_permission_settings = args[:predefined_permission_settings] if args.key?(:predefined_permission_settings) @single_user_bot_dm = args[:single_user_bot_dm] if args.key?(:single_user_bot_dm) @space_details = args[:space_details] if args.key?(:space_details) @space_history_state = args[:space_history_state] if args.key?(:space_history_state) @space_threading_state = args[:space_threading_state] if args.key?(:space_threading_state) @space_type = args[:space_type] if args.key?(:space_type) @space_uri = args[:space_uri] if args.key?(:space_uri) @threaded = args[:threaded] if args.key?(:threaded) @type = args[:type] if args.key?(:type) end |