Class: Google::Apis::ChatV1::UpdatedWidget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

For selectionInput widgets, returns autocomplete suggestions for a multiselect menu.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdatedWidget

Returns a new instance of UpdatedWidget.



7068
7069
7070
# File 'lib/google/apis/chat_v1/classes.rb', line 7068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#suggestionsGoogle::Apis::ChatV1::SelectionItems

List of widget autocomplete results. Corresponds to the JSON property suggestions



7060
7061
7062
# File 'lib/google/apis/chat_v1/classes.rb', line 7060

def suggestions
  @suggestions
end

#widgetString

The ID of the updated widget. The ID must match the one for the widget that triggered the update request. Corresponds to the JSON property widget

Returns:

  • (String)


7066
7067
7068
# File 'lib/google/apis/chat_v1/classes.rb', line 7066

def widget
  @widget
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7073
7074
7075
7076
# File 'lib/google/apis/chat_v1/classes.rb', line 7073

def update!(**args)
  @suggestions = args[:suggestions] if args.key?(:suggestions)
  @widget = args[:widget] if args.key?(:widget)
end