Class: Google::Apis::ChatV1::UpdatedWidget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

For selectionInput widgets, returns autocomplete suggestions for a multiselect menu.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdatedWidget

Returns a new instance of UpdatedWidget.



6692
6693
6694
# File 'lib/google/apis/chat_v1/classes.rb', line 6692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#suggestionsGoogle::Apis::ChatV1::SelectionItems

List of widget autocomplete results. Corresponds to the JSON property suggestions



6684
6685
6686
# File 'lib/google/apis/chat_v1/classes.rb', line 6684

def suggestions
  @suggestions
end

#widgetString

The ID of the updated widget. The ID must match the one for the widget that triggered the update request. Corresponds to the JSON property widget

Returns:

  • (String)


6690
6691
6692
# File 'lib/google/apis/chat_v1/classes.rb', line 6690

def widget
  @widget
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6697
6698
6699
6700
# File 'lib/google/apis/chat_v1/classes.rb', line 6697

def update!(**args)
  @suggestions = args[:suggestions] if args.key?(:suggestions)
  @widget = args[:widget] if args.key?(:widget)
end