Class: Google::Apis::ChatV1::UserMentionMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb

Overview

Annotation metadata for user mentions (@).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserMentionMetadata

Returns a new instance of UserMentionMetadata.



7192
7193
7194
# File 'lib/google/apis/chat_v1/classes.rb', line 7192

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#typeString

The type of user mention. Corresponds to the JSON property type

Returns:

  • (String)


7182
7183
7184
# File 'lib/google/apis/chat_v1/classes.rb', line 7182

def type
  @type
end

#userGoogle::Apis::ChatV1::User

A user in Google Chat. When returned as an output from a request, if your Chat app authenticates as a user, the output for a User resource only populates the user's name and type. Corresponds to the JSON property user



7190
7191
7192
# File 'lib/google/apis/chat_v1/classes.rb', line 7190

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7197
7198
7199
7200
# File 'lib/google/apis/chat_v1/classes.rb', line 7197

def update!(**args)
  @type = args[:type] if args.key?(:type)
  @user = args[:user] if args.key?(:user)
end