Class: Google::Apis::ChatV1::WorkflowDataSourceMarkup
- Inherits:
-
Object
- Object
- Google::Apis::ChatV1::WorkflowDataSourceMarkup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chat_v1/classes.rb,
lib/google/apis/chat_v1/representations.rb,
lib/google/apis/chat_v1/representations.rb
Overview
- Only supported by Google Workspace Workflow, but not Google Chat apps or
Google Workspace add-ons. In a
TextInputorSelectionInputwidget with MULTI_SELECT type or aDateTimePicker, provide data source from Google.
Instance Attribute Summary collapse
-
#include_variables ⇒ Boolean
(also: #include_variables?)
Whether to include variables from the previous step in the data source.
-
#type ⇒ String
The type of data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowDataSourceMarkup
constructor
A new instance of WorkflowDataSourceMarkup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowDataSourceMarkup
Returns a new instance of WorkflowDataSourceMarkup.
6887 6888 6889 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6887 def initialize(**args) update!(**args) end |
Instance Attribute Details
#include_variables ⇒ Boolean Also known as: include_variables?
Whether to include variables from the previous step in the data source.
Corresponds to the JSON property includeVariables
6879 6880 6881 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6879 def include_variables @include_variables end |
#type ⇒ String
The type of data source.
Corresponds to the JSON property type
6885 6886 6887 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6885 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6892 6893 6894 6895 |
# File 'lib/google/apis/chat_v1/classes.rb', line 6892 def update!(**args) @include_variables = args[:include_variables] if args.key?(:include_variables) @type = args[:type] if args.key?(:type) end |